%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  $RCSfile: lexicon.pl,v $
%% $Revision: 1.58 $
%%     $Date: 2004/01/02 01:07:41 $
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%   Milca English Resource Grammar (MERGE) for the Trale system
%%
%%   Authors: Kordula De Kuthy, Vanessa Metcalf, Detmar Meurers  
%%            Department of Linguistics, The Ohio State University 
%%            http://ling.osu.edu/~dm/merge/
%%
%%            Based on the English Resource Grammar (ERG)
%%            Version of Jan 16, 2002, developed at CSLI, Stanford
%%            University by Dan Flickinger in collaboration with 
%%            colleagues on the German Verbmobil project and with 
%%            member institutions of the the LinGO consortium, cf.
%%            http://lingo.stanford.edu/
%%
%%   Lexicon
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile '~~>'/2.
:- multifile '~~~>'/2.
:- multifile '~~~~>'/2.

%%%%% proper nouns
%%%%-----------------------------

kim       ~~> @n_proper_le.
sandy     ~~> @n_proper_le.               
cindy     ~~> (@n_proper_le,
               synsem:local:agr:png:gen:fem_star).
tom       ~~> (@n_proper_le,
               synsem:local:agr:png:gen:masc_star).
bob       ~~> (@n_proper_le,
               synsem:local:agr:png:gen:masc_star).
abrams    ~~> @n_proper_le.
browne    ~~> @n_proper_le.
chiang    ~~> @n_proper_le.
devito    ~~> @n_proper_le.
lee       ~~> @n_proper_le.
sara      ~~> (@n_proper_le,
               synsem:local:agr:png:gen:fem_star).
pat       ~~> @n_proper_le.               
csli      ~~> @n_proper_le.

january ~~> @n_month_le.
july    ~~> @n_month_le.

%january_2
january ~~> @n_month_year_le.
july    ~~> @n_month_year_le.

%nineteen_eightyfour_2
nineteen_eightyfour ~~> @n_year_le.
nineteen_eightysix  ~~> @n_year_le.

%monday_n1
monday ~~> @n_day_of_week_le.

%monday_n2
mon ~~> @n_day_of_week_le.

%tuesday_n1
tuesday ~~> @n_day_of_week_le.

%France_n1
france ~~> @n_proper_le.

%Paris_n1
paris ~~> @n_proper_le.

palo_alto ~~> @n_proper_le.

%% pronouns
%-----------------------------
%nominative
i  ~~> (@n_pers_pro_le,
             synsem:local:(cat:head:case:nom,
                           keys:key:inst:(png:(pn:firstsg_star),
                                          prontype:std_1sg))).

you  ~~> (@n_pers_pro_le,
             synsem:local:(keys:key:inst:(png:(pn:secondper),
                                          prontype:std_2))).

he  ~~> (@n_pers_pro_le,
             synsem:local:(cat:head:case:nom,
                           keys:key:inst:(png:(pn:thirdsg_star,
                                               gen:masc),
                                          prontype:std_3))).

she  ~~> (@n_pers_pro_le,
             synsem:local:(cat:head:case:nom,
                           keys:key:inst:(png:(pn:thirdsg_star,
                                               gen:fem),
                                          prontype:std_3))).

it  ~~> (@n_pers_pro_le,
             synsem:local:(keys:key:inst:(png:(pn:thirdsg_star,
                                               gen:neut),
                                          prontype:std_3),
                           ctxt:activated:minus)).

it    ~~> @n_expl_it_le.
there ~~> @n_expl_there_le.
there ~~> (@n_adv_le,
           synsem:local:( cat:head:case:acc,
                   cont:liszt:[( handel:Hand, 
                                   inst:Inst),
                                 x_def_rel,
                               (adv_rel, %x_there_rel
                                handel:Hand,
                                 arg:Inst)],
                   keys:key:place_rel)).

we ~~> (@n_pers_pro_le,
             synsem:local:(cat:head:case:nom,
                           keys:key:inst:(png:pn:firstpl_star,
                                          prontype:std_1pl))).

they ~~> (@n_pers_pro_le,
             synsem:local:(cat:head:case:nom,
                           keys:key:inst:(png:pn:thirdpl_star,
                                          prontype:std_3))).

%%%this is used for things like "everyone is sara aren't they"
%%%they_sg
they ~~> (@n_pers_pro_noagr_le,
          synsem:local:(cat:head:case:nom,
                        keys:key:inst:(png:(pn:thirdsg_star,
                                            gen:andro_star),
                                       prontype:std_3),
                        agr:png:pn:thirdpl_star)).

%%%%accusative 
me ~~> (@n_pers_pro_le,
            synsem:local:(cat:head:case:acc,
                          keys:key:inst:(png:pn:firstsg_star,
                                         prontype:std_1sg))).

her ~~> (@n_pers_pro_le,
            synsem:local:(cat:head:case:acc,
                          keys:key:inst:(png:(pn:thirdsg_star,
                                              gen:fem),
                                         prontype:std_3))).

him ~~> (@n_pers_pro_le,
            synsem:local:(cat:head:case:acc,
                          keys:key:inst:(png:(pn:thirdsg_star,
                                              gen:masc),
                                         prontype:std_3))).
us ~~> (@n_pers_pro_le,
            synsem:local:(cat:head:case:acc,
                          keys:key:inst:(png:pn:firstpl_star,
                                         prontype:std_1pl))).

them ~~> (@n_pers_pro_le,
             synsem:local:(cat:head:case:acc,
                           keys:key:inst:(png:pn:thirdpl_star,
                                          prontype:std_3))).

%possessive
my ~~> (@det_poss_le,
           synsem:local:cont:liszt:[relation,
                                    relation,
                                    relation,
                                    inst:(png:pn:firstsg_star,
                                          prontype:std_1sg)]).

her ~~> (@det_poss_le,
            synsem:local:cont:liszt:[relation,
                                     relation,
                                     relation,
                                     inst:(png:(pn:thirdsg,
                                                gen:fem),
                                           prontype:std_3)]).

his ~~> (@det_poss_le,
    synsem:local:cont:liszt:[relation, relation, relation,
                               ( inst: (png:(pn:thirdsg,
                                             gen:masc_star),
                                        prontype:std_3))]).

its ~~> (@det_poss_le,
    synsem:local:cont:liszt:[ relation, relation, relation,
                               ( inst:(png:(pn:thirdsg_star,
                                            gen:neut_star),
                                       prontype:std_3 ))]).

their ~~> (@det_poss_le,
              synsem:local:cont:liszt:[relation,
                                       relation,
                                       relation,
                                       (inst:(png:pn:nonthirdsg,
                                              prontype:std_3))]).

mine ~~> (@n_poss_pro_le,
             synsem:local:cont:liszt:hd:inst:png:pn:firstsg).

%% Deictic pronouns

%that_deix
that ~~> (@n_deictic_pro_le,
   synsem:local:keys:(key:inst:png:(pn:thirdsg_star,
                                    gen:neut_star),
                      altkey:demon_far_rel)).  %_that_dem_rel

%these_deix
these ~~> (@n_deictic_pro_le,
   synsem:local:keys:(key:inst:png:pn:thirdpl_star,
                      altkey:demon_near_rel)).  %_these_dem_rel

%this_deix
this ~~> (@n_deictic_pro_le,
   synsem:local:keys:(key:inst:png:(pn:thirdsg_star,
                                    gen:neut_star),
                      altkey:demon_near_rel)).  %_this_dem_rel

%those_deix
those ~~> (@n_deictic_pro_le,
   synsem:local:keys:(key:inst:png:pn:thirdpl_star,
                      altkey:demon_far_rel)).  %_these_dem_rel

%% Generic pronouns

anyone ~~> (@n_generic_pro_le,
               synsem:local:keys:(key:reg_nom_rel, %_person_rel
                                  altkey:explicit_quant_agr_rel)). %_any_rel

everyone ~~> (@n_generic_pro_le,
              synsem:local:keys:( key:reg_nom_rel,
                                  altkey:explicit_quant_rel )).

           
%% Reflexive pronouns

herself ~~> (@n_refl_pro_le,
                synsem:local:keys:key:inst:png:(pn:thirdsg_star,
                                                gen:fem_star)).
himself ~~> (@n_refl_pro_le,
                synsem:local:keys:key:inst:png:(pn:thirdsg_star,
                                                gen:masc_star)).

itself ~~> (@n_refl_pro_le,
               synsem:local:keys:key:inst:png:(pn:thirdsg_star,
                                               gen:neut_star)).

myself ~~> (@n_refl_pro_le,
               synsem:local:keys:key:inst:png:pn:firstsg_star).

ourselves ~~> (@n_refl_pro_le,
                  synsem:local:keys:key:inst:png:pn:firstpl_star).

themselves ~~> (@n_refl_pro_le,
                   synsem:local:keys:key:inst:png:pn:thirdpl_star).

yourself ~~> (@n_refl_pro_le,
                 synsem:local:keys:key:inst:png:pn:secondsgstar).

yourselves ~~> (@n_refl_pro_le,
                   synsem:local:keys:key:inst:png:pn:secondpl_star).

each_other ~~> (@n_recip_pro_le,
                synsem:local:keys:key:inst:png:(png, pn:nonfirstsg)).

%% Wh pronouns
%what1
what ~~~~> (@n_wh_pro_le,
            synsem:local:keys:key:thing_rel).

what ~~~~> (@det_wh_le,
    synsem:( local:keys:key:(which_rel, handel:Hand),
             nonlocal:que:[Hand])).

%who1
who ~~~~> (@n_wh_pro_le,
           synsem:local:keys:key:person_rel).

%whom1
whom ~~~~> (@n_wh_pro_le,
            synsem:local:(cat:head:case:acc,
                          keys:key:person_rel)).

%%%%which1
which ~~~~> (@det_part_unsp_le,
             synsem:local:keys:key:which_rel). %_which_rel

%when_nom
when ~~~~> (@n_wh_adv_le,
            synsem:local:keys:key:temp_rel).

%%%when_subord_prd
when ~~~> (@p_subconj_prd_le,
           synsem:local:keys:key:subord_rel).
                                %_when_subord_rel

%where_nom
where ~~~~> (@n_wh_adv_le,
             synsem:local:keys:key:place_rel).

how_many ~~~~> (@det_part_pl_wh_le,
                synsem:local:keys:altkey:number_rel).


%% Free relatives
%what2
what ~~~~> (@n_freerel_pro_le,
            synsem:local:keys:key:thing_rel).

%what_det_freerel
what ~~~~> (@det_freerel_le,
            synsem:local:keys:key:free_relative_ever_rel).

%whatever1
whatever ~~~~> (@n_freerel_pro_le,
                synsem:local:keys:key:thing_rel).

%when_freerel_np
when ~~~~> (@n_freerel_pro_adv_le,
            synsem:local:(keys:key:temp_rel,
                          cont:liszt:[relation,relation,temp_loc_rel])).

%whenever_freerel_np
whenever ~~~~> (@n_freerel_pro_adv_le,
                synsem:local:(keys:key:temp_rel,
                              cont:liszt:[relation,relation,temp_loc_rel])).

%where_freerel_np
where ~~~~> (@n_freerel_pro_adv_le,
             synsem:local:(keys:key:place_rel,
                           cont:liszt:[relation,relation,unspec_loc_rel])).

%how_freerel_np
how ~~~~> (@n_freerel_pro_adv_le,
           synsem:local:(keys:key:diadic_noarg_nom_rel, %_way_n_rel
                         cont:liszt:[relation,relation,unspec_manner_rel])).

whichever ~~~~> (@n_freerel_part_le,
                 synsem:local:keys:key:free_relative_ever_rel).

%whoever1
whoever ~~~~> (@n_freerel_pro_le,
               synsem:local:keys:key:person_rel).

%% Relative pronouns

%that_r
that ~~~~> @n_rel_pro_nonwh_le.
            %synsem:local:cont:index:sort:nominal_sort

%who2
who ~~~~> @n_rel_pro_le.
%           synsem:local:cont:index:sort:human
% we don't have human in our hierarchy, and the specifications on
%nouns that would have motivated such a specification do not seem to
%be enforced anywhere.

whom ~~~~> (@n_rel_pro_le,
             synsem:local:cat:head:case:acc).
                          %cont:index:sort:human

%whose_2
whose ~~~~> @det_rel_poss_le.

%which_r
which ~~~~> @n_rel_pro_le.
            %synsem:local:cont:index:sort:entity   

%when2
when ~~~~> (@pp_rel_le,
             synsem:local:keys:(key:temp_loc_rel,
                                altkey:temp_rel)).

%where2
where ~~~~> (@pp_rel_le,
              synsem:local:keys:(key:unspec_loc_rel,
                                 altkey:place_rel)).

%%Partitive nouns
%-----------------------------
%all_pn
all ~~> (@n_part_npcomp_agr_le,
    synsem:local:keys:altkey:explicit_quant_agr_rel). %_all_rel

%none_pn1
none ~~> (@n_part_ppof_noagr_le,
    synsem:local:keys:altkey:explicit_quant_rel).  %_no_det_rel

%none_pn2
none ~~> (@n_part_nocomp_le,
    synsem:local:keys:altkey:explicit_quant_rel).  %_no_det_rel

%half_pn1
half ~~> (@n_part_ppof_agr_le,
    synsem:local:keys:altkey:explicit_quant_agr_rel).  %_half_det_rel

%half_pn2
%"half sleep" or "half sleeps"
half ~~> (@n_part_nocomp_le,
    synsem:local:keys:altkey:explicit_quant_agr_rel).

%half_pn3
%"half sleep" or "half sleeps"
half ~~> (@n_part_npcomp_agr_le,
    synsem:local:keys:altkey:explicit_quant_agr_rel).

%% COMMMON NOUNS
%-----------------------------
%% Intransitive nouns
%-----------------------------
%%%own_n1
own ~~> (@n_intr_le,
            synsem:local:(cat:val:spr:[local:cat:head:poss:plus],
                          keys:key:specific_nom_rel)).  %_own_n_rel

%one_n1
one ~~> (@n_intr_le,
            synsem:local:keys:key:specific_nom_rel). %_one_n_rel

dollar ~~> (@n_intr_le,
               synsem:local:keys:key:specific_nom_rel).
           %reg_nom_rel).

dog ~~> (@n_intr_le,
             synsem:local:keys:key:specific_nom_rel).
% [ SYNSEM.LOCAL.KEYS.KEY _dog_rel ].

bitch ~~> (@n_intr_le,
             synsem:local:keys:key:specific_nom_rel).


applicant ~~> (@n_intr_le,
    synsem:local:keys:key:specific_nom_rel). 

office ~~> (@n_intr_le,
    synsem:local:keys:key:specific_nom_rel).

bookcase ~~> (@n_intr_le,

    synsem:local:keys:key:specific_nom_rel).

interview ~~> (@n_intr_le,
               synsem:local:keys:key:specific_nom_rel).

woman ~~> (@n_intr_le,
           synsem:local:keys:key:specific_nom_rel).

engineer ~~> (@n_intr_le,
              synsem:local:keys:key:specific_nom_rel).

department ~~> (@n_intr_le,
                synsem:local:keys:key:specific_nom_rel). %_department_rel

consultant ~~> (@n_intr_le,
                synsem:local:keys:key:specific_nom_rel). %_consultant_rel

person ~~> (@n_intr_le,
            synsem:local:keys:key:specific_nom_rel). %_person_rel

telephone ~~> (@n_intr_le,
               synsem:local:keys:key:telephone_rel). %_telephone_rel

%-----------------------------
%% Nouns with PPof complements
%-----------------------------

apartment ~~> (@n_ppof_le,
    synsem:local:keys:key:diadic_noarg_nom_rel).
% SYNSEM.LOCAL.KEYS.KEY _apartment_rel

manager ~~> (@n_ppof_le,
    synsem:local:keys:key:diadic_noarg_nom_rel).

program ~~> (@n_ppof_le,
    synsem:local:keys:key:reg_nom_rel).

programmer ~~> (@n_ppof_le,
    synsem:local:keys:key:diadic_noarg_nom_rel).

team ~~> (@n_ppof_le,
    synsem:local:keys:key:diadic_noarg_nom_rel).

employee ~~> (@n_ppof_le,
    synsem:local:keys:key:diadic_noarg_nom_rel).

project ~~> (@n_ppof_le,
                synsem:local:keys:key:diadic_noarg_nom_rel). %_project_n_rel


member ~~> (@n_ppof_le,
               synsem:local:keys:key:diadic_noarg_nom_rel). %_member_rel

location ~~> (@n_ppof_le,
                 synsem:local:keys:key:diadic_noarg_nom_rel). %_location_rel

meeting ~~> (@n_ppof_le,
                synsem:local:keys:key:diadic_noarg_nom_rel). %_meeting_rel

room ~~> (@n_ppof_le,
             synsem:local:keys:key:diadic_noarg_nom_rel). %_room_rel

%number_n1
number ~~> (@n_ppof_le,
              synsem:local:keys:key:diadic_noarg_nom_rel). %_number_n_rel              
location ~~> (@n_ppof_le,
    synsem:local:keys:key:diadic_noarg_nom_rel).

staff ~~> (@n_ppof_le,
           synsem:local:keys:key:diadic_noarg_nom_rel).

%%%mother_n1
mother ~~> (@n_ppof_le,
            synsem:local:keys:key:diadic_noprep_nom_rel).  %_mother_rel        

%------------------------------------
%% Miscellaneous nouns
%------------------------------------

%belief_n1
belief ~~> (@n_cpcomp_fin_le,
            synsem:local:keys:key:hcomp_nom_rel). %_belief_rel

%belief_n2
belief ~~> (@n_ppcomp_le,
            synsem:local:keys:(key:diadic_noarg_nom_rel,
                                %_belief_in_rel
                                  compkey:x_in_rel)).
time ~~> (@n_mass_le,
          synsem:local:keys:key:specific_nom_rel).
                               %_time_mass_rel

%fact_n2
fact ~~> (@n_cpcomp_fin_le,
             synsem:local:keys:key:hcomp_nom_rel). %_fact_c_rel


time ~~> (@n_temp_ppcomp_le,
             synsem:local:keys:key:modable_hour_rel). %_time_rel

%year_n1
year ~~> (@n_temp_ppcomp_le,
             synsem:local:keys:key:non_day_diadic_modable_rel). %_year_rel

%%%%%%Date and time expressions
%%%%first_day_num 1st!!!
first ~~> @n_day_of_month_le.

third ~~> @n_day_of_month_le.

%%%three_day_num
%3!!
three ~~> @n_day_of_month_card_le.

fifteen ~~> @n_day_of_month_card_le.

%%%hour_n1
hour ~~> (@n_temp_ppcomp_le,
             synsem:local:keys:key:modable_hour_rel). %_hour_rel

month ~~> (@n_ppcomp_le,
              synsem:local:keys:key:non_day_diadic_modable_rel). %_month_rel

noon ~~> (@n_hour_le,
             synsem:local:keys:key:hour: (a_ twelve)).

%day_n
day ~~> (@n_temp_ppcomp_le,
            synsem:local:keys:key:unnamed_day_rel).

%day_part
day ~~> (@n_def_day_part_le,
            synsem:local:keys:key:(def_day_part_rel, %_def_day_rel
                                   inst:(png:(png,
                                              pn:thirdsg_star,
                                              gen:neut_star),
                                         divisible:minus))).

staff ~~> (@n_plur_ppcomp_le,
              synsem:local:keys:(key:diadic_noarg_nom_rel, %_staff_n_rel
                                 compkey:x_of_rel)).  %--compkey

                                 
%%  Titles
%mr_title
mr ~~> (@n_title_le,
           synsem:local:keys:key:title_rel). % [ TITLE 'mr ]

%esquire_ttl
esq ~~> (@n_post_title_le,
            synsem:local:keys:key:title_rel). %_esquire_rel


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% DETERMINERS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% NONPARTITIVE DETERMINERS

%% Definite and indefinite articles
%------------------------------
a ~~> (@det_sg_nomod_le,
          synsem:local:keys:key:some_rel).  % _a_quant_rel

an ~~> (@det_sg_nomod_le,
          synsem:local:keys:key:some_rel).  % _a_quant_rel

the  ~~> (@det_le,
   synsem:local:(cat:val:spr:(hd:local:keys:key:just_only_degree_rel,
                              tl:e_list),
                 keys:key:x_def_rel)).

%%%%% Demonstratives
%%%%----------------------------
%%%%"this" and "that" similar syntactically, as are "these" and "those".
%%%% "this" and "these" have same key value, as do "that" and "those".

%this_det
this ~~> (@det_sm_le,
             synsem:local:keys:key:demon_near_rel). %_this_dem_rel

%that_det
that ~~> (@det_sm_le,
             synsem:local:keys:key:demon_far_rel).  %_that_dem_rel

%these_det
these ~~> (@det_pl_le,
              synsem:local:keys:key:demon_near_rel). %_these_dem_rel

%those_det
those ~~> (@det_pl_le,
              synsem:local:keys:key:demon_far_rel). %_those_dem_rel

%% Quantifiers
%---------------------------------------
every ~~> (@det_sg_le,
              synsem:local:keys:key:explicit_quant_rel). %every_rel



%some_indiv
some ~~> (@det_le,
             synsem:local:keys:key:(some_rel, %_some_indiv_rel
                                    bv:divisible:minus)).

%no_det
no ~~> (@det_le,
           synsem:local:keys:key:explicit_quant_rel). %_no_det_rel


%%% PARTITIVE DETERMINERS
%%%--------------------------------------
%%%These lexical entries are eligible as input to three lexical rules
%%%which derive partitive nouns, with either an empty comps list,
%%%or selecting a PPof complement.  Of those derived partitive nouns
%%%that take a PP complement, the "agreeing" variety take agreement
%%%features from the NP complement of "of" via the keycomp feature
%%%(divisible feat value from the determiners keycomp value, pn feat
%%%value from its own keycomp), whereas the "nonagreeing"
%%%variety takes its agreement features from the determiner itself.

%any_det
any ~~> (@det_part_le,
            synsem:local:keys:key:explicit_quant_agr_rel). %_any_rel

%Bound variable the divisible:plus value associated with
%mass and plural nouns.
some ~~> (@det_part_le,
             synsem:local:keys:key:(some_rel, %_some_rel
                                    bv:divisible:plus)).

%either_det
either ~~> (@det_part_le,
               synsem:local:keys:key:explicit_quant_agr_rel). %_either_rel

few ~~> (@det_part_pl_le,
            synsem:local:keys:key:explicit_quant_noagr_rel). %_few_rel

few ~~> (@adj_intrans_le,
    synsem:local:keys:key:adj_rel).

fewer ~~> (@adj_comp_le,
    synsem:local:keys:key:adj_rel).

many ~~> (@det_part_pl_le,
             synsem:local:keys:key:much_many_rel). %_many_rel

several ~~> (@det_part_pl_le,
                synsem:local:keys:key:explicit_quant_noagr_rel). %_several_rel

both ~~> (@det_part_pl_le,
                synsem:local:keys:key:explicit_quant_noagr_rel). %_both_rel

most ~~> (@det_part_pl_mass_le,
             synsem:local:keys:key:explicit_quant_agr_rel). %_most_q_rel

all ~~> (@det_part_pl_mass_le,
            synsem:local:keys:key:explicit_quant_agr_rel). %_all_rel

more ~~> (@det_part_pl_mass_le,
             synsem:local:keys:key:explicit_quant_agr_rel). %_more_q_rel

enough ~~> (@det_part_pl_mass_le,
    synsem:local:keys:key:explicit_quant_agr_rel).

each ~~> (@det_part_sg_le,
    synsem:local:keys:key:explicit_quant_noagr_rel).


%one_determiner
%one_num_determiner
% 1 or one
one ~~> @det_part_one_le.
            
           
%%%%% possessives
%%%%--------------------------------
'''' ~~~~> @n_poss_clitic_lex_le.

'''' ~~~~> @n_poss_clitic_phr_le.

'''s' ~~~~> @n_poss_clitic_lex_le.

'''s' ~~~~> @n_poss_clitic_phr_le.

%%%%% prepositions
%%%%-----------------------------
%as_p1
as ~~> (@p_reg_le,
           synsem:local:keys:key:x_as_rel).

at ~~> (@p_reg_le,
    synsem:local:keys:key:x_at_rel).

on ~~> (@p_reg_le,
           synsem:local:keys:key:dir_or_state_rel). %_on_rel_a
                            
in ~~> (@p_reg_le,
           synsem:local:keys:key:x_in_rel_a).

to ~~> (@p_reg_le,
           synsem:local:keys:key:x_to_rel_a).

off ~~> (@p_reg_le,
    synsem:local:keys:key:x_off_rel_a).

off ~~> (@pp_le, 
    synsem:local:keys:key:x_off_rel).

of ~~> (@p_nospec_le,
    synsem:local:keys:key:x_of_rel_a).

for ~~> (@p_le,
    synsem:local:keys:key:x_for_rel_a).

by ~~> (@p_idiom_nomod_le,
    synsem:local:keys:key:x_by_pass_rel_a).

by ~~> (@p_le,
    synsem:local:keys:key:x_by_rel_a).

than ~~> @p_compar_than_le.

with ~~> (@p_le,
    synsem:local:keys:key:x_with_rel_a).

into ~~> (@p_reg_le,
    synsem:local:keys:key:x_into_rel_a).


%%%at_temp
at ~~> (@p_temp_le,
           synsem:local:keys:(key:temp_loc_rel, %_at_temp_rel,
                              compkey:hour_rel)).

%on_day
on ~~> (@p_temp_le,
           synsem:local:keys:(key:temp_loc_rel, %_on_temp_rel
                              compkey:day_rel)).

%but_except_p
but ~~> (@p_nospec_nogap_le,
            synsem:local:keys:key:miscprep_ind_rel). %_but_except_rel

%%% for "three times a day"
%a_per_p
a ~~> (@p_nbar_comp_nmod_le,
          synsem:local:keys:key:miscprep_ind_rel). %_a_per_rel

until ~~> (@p_no_n_mod_le,
    synsem:local:keys:key:x_until_rel_a).

before ~~> (@p_le,
    synsem:local:keys:key:temp_loc_indep_rel).

after ~~> (@p_le,
    synsem:local:keys:key:x_after_prepx_rel_a).

during ~~> (@p_le,
    synsem:local:keys:key:temp_loc_indep_rel).

without ~~> (@p_le,
    synsem:local:keys:key:x_without_rel_a).

%% intransitive verbs
%------------------------------
%%%walk_v1
walk ~~> (@v_unerg_le,
             synsem:local:keys:key:specific_arg1_rel). %walk_v_rel
             
arrive ~~> (@v_unerg_le,
               synsem:local:keys:key:specific_arg1_rel).

run    ~~> (@v_unerg_le,
               synsem:local:keys:key:specific_arg1_rel).

sleep  ~~> (@v_unerg_le,
               synsem:local:keys:key:specific_arg1_rel).

go     ~~> (@v_unerg_le,
               synsem:local:keys:key:specific_arg1_rel).

work   ~~> (@v_unerg_le,
               synsem:local:keys:key:work_unspec).

stand  ~~> (@v_unerg_le,
               synsem:local:keys:key:specific_arg1_rel).

fail ~~> (@v_unerg_le,
%%  [ stem < "fail" >,
    synsem:local:keys:key:specific_arg13_rel).

know ~~> (@v_unerg_le,
    synsem:local:keys:key:specific_arg13_rel).

see ~~> (@v_unerg_le,
    synsem:local:keys:key:specific_arg1_rel).

smile ~~> (@v_unerg_le,
    synsem:local:keys:key:specific_arg1_rel).


do ~~> (@v_unerg_le,
    synsem:local: (cat:head:vform:bse_only,
                   keys:key:specific_arg1_rel)).

leave ~~> (@v_unerg_le,
    synsem:local:keys:key:specific_arg134_rel).

%%%wonder_v2
wonder ~~> (@v_unerg_le,
               synsem:local:keys:key:specific_arg14_rel). %_wonder_rel

%%%rain1
rain ~~> (@v_atrans_le,
             synsem:local:keys:key:weather_v_rel). %_rain_rel

talk ~~> (@v_unerg_le,
    synsem:local:keys:key:specific_arg13_rel).

%%%consult_v1
consult ~~> (@v_unerg_le,
                synsem:local:keys:key:specific_arg13_rel). %_consult_rel

%% transitive verbs
%--------------------------------
%%%find_v1
find ~~> (@v_np_trans_le,
   synsem:local:keys:key:specific_arg123_rel). %_find_rel

hire ~~> (@v_np_trans_le,
             synsem:local:keys:key:specific_arg13_rel).

need ~~> (@v_np_trans_le,
    synsem:local:keys:key:specific_arg13_rel).

evaluate ~~> (@v_np_trans_le,
    synsem:local:keys:key:specific_arg13_rel).

list ~~> (@v_np_trans_le,
    synsem:local:keys:key:specific_arg13_rel).

fail ~~> (@v_np_trans_le,
    synsem:local:keys:key:specific_arg13_rel).

see ~~> (@v_np_trans_le,
    synsem:local:keys:key:specific_arg13_rel).

employ ~~> (@v_np_trans_le,
    synsem:local:keys:key:specific_arg13_rel).


leave ~~> (@v_np_trans_le,
    synsem:local:keys:key:specific_arg134_rel).

interview ~~> (@v_npstar_trans_le,
    synsem:local:keys:key:specific_arg13_rel).

help ~~> (@v_npstar_trans_le,
    synsem:local:keys:key:specific_arg13_rel).

%%%win_v1
win ~~> (@v_npstar_trans_le,
   synsem:local:keys:key:specific_arg13_rel).  %_win_rel

%%%eat1
eat ~~> (@v_npstar_trans_le,
   synsem:local:keys:key:specific_arg13_rel).  %_eat_rel            

become ~~> (@v_np_non_trans_le,
    synsem:local:keys:key:specific_arg12_rel).

approve ~~> (@v_empty_prep_intrans_le,
    synsem:local:keys: (key:specific_arg13_rel,
                        compkey:x_of_rel_s)).

%%%run_into_v1
run ~~> (@v_empty_prep_intrans_le,
   synsem:local:keys:(key:specific_arg13_rel, %run_into_rel
                      compkey:x_into_rel_s)).

%visit_v1
visit ~~> (@v_np_trans_le,
              synsem:local:keys:key:specific_arg13_rel). %_visit_v_rel

manage ~~> (@v_np_trans_le,
    synsem:local:keys:key:specific_arg13_rel).

have ~~> (@v_poss_le,
    synsem:local:keys:key:specific_arg12_rel).

make ~~> (@v_np_trans_le,
    synsem:local:keys:key:specific_arg13_rel).

know ~~> (@v_np_trans_le,
    synsem:local:keys:key:specific_arg13_rel).

do ~~> (@v_np_trans_le,
    synsem:local:keys:key:(specific_arg134_rel,
                           arg3:non_expl_ind )).
move ~~>  (@v_unacc_le,
    synsem:local:keys:key:arg3_event_rel).

%%move_v2 := v_np*_trans_double_pp*_le &
%%    SYNSEM.LOCAL [ CAT.VAL.COMPS < synsem, 
%%                                   synsem,
%%                                   [ LOCAL.KEYS.KEY dir_or_state_rel ] >,
%%                   KEYS [ KEY _move_rel,
%%                          --OCOMPKEY _from_rel ] ] ].

move ~~> (@v_np_trans_le,
    synsem:local:keys:key:specific_arg13_rel).

finish ~~> (@v_np_trans_le,
    synsem:local:keys:key:specific_arg13_rel).

cease ~~> (@v_unacc_le,
    synsem:local:keys:key:arg3_event_rel).

continue ~~> (@v_unacc_le,
    synsem:local:keys:key:arg3_event_rel).

continue ~~> (@v_np_trans_le,
    synsem:local:keys:key:specific_arg13_rel).



%% ditransitive verbs
%--------------------------------
show ~~> (@v_ditrans_le,
      synsem:local:keys:key:specific_arg123_rel).


show ~~> (@v_np_trans_le,
    synsem:local:keys:key:specific_arg123_rel).

%%%like_v1
like ~~> (@v_np_trans_le,
             synsem:local:keys:key:specific_arg13_rel). %_like_rel

say ~~> (@v_pp_cp_le,
      synsem:local:keys: (key:specific_arg134_rel,
                       compkey:x_to_rel_s)).

bet ~~> (@v_np_np_cp_le,
    synsem:local:keys:key:arg1234_rel).

lay ~~> (@v_particle_np_le,
    synsem:local:keys:( key:specific_arg13_rel,
                        compkey:x_off_rel_s)).

lay ~~> (@v_np_prep_trans_dors_le,
    synsem:local:keys:key:specific_arg134_rel).

make ~~> (@v_ditrans_only_le,
    synsem:local:keys:key:specific_arg123_rel).

talk ~~> (@v_double_pp_le,
    synsem:local:keys:( key:specific_arg13_rel,
                        compkey:x_to_rel,
                        ocompkey:x_about_rel)).

talk ~~> (@v_prep_intrans_le,
%%  [ stem < "talk" >,
    synsem:local:keys:( key:specific_arg13_rel,
                        compkey:x_to_rel)).

%%% predicative verbs
%%%------------------------------
become ~~> (@v_prd_ssr_le,
    synsem:local:( cat:val:comps:[ ( local:cat:head:(adverbee, %v_or_g_or_a,
                                                     tam:aspect:strict_nonprg ) )],
                   keys:key:arg4_event_rel)).


%% subject equi verbs

know ~~> (@v_subj_equi_le,
    synsem:local:keys:key:specific_arg14_rel).

manage ~~> (@v_subj_equi_le,
    synsem:local:keys:key:specific_arg14_rel).

help ~~> (@v_subj_equi_le,
    synsem:local:keys:key:specific_arg14_rel).

help ~~> (@v_subj_equi_bse_le,
    synsem:local:keys:key:specific_arg14_rel).

promise ~~> (@v_anom_equi_le,
    synsem:local:keys:key:specific_arg134_rel).

get ~~> (@v_subj_equi_prd_le,
    synsem:local:keys:key:specific_arg134_rel).

finish ~~> (@v_subj_equi_prp_le,
    synsem:local:keys:key:specific_arg14_rel).

cease ~~> (@v_subj_equi_le,
    synsem:local:keys:key:specific_arg14_rel).

cease ~~> (@v_subj_equi_prp_le,
    synsem:local:keys:key:specific_arg14_rel).

continue ~~> (@v_subj_equi_le,
    synsem:local:keys:key:specific_arg14_rel).

continue ~~> (@v_subj_equi_prp_le,
    synsem:local:keys:key:specific_arg14_rel).

%% object equi verbs

urge ~~> (@v_obj_equi_le,
    synsem:local:keys:key:specific_arg134_rel).

cause ~~> (@v_obj_equi_le,
    synsem:local:keys:key:specific_arg134_rel).

appeal ~~> (@v_oeq_pp_inf_le,
    synsem:local:keys:( key:specific_arg134_rel,
                        compkey:x_to_rel_s)).

have ~~> (@v_obj_equi_non_trans_prd_le,
    synsem:local:keys:key:specific_arg134_rel).

%% raising verbs

fail ~~> (@v_ssr_le,
    synsem:local:keys:key:arg4_event_rel).

know ~~> (@v_sor_le,
    synsem:local:keys:key:specific_arg14_rel).

help ~~> (@v_sor_le,
    synsem:local:keys:key:specific_arg14_rel).

help ~~> (@v_sorb_le,
    synsem:local:keys:key:specific_arg14_rel).

make ~~> (@v_sorb_le,
    synsem:local:keys:key:specific_arg14_rel).

made ~~> (@v_sorb_pass_le,
    synsem:local:keys:key:specific_arg14_rel).

%%%know_v2
know ~~> (@v_cp_fin_inf_non_trans_le,
    synsem:local:keys:key:specific_arg14_rel).

see ~~> (@v_cp_fin_inf_non_trans_le,
    synsem:local:keys:key:specific_arg14_rel).

%%%wonder_v1
wonder ~~> (@v_cp_ques_fin_inf_non_trans_le,
            synsem:local:keys:key:specific_arg14_rel).  %_wonder_rel

see ~~> (@v_np_comp_le,
    synsem:local:( cat:val:comps: 
                         [( local:cont:index:Ind),
                           ( local:cont:index:Ind)],
                   keys:( key:specific_arg134_rel,
                          ocompkey:x_as_rel))).

appear ~~> (@v_pp_inf_ssr_le,
    synsem:local:keys:key:arg24_event_rel).

appear ~~> (@v_prdp_pp_ssr_le,
    synsem:local:( cat:val:comps:hd:local:cat:head:adj,
                   keys:key:arg24_event_rel)).

%% expletive verbs
appear ~~> (@v_expl_it_subj_pp_cp_le,
    synsem:local:keys:key:arg24_event_rel).

deny ~~> (@v_np_trans_le,
    synsem:local:keys:key:specific_arg13_rel).

deny ~~> (@v_cp_prop_non_trans_le,
    synsem:local:keys:key:specific_arg14_rel).

%%%think1
think ~~> (@v_cp_prop_non_trans_le,
   synsem:local:keys:key:specific_arg14_rel).  %think_h_rel

%%%believe_v3
believe ~~> (@v_cp_prop_non_trans_le,
   synsem:local:keys:key:specific_arg14_rel).  %_believe_h_rel          

%%%suppose_v1
suppose ~~> (@v_cp_propstar_non_trans_le,
   synsem:local:keys:key:specific_arg14_rel).  %_suppose_rel


%%%%% miscellaneous verbs

%%%talk_v2
talk ~~> (@v_prep_intrans_le,
   synsem:local:keys:(key:specific_arg13_rel, %_talk_about_rel
                      compkey:x_to_rel)).

%%%%% auxiliaries
%%%%------------------------------
%%%be_id_am
am ~~~> @vc_id_am_le.

%%%b_c_am
am ~~~> @vc_prd_am_le.

is ~~~> @vc_prd_is_le.

is ~~~> @vc_there_is_le.

is ~~~> @vc_id_is_le.

'''s' ~~> @vc_prd_is_cx_le.

'''s' ~~> @vc_id_is_cx_le.

'''s' ~~> @vc_there_s_cx_le.

isnt ~~~> @vc_prd_is_neg_le.

isnt ~~~> @vc_id_is_neg_le.

isnt ~~~> @vc_there_is_neg_le.

are ~~~> @vc_prd_are_le.

are ~~~> @vc_there_are_le.

are ~~~> @vc_id_are_le.

arent ~~~> @vc_prd_am_neg_le.

arent ~~~> @vc_prd_are_neg_le.

arent ~~~> @vc_id_am_neg_le.

arent ~~~> @vc_id_are_neg_le.

arent ~~~> @vc_there_are_neg_le.

be ~~> @vc_prd_be_le.

be ~~> @vc_id_be_le.

be ~~> @vc_there_be_le.

been ~~> @vc_prd_been_le.

been ~~> @vc_id_been_le.

been ~~> @vc_there_been_le.

was ~~~> @vc_prd_was_le.

was ~~~> (@vc_id_was_le).

was  ~~~> @vc_there_was_le.

wasnt ~~~> @vc_id_was_neg_le.

wasnt ~~~> @vc_there_was_neg_le.

wasnt ~~~> @vc_prd_was_neg_le.

were ~~~> @vc_prd_were_le.

were ~~~> @vc_id_were_le.

were ~~~> @vc_there_were_le.

werent ~~~> @vc_prd_were_neg_le.

werent ~~~> @vc_id_were_neg_le.

werent ~~~> @vc_there_were_neg_le.

being ~~> @vc_prd_being_le.

being ~~> @vc_id_being_le.

being ~~> @vc_there_being_le.

may ~~> (@va_modal_pos_le,
    synsem:local: (cat:head:tam:tense:present_star,
                   keys:key:modal_rel)).

might ~~> (@va_modal_subj_pos_le,
    synsem:local:( cat:head:tam:tense:present_star,
                   keys:key:modal_rel)).

can ~~~> (@va_modal_pos_le, 
    synsem:local: ( cat:head:tam:tense:present_star,
                    keys:key:modal_rel ) ).

cannot ~~> (@va_modal_neg_le,
    synsem:local: ( cat:head:tam:tense:present_star,
                   keys:key:modal_rel)).

cant ~~~> (@va_modal_neg_le,
    synsem:local:( cat:head:tam:tense:present_star,
                   keys:key:modal_rel)).

could ~~~> (@va_modal_subj_pos_le, 
    synsem:local:keys:key:modal_rel ).

couldnt ~~~> (@va_modal_subj_neg_le,
    synsem:local:keys:key:modal_rel).

must ~~> (@va_modal_pos_le, 
    synsem:local: ( cat:head:tam:tense:present_star,
                    keys:key:modal_rel ) ).

dare ~~> (@va_modal_pos_le, 
    synsem:local: (cat:head:tam:tense:present_star,
                   keys:key:modal_rel ) ).

had_better ~~> (@va_modal_pos_le,
    synsem:local: (cat:head:tam:tense:present_star,
                   keys:key:modal_rel)).

better ~~> (@va_modal_pos_le,
    synsem:local: (cat:head: (tam:tense:present_star,
                              inv:minus),
                   keys:key:modal_rel)).

shall ~~~> (@va_will_pos_le,
    synsem:local:keys:key:modal_rel ).

should ~~~> (@va_modal_subj_pos_le, 
    synsem:local:keys:key:modal_rel ).

shouldnt ~~~> (@va_modal_subj_neg_le,
    synsem:local:keys:key:modal_rel).

will ~~~> (@va_will_pos_le, 
    synsem:local:keys:key:will_would_rel ).

'''ll' ~~> (@va_will_pos_cx_le,
    synsem:local:keys:key:will_would_rel).

wont ~~~> (@va_will_neg_le,
    synsem:local:keys:key:will_would_rel).

would ~~~> (@va_would_pos_le,
    synsem:local:keys:key:will_would_rel ).

'''d' ~~> (@va_would_pos_cx_le,
    synsem:local:keys:key:will_would_rel).

wouldnt ~~~> (@va_would_neg_le,
    synsem:local:keys:key:will_would_rel).

do ~~~> (@va_do_fin_le).

dont ~~~> @va_dont_imp_le.

do_not ~~> @va_dont_imp_le.

dont ~~~> @va_dont_neg_pres_le.

does ~~~> (@va_does_le).

doesnt ~~~> @va_doesnt_neg_pres_le.

did ~~~> (@va_did_le).

didnt ~~~> @va_do_neg_past_le.

has ~~~> (@va_has_le).

'''s' ~~> @va_has_cx_le.

hasnt ~~~> @va_has_neg_le.

have ~~~> (@va_have_bse_le).

havent ~~~> @va_have_fin_neg_le.

had ~~~> @va_had_le.

'''d' ~~> @va_had_cx_le.

hadnt ~~~> @va_had_neg_le.

having ~~> @va_have_prespart_le.

ought ~~~> (@va_ought_pos_le,
    synsem:local:( cat:head:tam:tense:present_star,
                   keys:key:modal_rel)).

used ~~> (@va_past_ought_pos_le,
    synsem:local:( cat:head:tam:tense:past_star,
                   keys:key:modal_rel)).

going ~~> (@va_quasimodal_le,
    synsem:local:( cat:head:( vform:prp, 
                              prd:plus,
                              tam:tense:future_star),
                   keys:key:will_would_rel)).

%to_c_prop
to ~~> @comp_to_prop_le.

%t_c_nonprop
%to ~~> @comp_to_nonprop_le.

%%%%% Modifiers


%%%%% adjectives
%%%%------------------------

heavy~~> (@adj_intrans_le,
              synsem:local:keys:key:adj_rel). %_heavy_rel

%good_a1
good ~~> (@adj_intrans_le,
             synsem:local:keys:key:adj_rel).  %_good_rel

%trustworthy_a1
trustworthy ~~> (@adj_intrans_le,
                    synsem:local:keys:key:adj_rel). %_trustworthy_rel

competent ~~> (@adj_intrans_le,
               synsem:local:keys:key:adj_arg4_rel).
%%    SYNSEM.LOCAL.KEYS.KEY _competent_rel ].

%true_a1
true ~~> (@adj_intrans_le,
             synsem:local:keys:key:it_adj_arg4_rel). %_true_rel
%true_a2
true ~~> (@adj_reg_atrans_that_cp_le,
    synsem:local:keys:key:it_adj_arg4_rel).

%former_a1
former ~~> (@adj_intrans_le,
               synsem:local:keys:key:adj_rel). %_former_rel

%old_a1
old ~~> (@adj_intrans_le,
            synsem:local:keys:key:adj_rel). %_old_rel

older ~~> (@adj_comp_le,
              synsem:local:keys:key:adj_rel).

%oldest_a1
oldest ~~> (@adj_superl_le,
               synsem:local:keys:key:adj_rel).

hard ~~> (@adj_intrans_le,
    synsem:local:keys:key:adj_rel).

harder ~~> (@adj_comp_le,
    synsem:local:keys:key:adj_rel).

%more_adj
more ~~> (@adj_more_less_le,
             synsem:local:keys:key:more_less_adj_rel). %_more_adj_rel

unevaluated ~~> (@adj_intrans_le,
    synsem:local:keys:key:adj_rel).


%% adverbs

not ~~> (@adv_not_le).

never ~~> (@adv_vp_pre_le,
    synsem:local:keys:key:adv_rel).

too ~~> (@adv_vp_post_le,
    synsem:local:keys:key:adv_rel).

so ~~> (@adv_s_pre_word_nospec_le,
    synsem:local:keys:key:adv_rel).

evidently ~~> (@adv_vp_aux_le,
    synsem:local:keys:key:adv_rel).

evidently ~~> (@adv_s_prop_pre_le,
    synsem:local:keys:key:adv_rel).

competently ~~> (@adv_int_vp_le,
    synsem:local:keys:key:adv_rel).

previously ~~> (@adv_int_vp_le,
    synsem:local:keys:key:adv_rel).

merely ~~> (@adv_vp_aux_le,
    synsem:local:keys:key:adv_rel).

only ~~> (@adv_vp_aux_le,
    synsem:local:keys:key:adv_rel).

only ~~> (@adv_s_pre_le,
    synsem:local:keys:key:adv_rel).

only ~~> (@adv_vp_post_le,
    synsem:local:keys:key:adv_rel).

enough ~~> (@adv_int_vp_post_le,
    synsem:local:keys:key:x_enough_isect_rel).

often ~~> (@adv_int_vp_aux_le,
    synsem:local:keys:key:adv_rel).

often ~~> (@adv_int_vp_post_le,
    synsem:local:keys:key:adv_rel).

ever ~~> (@adv_vp_pre_le,
    synsem:local:keys:key:neg_polar_rel).

ever ~~> (@adv_s_pre_le,
    synsem:local:keys:key:neg_polar_rel).

then ~~> (@adv_disc_le,
    synsem:local:( cat:posthead:minus,
                   keys:key:( excl_rel, excl:(a_ then)))).

then ~~> (@adv_disc_le,
    synsem:local:( cat:posthead:plus,
                   keys:key:( excl_rel, excl:(a_ then)))).

now ~~> (@n_adv_le,
    synsem:local:cont:liszt:[( time_rel, 
                                handel:Hand, 
                                 inst:Inst),
                               x_def_rel,
                               (adv_rel, 
                                handel:Hand,
                                 arg:Inst)]).

%%%late_adv
late ~~> (@n_adv_le,
   synsem:local:cont:liszt:[(time_rel,
                             handel:Hand,
                             inst:Inst),
                            x_def_rel,
                            (adj_rel, %_late_rel
                                handel:Hand,
                                event:e:tense:no_tense,
                                arg:Inst)]).

%%%here_nom
here ~~> (@n_adv_le,
   synsem:local:(cont:liszt:[(handel:Hand,
                              inst:Inst),
                             x_def_rel,
                             (adv_rel, %_here_rel
                                 handel:Hand,
                                 arg:Inst)],
                 keys:key:place_rel)).
                             

%%%%Numbers

%ordinal
first ~~> (@adj_bare_unspecified_ord_le,
              synsem:local:(cat:head:intadj, %intadj1
                            keys:key:(const_rel,
                                      const_value:(a_ one)))). % "1"

%cardinal

a_dozen ~~> (@adj_bare_unspecified_card_le,
		synsem:local:(cat:head:intadj, %intadj1
			      keys:key:const_value:(a_ twelve))).

two ~~> (@adj_bare_unspecified_card_le,
            synsem:local:(cat:head:intadj, %intadj1
                          keys:key:const_value:(a_ two))).
three ~~> (@adj_bare_unspecified_card_le,
            synsem:local:(cat:head:intadj, %intadj1
                          keys:key:const_value:(a_ three))).

five ~~> (@adj_bare_unspecified_card_le,
             synsem:local:(cat:head:intadj, % intadj1
                           keys:key:const_value:(a_ five))). % "5"

seven ~~> (@adj_bare_unspecified_card_le,
            synsem:local:(cat:head:intadj, %intadj1
                          keys:key:const_value:(a_ seven))).

ten ~~> (@adj_bare_unspecified_card_le,
            synsem:local:(cat:head:intadj, %intadj2
                          keys:key:const_value:(a_ ten))).

thirty ~~> (@adj_bare_unspecified_card_le,
            synsem:local:(cat:head:intadj, %intadj2
                          keys:key:const_value:(a_ thirty))).

%dozen_a1 := adj_bare_specified_card_dozen_le &
%   SYNSEM.LKEYS.KEYREL.CARG "12" ].

%most_adj
most ~~> (@adj_most_least_le,
             synsem:local:keys:key:most_least_adj_rel). %_most_adj_rel


%% degree specifiers
%-------------------------

%only_deg
only ~~> (@adv_degree_spec_le,
             synsem:local:keys:key:just_only_deg_rel). %_only_deg_rel

any ~~> (@adv_degree_spec_le,
            synsem:local:keys:key:much_deg_rel). %_any_deg_rel

very ~~> (@adv_degree_spec_le,
             synsem:local:keys:key:x_very_deg_rel).

almost ~~> (@adv_degree_spec_le,
               synsem:local:keys:key:very_deg_rel). %_almost_deg_rel

twice ~~> (@adv_degree_spec_le,
              synsem:local:keys:key:very_deg_rel). %_twice_deg_rel

too ~~> (@adv_degree_spec_le,
    synsem:local:keys:key:very_deg_rel).

much ~~> (@adv_degree_spec_le,
    synsem:local:keys:key:much_deg_rel).

%as_eq_deg
as ~~> @eq_degree_spec_le.


how ~~~~> (@pp_wh_le,
    synsem:local:keys:( key:unspec_manner_rel,
                        altkey:diadic_noarg_nom_rel)).

how ~~~> (@how_compl_le,
%%  [ stem < "how" >,
    synsem:local:keys:( key:unspec_manner_rel,
                        altkey:diadic_noarg_nom_rel)).

how ~~~~> @adv_wh_degree_spec_le.
%  [ stem < "how" > ].

how ~~~~> @adj_wh_le.
%%  [ stem < "how" > ].




%%% complementizer
%%%---------------------
%that_c
that ~~> @comp_that_le.
%%%  [ STEM < "that" > ].

to ~~> @comp_to_nonprop_le.

%%%for_c
for ~~> @comp_for_le.

%%%whether_c_fin
whether ~~> @comp_whether_fin_le.

%%%whether_c_inf
whether ~~> @comp_whether_inf_le.
         
in_order_to ~~> (@p_subconj_inf_le,
    synsem:local:keys:key:subord_rel).

as ~~> (@p_cp_le,
    synsem:local:keys:key:x_as_rel).

as ~~> (@p_prdp_le,
    synsem:local:( cat:head:prd:minus,
                   keys:key:x_as_rel)).

if ~~> (@p_subconj_if_indic_le,
    synsem:local:keys:key:subord_rel).  % _if_then_rel

if ~~> (@p_subconj_if_subjnct_le,
    synsem:local:keys:key:subord_rel).  % _if_then_rel

if ~~> @comp_if_indic_le.

if ~~> @comp_if_subjnct_le.


although ~~> (@p_subconj_le,
    synsem:local:keys:key:subord_rel).

when ~~> (@p_subconj_le,
    synsem:local:keys:key:subord_rel).

until ~~> (@p_cp_le,
    synsem:local:keys:key:x_until_rel).

before ~~> (@p_cp_le,
    synsem:local:keys:key:temp_loc_indep_rel).

after ~~> (@p_cp_le,
    synsem:local:keys:key:x_after_prepx_rel).

as_soon_as ~~> (@p_subconj_le,
    synsem:local:keys:key:subord_rel ).

while ~~> (@p_subconj_le,
    synsem:local:keys:key:subord_rel).



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Coordination
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%and_conj
and ~~~> (@conj_complex_le,
   synsem:local:(conj:(lex_conj,
                       chead:left:[cnil,cnil]),
                 cont:liszt:[conj_rel], %_and_rel
                 agr:png:(png,
                          pn:thirdpl))).

%and_conj_2
and ~~~> (@conj_complex_le,
   synsem:local:(conj:(lex_conj,
                       chead:left:[both]),
                 cont:liszt:[conj_rel], %_and_rel
                 agr:png:(png,
                          pn:thirdpl))).

%both_conj
both ~~~> (@conj_atomic_le,
             synsem:local:conj:both).

%either_conj
either ~~~> (@conj_atomic_le,
               synsem:local:conj:either).

either ~~> (@adv_post_le,
    synsem:local:keys:key:adv_rel).

%or_conj_1
or ~~~> (@conj_complex_le,
   synsem:local:(cat:val:comps:hd:local:agr:Agr,
                 agr:Agr,
                 conj:(lex_conj,
                       chead:left:[cnil,cnil]),
                 cont:liszt:[conj_rel])).  %_or_rel

%or_conj_2
or ~~~> (@conj_complex_le,
   synsem:local:(cat:val:comps:hd:local:agr:Agr,
                 agr:Agr,
                 conj:(lex_conj,
                       chead:left:[either]),
                 cont:liszt:[conj_rel])).  %_or_rel

%neither_conj
neither ~~~> (@conj_atomic_le,
                synsem:local:conj:neither).

neither ~~> (@det_part_sg_le,
    synsem:local:keys:key:explicit_quant_noagr_rel).


%nor_conj
nor ~~~> (@conj_complex_le,
   synsem:local:(conj:(lex_conj,
                       chead:left:[cnil,cnil]),
                 cont:liszt:[conj_rel], %_nor_rel
                 agr:png:(png,
                          pn:thirdpl))).

%nor_conj_2
nor ~~~> (@conj_complex_le,
   synsem:local:(conj:(lex_conj,
                       chead:left:[neither]),
                 cont:liszt:[conj_rel], %_nor_rel
                 agr:png:(png,
                          pn:thirdpl))).


but ~~~> (@conj_complex_le,
    synsem:local:( cat:val:comps:hd:local:cont:index:event,
                   conj:(lex_conj, chead:left:[cnil]),
                   cont:liszt:[conj_rel])). %_but_rel
