%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  $RCSfile: lexrules.pl,v $
%% $Revision: 1.41 $
%%     $Date: 2004/01/02 03:24:47 $
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%   Milca English Resource Grammar (MERGE) for the Trale system
%%
%%   Authors: Kordula De Kuthy, Vanessa Metcalf, Detmar Meurers  
%%            Department of Linguistics, The Ohio State University 
%%            http://ling.osu.edu/~dm/merge/
%%
%%            Based on the English Resource Grammar (ERG)
%%            Version of Jan 16, 2002, developed at CSLI, Stanford
%%            University by Dan Flickinger in collaboration with 
%%            colleagues on the German Verbmobil project and with 
%%            member institutions of the the LinGO consortium, cf.
%%            http://lingo.stanford.edu/
%%
%%   Lexical rule definitions
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile '##'/2.
:- multifile if/2.
:- multifile '*>'/2. 
:- multifile ':='/2.

:- discontiguous ':='/2.
:- discontiguous lex_rule/2.

:- lex_rule_depth(5).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Verbal inflections

non_fin_verb := 
  ( stemhead:vstem,
    cat:head: (voice:active,
	       tam: (tense:Tense,
		     aspect:Aspect)),
    cont:index: (Index,   e: (tense:Tense,
			      aspect:Aspect)),
    keys:key:event:Index).

verb_participle_affix := 
  ( stemhead:vstem,
    cat: (head: (mod:[( local: (intersective_mod,
			         cat: (@n_or_v_cat, 
                                       head: (aux:minus,
                                              tam:tense:real_tense)),
                                 agr:Agr))],
		 prd:plus),
	  val:subj:[ ( local:cont:index:Agr,
                       nonlocal:slash:e_list)],	%0-dlist
	  hc_lex:minus),
    cont: (top:Hand,
	   index:Event),
    agr:Agr,
    keys:key: (handel:Hand,
	       event:Event)).

prp_verb := (@non_fin_verb,@verb_participle_affix,
    cat:head: (vform:prp,
	       tam:aspect:progr_star)).

%DPF 27-May-01 - Removed [ASPECT perf*] since this form is also used for
%passives, and since the auxiliary "have" already imposes ASPECT perf* on the
%relevant event.
psp_verb := (@non_fin_verb, nomod_local,
    cat: (head: (vform:psp,
		  prd:minus),
	  val:subj:[opt:minus])).


non_perf := local.

bse_verb := (@non_fin_verb,@non_perf,
    cat:( head: (vform:bse,	
                 mod: [(local: (intersective_mod,
			        cat: @nbar_cat))],
		 prd:minus,
		 tam:aspect:no_aspect_star),
          posthead:plus,
	  val:subj:[( unexpressed,opt:minus)])).

basic_fin_verb := (@non_perf,
 stemhead:vstem,
    cat:(head:(prd:minus,
                 voice:active,
		 tam:( tense:Tense,
		       aspect:Aspect),
		 vform:fin_star,
		 mod:[(local:( intersective_mod,
			       cat: @nbar_cat ))]),
	  posthead:plus,
	  val:subj:[( synsem , local:( cat: @nomp_cat_nom, %nomp_cat_nom_min
				       conj:cnil))]),
    cont:(psoa,index:(Event, e:( tense:Tense,
				 aspect:Aspect))),
    keys:key:event:Event).

fin_verb := (@basic_fin_verb,  
                cat:val:subj:[(opt:minus)]).

pres_verb := (@fin_verb, 
                 cat:head:tam:(ind_or_mod_subj_tam, % 'star' types
			       %needed for coordination
			       tense:present_star,
			       aspect:no_aspect_star,
			       mood:indicative_star)).

past_or_subj_verb := (@fin_verb,
      cat:head:tam:past_or_subj_tam ).

third_sg_fin_verb := (@pres_verb,
                         agr:png:pn:thirdsg).

non_third_sg_fin_verb := (@pres_verb,
    cat:val:subj:[(local: (local,cont:nom_obj))],
    agr:png:(png,pn:strict_nonthirdsg)). %,strict_sort


%% Constraints on lexical rules

(word,lr:lexrule_supermost) *>(dtr:(sign,alts:Alts,
                                posscl:minus),
                      alts:Alts ).


(word,lr:lex_rule_super) *>
  ( synsem:amalgamating_synsem, %added for nonlocal feature amalgamation
    dtr: (word,
	     inflected:plus,
	     synsem:local:conj:cnil),
      inflected:plus,
      synsem:local:conj:cnil).

(word,lr:lex_rule_compos ) *>
  ( dtr:synsem:local:cont:liszt:Middle,
    synsem:local:cont:liszt:Result,
    c_cont:liszt:First)
 goal (append(First,Middle,Result)).

(word,lr:lex_rule_super_compos) *> (posscl:minus).


%---------------------------------------------------------------

lex_rule := (word, lr:lex_rule_super_compos,
    dtr: (synsem:local: (cat: (mc:Mc,
			       hc_lex:Hclex),
			 keys:message:Msg)),
    synsem:local: (arg_s:valence_append(Subj,Spr,Comps),%added
		      cat: (val:(subj:Subj,
				 spr:Spr,
				 comps:Comps),
			       mc:Mc,
			       hc_lex:Hclex),
		      keys:message:Msg)).

lex_rule_infl_affixed_macro(Dtr) := %% lex_rule_compos &
   (inflected:plus,
    key_arg:Keyarg,   
    synsem:Synsem,
    root:Root,
    posscl:minus,
    dtr:(Dtr,    inflected:minus,
                 key_arg:Keyarg,   
                 synsem:Synsem,
                 root:Root),
    c_cont:liszt:e_list).



%%% lexical rule to derive fin verbs form bse verbs


third_sg_fin_verb_infl_rule ##
    Dtr
**>
   ( lr:lex_rule_infl_affixed,
    needs_affix:plus,
    synsem:local: @third_sg_fin_verb,
    @lex_rule_infl_affixed_macro(Dtr))
morphs
%suffix (!s !ss) (!ss !ssses) (ss sses) (!ty !ties) (ch ches) (sh shes) (x xes) (z zes)
     X      becomes  Y when irregpres(X,Y), 
    (X,S,s) becomes (X,S,ssess) when letter_set_s(S),
    (X,ss)  becomes (X,sses),  
    (X,T,y) becomes (X,T,ies) when letter_set_t(T), 
    (X,ch)  becomes (X,ches),
    (X,sh)  becomes (X,shes),
    (X,x)   becomes (X,xes),
    (X,z)   becomes (X,zes),    
    (X,C)   becomes (X,C,s) when letter_set_s(C).

psp_verb_infl_rule ##
%suffix (* ed) (!ty !tied) (e ed) (!t!v!c !t!v!c!ced)
    Dtr
**>    
   (lr:lex_rule_infl_affixed,
    needs_affix:plus,
    synsem:local: @psp_verb,
    @lex_rule_infl_affixed_macro(Dtr))
morphs
     X        becomes  Y when irregpast(X,_,Y),
    (X,T,y)   becomes (X,T,ied) when letter_set_t(T), 
    (X,e)     becomes (X,ed),
    (X,T,V,C) becomes (X,T,V,C,C,ed) when (letter_set_t(T),letter_set_v(V),letter_set_c(C)), 
     X        becomes (X,ed).


past_verb_infl_rule ##
%suffix (* ed) (!ty !tied) (e ed) (!t!v!c !t!v!c!ced) 
    Dtr
**>
  (lr:lex_rule_infl_affixed,
    needs_affix:plus,
    synsem:local: @past_or_subj_verb,
    @lex_rule_infl_affixed_macro(Dtr))
morphs
     X        becomes  Y when irregpast(X,Y,_),
    (X,T,y)   becomes (X,T,ied) when letter_set_t(T), 
    (X,e)     becomes (X,ed),
    (X,T,V,C) becomes (X,T,V,C,C,ed) when (letter_set_t(T),letter_set_v(V),letter_set_c(C)), 
     X        becomes (X,ed).

prp_verb_infl_rule ##
%suffix (!t!v!c !t!v!c!cing) (* ing) (e ing) (ee eeing) (ie ying)
    Dtr
**>
   (lr:lex_rule_infl_affixed,
    needs_affix:plus,
    synsem:local: @prp_verb,
    @lex_rule_infl_affixed_macro(Dtr))
morphs
     X        becomes  Y when irregprp(X,Y),
    (X,T,V,C) becomes (X,T,V,C,C,ing) when (letter_set_t(T),letter_set_v(V),letter_set_c(C)),
    (X,e)     becomes (X,ing),
    (X,ee)    becomes (X,eeing),
    (X,ie)    becomes (X,ying),
     X        becomes (X,ing).


bse_verb_infl_rule ##
    Dtr
**>
   (lr:lex_rule_infl_affixed,
    needs_affix:minus,
    synsem:local: @bse_verb,
    @lex_rule_infl_affixed_macro(Dtr))
morphs X becomes X.


non_third_sg_fin_verb_infl_rule ##
    Dtr
**>
   (lr:lex_rule_infl_affixed,
    needs_affix:minus,
    synsem:local: @non_third_sg_fin_verb,
    @lex_rule_infl_affixed_macro(Dtr))
morphs X becomes X.


%% non-inflectional lexical rules

sai(Dtr) := (@lex_rule,
    dtr:(Dtr,synsem:( local:( cat:( head:( verb,
				        inv:plus,
					 vform:(fin_star,Vform),
                                         tam:Tam,
					 voice:Voice),
				  val:( subj:[(Subj,canonical_synsem,
                                                local:cat: @nomp_cat_nom )],
					comps:Comps,
					spr:Spr,
					keycomp:Keycomp)),
			    cont:( top:Dtrhand,
				   index:Ind,
				   h_cons:Hcons),
                            agr:Agr,
			    keys:Keys),
                    nonlocal:Nonloc)),
    synsem:( @sai_synsem,
	  local:( cat:( head:( vform:Vform,
				tam:Tam,
                                voice:Voice),
                         val:( comps:[(Subj, opt:minus)
				       |Comps ],
			       spr:Spr,
			       subj:[anti_synsem],
			       keycomp:Keycomp)),
		   cont:( top:Dtrhand,
			  index:Ind,
			  h_cons:Hcons),
                   agr:Agr,
		   keys:(Keys,
		        message:[])),
	   nonlocal:Nonloc),
    c_cont:liszt:[]).

sai_rule ##
   Dtr
**>
  (lr:sai,
   @sai(Dtr))
morphs X becomes X.

tag(Dtr) := (lr:lex_rule_super,
    dtr:(Dtr,synsem:(@sai_synsem,
		     local:(cat:(head:tam:Tam,
				 val:comps:(hd:local:agr:png:Png,
					    tl:hd:local:cat:head:subst),
				 hc_lex:Hclex),
			    keys:key:Key),
		     nonlocal:(Nonloc,
			       slash:[],
			       rel:[],
			       que:[]))),
    synsem:(@tag_synsem,
	    local:(cat:(head:tam:Tam,
			val:comps:hd:(synsem,
				      local:(cat: @nomp_cat_nom, %@nomp_cat_nom_min,
					     agr:png:Png,
					     keys:message:[],
					     conj:cnil),
				      opt:minus),
			hc_lex:Hclex),
		   cont:liszt:Cliszt,
		   keys:(key:Key,
			 message:[Msg])),
	    nonlocal:Nonloc),
    dtr:Dtr,		
    c_cont:liszt:(Cliszt,
		  [Msg])).

tag_rule ##
   Dtr
**>
  (lr:tag,
   @tag(Dtr))
morphs X becomes X.

adv_addition(Dtr) := (@lex_rule,
    dtr: (Dtr,synsem: 
               ( local:( stemhead:vstem,
			 cat:( head:( verb,
				      aux:plus,
				      vform:fin,
                                      mod:Mod,
                                      prd:Prd,
                                      inv:Inv,
                                      tam:Tam,
                                      voice:Voice),
			       val:( subj:(Subj,[synsem]),
				     comps:(Comps,substlist),
				     spr:Spr),
			       posthead:Ph),
			 cont:( top:Vtop,
				index:Vindex,
				h_cons:Hcons),
			 ctxt:Ctxt,
			 keys:Keys),
		 nonlocal:Nonloc)),
    synsem:( @aux_verb,
	  local: 
	   ( cat: 
	     ( head:( verb,
                      aux:plus_star,
                      vform:fin,
                      mod:Mod,
                      prd:Prd,
                      inv:Inv,
                      tam:Tam,
                      voice:Voice),
               val:( subj:Subj,
		     comps:[( local:( local,
				     cat:head:(basic_lexadv,
                                           mod:[( local:cont:top:Vtop)],
                                            tam:tense:no_tense),
				      cont:( top:Advtop,
                                             index:Vindex),
				      keys:message:[]),
			      lex:plus,
			      opt:minus)|Comps],
		     spr:Spr),
	       posthead:Ph),
	     cont:( top:Advtop,
		    index:Vindex,
		    h_cons:Hcons),
	     ctxt:Ctxt,
	     keys:Keys),
	   nonlocal:Nonloc),
    c_cont:liszt:[]).

adv_addition_rule ##
   Dtr
**>
  (lr:adv_addition,
   @adv_addition(Dtr))
morphs X becomes X.

vp_ellipsis := (@lex_rule,
%%   stem #orth,
    dtr:(% stem #orth,
	  synsem: 
	   (local: (cat: (head:(verb,
				  mod:Mod,
                                  prd:Prd,
                                  inv:Inv,
                                  aux:plus,
                                  tam:(Tam,
                                       aspect:nonprg),
                                  vform:Vform,
                                  voice:Voice),
                           posthead:Ph,
			   val:( subj:Subj,
				 spr:Spr,
				 comps:[(unexpressed,
					  local:( cat:head:subst,
						   cont: (top:Chand,
                                                          e_index:Cind),
						   keys:key:Altkey))])),
		     cont:( top:Hand,
			    index:Ind,
			    h_cons:Hcons),
		     ctxt:Ctxt,
		     keys:key:Key),
	     nonlocal:Nonloc)),
    synsem:(@verb_synsem,
	    local:( cat:( head:(verb, 
                                mod:Mod,
                                prd:Prd,
                                inv:Inv,
                                aux:plus_star,
                                tam:Tam,
                                vform:Vform,
                                voice:Voice),
                         posthead:Ph,
			 val:( subj:Subj,
			       spr:Spr,
			       comps:[])),
		   cont:( top:Hand,
			  index:Ind,
			  h_cons:Hcons),
		   keys:( key:Key,
			  altkey:(Altkey,ellipsis_rel,
				         handel:Chand,
                                         event:Cind)),
		   ctxt:Ctxt),
	   nonlocal:Nonloc ),
    c_cont:liszt:[Altkey]).

vp_ellipsis_ref(Dtr) := (@vp_ellipsis,
   dtr:(Dtr,synsem:local:cat:val: (subj:[(local:cont:index:(ref_ind,Sind))],
			           comps:[(local:cont:index:Cind)])),
   synsem: (@verb_synsem,
	    local:keys:altkey: (event:Cind,
			        role:Sind))).

vpellipsis_ref_lr ##
    Dtr
**>
   (lr:vp_ellipsis_ref,
    @vp_ellipsis_ref(Dtr))
morphs X becomes X.   

vp_ellipsis_expl(Dtr) := (@vp_ellipsis,
   dtr:(Dtr,synsem:local:cat:val:subj:[( local:( cont:index:there_ind,
					      keys:key:no_rel))]),
    synsem:(@verb_synsem,
	  local: ( cont:index:Event,
		   keys:altkey:event:Event))).

vpellipsis_expl_lr ##
    Dtr
**>
   (lr:vp_ellipsis_expl,
    @vp_ellipsis_expl(Dtr))
morphs X becomes X.   

passive_verb(Dtr) := (@lex_rule,
    dtr: (Dtr,
          alts:passive:plus,
	  synsem:(@trans_subst, @verb_synsem, %as a type, this
		  %filtered out other head types which would unify with
		  %verb*
                 local: (stemhead:vstem,
                         cat: (head: (verb, %added
					 vform:psp_or_psp_irreg,
					 tam: (tense:Tense,
                                            aspect:nonprf,
                                            mood:Mood) ),
                               val: (subj: [(local:(local,
						     cont:index:Subjind), 
						  nonlocal:Snonloc )],
					 spr:Spr,
					 comps:(hd: (local:(local,
							 cont:Objcont ),
							 nonlocal:Ononloc ),
						 tl:Comps) ) ),
			 cont: (top:Hand,
				h_cons:Hcons ),
			 keys: (key:(Key,
				     arg13_rel), %added to rule out
				   %non-transitives like possessive
				   %have and become.
				compkey:Ckey,
				ocompkey:Ockey ),
			 ctxt:Ctxt ),
		   nonlocal:Nonloc ) ),
    synsem:(@passive_synsem,
	  local: (@verb_participle_affix,
		  cat: (head:(verb_star,aux:minus,
					vform:pas,
					voice:passive,
                                        tam: (tense:Tense,
                                              mood:Mood ) ),
			 val: (subj: [(synsem,
					 local: ( cat: @nomp_cat_min,
						  conj:cnil,
						  cont:Objcont ),
					  nonlocal:Ononloc ) ],
                               spr:Spr,
                               comps: [(synsem, 
                                        local:(local,
                                                cat: ( head:prep,
                                                       val: (subj:[],
                                                             spr:o_list,
                                                             comps:o_list) ),
                                                 keys:key:(x_by_pass_rel_cm,
                                                      arg3:Subjind ) ),
                                         nonlocal:Snonloc,
                                         opt:plus )|Comps] ) ),
                   cont: (top:Hand,
                          index:(Ind,e:aspect:perf_star),
                          e_index:Ind,
			  h_cons:Hcons ),
		   keys: (key:Key,
			  compkey:Ckey,
			  ocompkey:Ockey),
		   ctxt:Ctxt),
	   nonlocal:Nonloc),
    c_cont:liszt:[]).

passive_rule ##
   Dtr
**>
  (lr:passive_verb,
   @passive_verb(Dtr))
morphs X becomes X.

verbal_gerund := (@lex_rule,
    dtr:( synsem:( @verb_synsem,
	        local:(  stemhead:vstem,
                         cat:( head:( verb,
                                     vform:prp,
				      aux:minus),
			       val:comps:Comps),
			 cont:( top:Hand,
				h_cons:Hcons),
			 keys:( key:event:e:tense:no_tense,
                                compkey:Ckey,
				ocompkey:Ockey),
			 ctxt:Ctxt),
		 nonlocal:Nonloc)),
    synsem:( @nonpro_onearg_synsem,
	    local:(  agr:Ind,
		     cat:( head:(gerund_star,
				 mod:[],
				  prd:minus),
			   val:( subj:[( local:cat:head:noun_star)],
				 spr:[( opt:minus)],
				 comps:Comps)),
		     cont:( top:Hand,
			    index:(Ind,
				    png:( png, pn:thirdsg_star,
						 gen:neut_star),
				     divisible:plus),
			    h_cons:Hcons),
		     keys:( key:( gerund_rel,Key,
				 handel:Hand,
				  inst:Ind),
			    compkey:Ckey,
			    ocompkey:Ockey),
		     ctxt:Ctxt),
	     nonlocal:(Nonloc, rel:[])),
    c_cont:liszt:[Key]).


vger_ing(Dtr) := (@verbal_gerund,
   dtr:(Dtr,synsem:local:cat:val:subj:[( local:cont:index:Subj,
                                         nonlocal:Snonloc)]),
    synsem:local:( cat:val:( subj:[( synsem,
				     local:( cat: @nomp_cat_acc, %nomp_cat_acc_min
					      conj:cnil,
					      cont:index:Subj))],
			     spr:[( local:( local,
					    cat:( head:( det, 
						     poss:plus),
						   val:( subj:[],
							 spr:o_list,
							 comps:o_list)),
					     keys:altkey:( arg:Ind,
                                                           arg3:Subj)),
                                     nonlocal:Snonloc)]),
		   cont:index:Ind)).

vger_ing_rule ##
    Dtr
**>
  (lr:vger_ing_lr,
   @vger_ing(Dtr))
morphs X becomes X.  


dative_shift_rule ##
    Dtr
**>
  (lr:dative_shift_lr,
   @dative_shift_lr(Dtr))
morphs X becomes X.

% This dative_shift_lexical rule is rather odd in that no connection
% at all is established between the two NPs on the comps of the 
% input and the and the NP + PP on the comps of the output of the
% lexical rule. A future version of the grammar should ensure the
% proper identification of the comps elements, e.g. to be able to
% share the nonlocal values correctly (otherwise amalgamation on the input
% of the lexical rule puts complements onto slash which aren't even part
% of the output any more! Currently we avoid this by disallowing slash
% amalgamation for the input byt specifying its nonlocal slash to be [].


dative_shift_lr(Dtr-sign) := (@lex_rule,
   dtr: (Dtr,synsem: (@ditrans_verb,
	    local: (cat: (head:Head,
			  val:subj:Subj),
		    cont: (top:Top,
			   index:Ind,
			   liszt:Liszt,
			   h_cons:Hcons ),
		    keys: (key:Key,
			   altkey:Altkey,
			   compkey:Ckey),
		    ctxt:Ctxt),
	    nonlocal:(slash:[],
		      rel:[],
		      que:[]))),
   synsem: (@to_trans_verb,
	    local: (cat: (head:Head,
			  val: (subj:Subj,
				comps: [(opt:minus),(opt:minus)])),
		    cont: (top:Top,
			   index:Ind,
			   liszt:Liszt,
			   h_cons:Hcons),
		    keys: (key:Key,
			   altkey:Altkey,
			   compkey:Ckey),
		    ctxt:Ctxt)),
   c_cont:liszt:[]).


%%% Derives an attributive adjective from a passive or prp verb.
%%% e.g. the hired programmer
attr_adj_verb_part ##
   Dtr
**>
  (lr:attr_adj_verb_part,
   @attr_verb_part_lr(Dtr))
morphs X becomes X.

attr_verb_part_lr(Dtr-sign) := (@lex_rule,
   dtr:(Dtr,
	synsem:(@passive_synsem, %@passive_or_unacc_synsem,
		local:(cat:(head:(verb,
				  vform:pas, %pas_or_psp, changed
				  %because we don't have unacc as a
				 %type -- we lose "moved" and "continued"
				  aux:minus),
			    val:(subj:Subj,
				 spr:Spr)),
		       cont:(top:Top,
			     index:Event,
			     h_cons:Hcons),
		       ctxt:Ctxt,
		       keys:(Keys,
			     compkey:no_rel)),
		nonlocal:Nonlocal)),
   synsem:(canonical_synsem,
	   local:(cat:(head:(adj_star,
			     mod:[local:(intersective_mod,
					 cat:(@n_or_v_cat,
					      head:(aux:minus,
						    tam:tense:real_tense)),
					 agr:Ind,
					 cont:index:Ind)],
			     prd:minus),
		       val:(subj:(Subj,
				  [local:cont:index:Ind]),
			    spr:Spr,
			    comps:[])),
		  cont:(top:Top,
			index:(Event,
			       e:(tense:no_tense,
				  aspect:perf_star)),
			h_cons:Hcons),
		  ctxt:Ctxt,
		  keys:Keys),
	   modified:periph:na,
	   nonlocal:Nonlocal),
   c_cont:liszt:[]). 

attr_verb_part_lr(Dtr-sign) := (@lex_rule,
   dtr:(Dtr,
	synsem:(@unacc_verb, %@passive_or_unacc_synsem,
		local:(cat:(head:(verb,
				  vform:psp, %pas_or_psp, changed
				  %because we don't have unacc as a
				 %type -- we lose "moved" and "continued"
				  aux:minus),
			    val:(subj:Subj,
				 spr:Spr)),
		       cont:(top:Top,
			     index:Event,
			     h_cons:Hcons),
		       ctxt:Ctxt,
		       keys:(Keys,
			     key:arg3_event_rel, %specific to
			     %unaccusative verbs
			     compkey:no_rel)),
		nonlocal:Nonlocal)),
   synsem:(canonical_synsem,
	   local:(cat:(head:(adj_star,
			     mod:[local:(intersective_mod,
					 cat:(@n_or_v_cat,
					      head:(aux:minus,
						    tam:tense:real_tense)),
					 agr:Ind,
					 cont:index:Ind)],
			     prd:minus),
		       val:(subj:(Subj,
				  [local:cont:index:Ind]),
			    spr:Spr,
			    comps:[])),
		  cont:(top:Top,
			index:(Event,
			       e:(tense:no_tense,
				  aspect:perf_star)),
			h_cons:Hcons),
		  ctxt:Ctxt,
		  keys:Keys),
	   modified:periph:na,
	   nonlocal:Nonlocal),
   c_cont:liszt:[]). 

%*******************************************************************
%             LEXICAL RULES FOR PARTITIVES
%*******************************************************************
%For constructions like "many sleep".  However, this grammar has no
%agreement constraints for these derived lexical entries, so it
%also licenses things like "many sleeps".  
part_nocomp_constr ##
   Dtr
**>
  (lr:part_nocomp_constr,
   @part_nocomp_constr(Dtr))
morphs X becomes X.

%part_ppof_agr := part_ppof_agr_constr.
%For constructions like "most of the programmers sleep(*s)"
%Agreement between verb and NP.
part_ppof_agr_constr ##
   Dtr
**>
  (lr:part_ppof_agr_constr,
   @part_ppof_agr_constr(Dtr))
morphs X becomes X.

%For constructions like "many of the programmers".  Agreement between
%verb and partitive noun, which gets them from lr input determiner.
part_ppof_noagr_constr ##
   Dtr
**>
   (lr:part_ppof_noagr_constr,
    @part_ppof_noagr_constr(Dtr))
morphs X becomes X.

%% Relevant macros
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%No agreement feature specifications.
part_nocomp_constr(Dtr-sign) := (@basic_part_constr,
   dtr:Dtr,
   synsem: @partitive_noun_nocomp_synsem).

%Takes a something with key value explicit_quant_agr_rel
%(will be particular quantifiers).and returns a noun.  
%%%Takes agreement feature divisible value from keycomp
%%%value of daughter, and the pn value from its own
%%%keycomp value.
%%%No index value requirements of the NP complement of "of",
%%%(see below), so the grammar allows "most of the dog",
%%%but not "most dog" -- but that seems appropriate for
%%%these partitives.
part_ppof_agr_constr(Dtr-sign) := (@basic_part_constr,
    dtr:(Dtr,
	 synsem:local:(keys:key:explicit_quant_agr_rel,
		      cat:val:keycomp:local:agr:divisible:Div)),
    synsem:(@partitive_noun_ppof_synsem,
	    local:(cat:val:keycomp:local:agr:png:pn:Pn,
		   agr:(png:pn:Pn,
			divisible:Div)))).

%%%Takes all agreement features from the determiner daughter.
%%%All varieties of determiner lexical entry have key:b(ound)
%%%v(ariable) specifications, some person/number type, which is
%%%equated with the index value of the N' on the spec list.
%%%However, since nothing like this is inherited from the
%%%input lexical entry, or enforced on the derived lexical entry,
%%%the grammar allows things like "many of the dog",
%%%but not "many dog".
part_ppof_noagr_constr(Dtr-sign) := (@basic_part_constr,
   dtr:(Dtr,
	synsem:local:(keys:key:explicit_quant_or_udef_noagr_rel,
		      agr:Agr)),
   synsem:(@partitive_noun_ppof_synsem,
	   local:agr:Agr)).

%More explicit syntactically: takes a partive determiner,
%returns a partitive noun (synsem values).  Don't quite
%get the semantics: key value of dtr is altkey value of
%mother, while key value of mother is on the liszt in c_cont.
%Where will this come from?  H_cons and divisible value
%inherited.  
basic_part_constr := (@lex_rule,
    dtr:synsem:(@part_det_synsem,
		local:(keys:key:Relation,
		       cont:h_cons:Hcons,
		       agr:divisible:Div),
		nonlocal:Nonlocal),
    synsem:(@partitive_noun_synsem,
	    local:(keys:(key:Key,
			 altkey:Relation),
		   cont:h_cons:Hcons,
		   agr:divisible:Div),
	    nonlocal:Nonlocal),
    c_cont:liszt:(hd:Key, %exclamation
		  tl:e_list)).

%************************************************************
% Changing partitive_num_phrase to a lexrule.

partitive_num ##
   Dtr
**>
  (lr:partitive_num,
   @partitive_num(Dtr))
morphs X becomes X.

partitive_num(Dtr) := (@lex_rule, %@phrasal,
   synsem:(local:(cat:(head:(partn,
			     mod:e_list,
			     poss:minus),
		       val:(subj:e_list,
			    spr:(hd:(synsem,
				     local:(local, %local_min
					    cat:val:(spr:o_list,
						     comps:o_list),
					    cont:top:Hand,
					    keys:key:(degree_rel,
						      darg:Darg)),
				     nonlocal:(que:e_list,
					       rel:e_list),
				     opt:plus),
				 tl:e_list),
			    comps:(hd:(synsem,
				       local:(local, %local_min
					      cat:(head:(prep,
							 prd:minus,
							 tam:tense:no_tense),
						   val:comps:o_list),
					      cont:(top:Nhand,
						    index:Index),
					      keys:key:(x_of_rel,
							arg3:Arg3)),
				       nonlocal:slash:e_list,
				       opt:plus),
				   tl:e_list))),
		  cont:nom_obj,
		  conj:cnil,
		  agr:Index,
		  keys:(key:(Key,
			     part_of_rel,
			     handel:Nhand,
			     inst:Index,
			     arg3:(Arg3,
				   non_expl_ind)),
			altkey:(Altkey,
				def_explicit_rel,
				bv:Index,
				restr:Phand,
				dim:Darg),
			message:e_list)),  
	   nonlocal:(Nonloc,
		     rel:e_list)),
   root:minus,
   dtr: (Dtr,
	     inflected:plus,
	     synsem:(@basic_norm_num_synsem,
		     local:(cat:val:(spr:o_list,
				     subj:e_list,
				     comps:e_list),
			    conj:cnil,
			    cont:index:Index,
			    keys:altkey:handel:Nhand,
			    agr:Index),
		     nonlocal:Nonloc)),
   c_cont:(top:Hand,
	   index:Index,
	   liszt:(hd:Key,
		  tl:(hd:Altkey,
		      tl:e_list)),  
	   h_cons:(hd:(qeq,
		       sc_arg:Phand,
		       outscpd:Nhand),
		   tl:e_list))).

%**************************************************************************		  
date_det_lr := (@lex_rule,
   dtr:synsem:(local:(stemhead:nstem,
	       cat:val:comps:[opt:plus],
	       cont:h_cons:Hclist,
	       keys:(key:Altkey,
		     compkey:Ckey,
		     ocompkey:Ockey),
	       ctxt:Ctxt),
	       nonlocal:Nonloc),
   synsem:(@nomod_synsem,
	  local:(cat:(head:det,
		      val:(subj:[],
			   spr:[],
			   comps:[],
			   spec:[local:(cont:index:Ind,
					keys:key:handel:Ntop)])),
		 cont:(index:Ind,
		       h_cons:[(qeq,
				sc_arg:Rhand,
				outscpd:Ntop),
			       (qeq,
				   sc_arg:Mhand,
				   outscpd:Mtop)|Hclist]),
		 keys:(key:(Key,
			    def_rel,
			    bv:Ind,
			    restr:Rhand),
		       altkey:(Altkey,
			       handel:Mtop,
			       inst:Spind),
		       compkey:Ckey,
		       ocompkey:Ockey),
		 ctxt:Ctxt),
	   nonlocal:(Nonloc,
		     que:[], %added for residues
		     rel:[]), %added for residues
	   modified:hasmod),
   c_cont:liszt:[Key,
		 (x_of_rel,
		  handel:Ntop,
		  event:e:tense:no_tense,
		  arg:Ind,
		  arg3:Spind),
		 (def_rel,
		     bv:Spind,
		     restr:Mhand)]).

month_det_lr(Dtr) := (@date_det_lr,
    dtr:(Dtr,
	 synsem:local:keys:key:mofy_rel),
    synsem:local:cat:val:spec:[local:keys:key:dofm_rel]).

monthdet ##
   Dtr
**>
   (lr:monthdet,
    @month_det_lr(Dtr))
morphs
    X becomes X.       

mofy_dofm_yofc_lr(Dtr) := (@lex_rule,
   %synsem: @dom_ord_yofc_synsem, specifications given below, liszt
			      %elements reordered
   synsem: @mofy_dofm_yofc_synsem,
   dtr:(Dtr,
	synsem: @dom_ord_synsem)).

mofy_dofm_yofc_synsem := (@xref_synsem, @two_arg, @nonpro_nomod_synsem,
				%@noun_two_arg_nomod_synsem,
	   
        local:(cat:(head:(noun,
			  prd:plus),
		    val:(spr:[(expressed_synsem,
			       local:(local,
				      cat:(head:det,
					   val:(subj:[],
						spr:o_list,
						comps:o_list)),
				      keys:(key:abstr_def_rel, %(abstr_def_rel, quant_or_wh_rel),
					    altkey:mofy_rel)),
			       opt:minus)],
			comps:[(expressed_synsem,
				 local:(cat: @nomp_cat_acc,
				%nomp_cat_acc_min,
					conj:cnil,
					keys:(key:yofc_rel, %(abstr_named_rel, yofc_rel),
					      message:[]),
					cont:(top:Top,
					      index:Cindex)),
				 nonlocal:slash:e_list,
				 opt:minus)])),
	       agr:Index,
	       cont:(top:Top,	%(Top,Hand1),
		     index:(Index,
			    ref_ind,
			    divisible:minus_star),
		     liszt:[(unspec_rel,
			     handel:Hand,
			     hinst:Index,
			     nhinst:Cindex),
			    (Key,
				dofm_rel, % (dofm_rel, basic_nom_rel),
				handel:Top, %Hand1,
				inst:(Index,
				      png:(png,
					   pn:thirdsg_star,
					   gen:neut_star)))],
		     h_cons:[]),
	       keys:key:(Key,
			 handel:Hand),
	       stemhead:countnstem)).

dofm_yofc ##
   Dtr
**>
   (lr:dofm_yofc,
   @mofy_dofm_yofc_lr(Dtr))
morphs
   X becomes X.


%*******************************************************************
%             LEXICAL RULES FOR NOUNS
%*******************************************************************

sing_noun_infl_rule ##
   Dtr
**>
  (lr:lex_rule_infl_affixed,
    needs_affix:minus,
    synsem:local: @sing_noun,
    @lex_rule_infl_affixed_macro(Dtr))
morphs
     X becomes X.

%%%If a stem has local feature values matching the description
%%%@mass_noun, then it is licenced (with no affixes) as a noun.
mass_noun_infl_rule ##
   Dtr
**>
  (lr:lex_rule_infl_affixed,
      needs_affix:minus,
      synsem:local: @mass_noun,
      @lex_rule_infl_affixed_macro(Dtr))
morphs
     X becomes X.

mass_count_noun_infl_rule ##
   Dtr
**>
  (lr:lex_rule_infl_affixed,
      needs_affix:minus,
      synsem:local: @mass_count_noun,
      @lex_rule_infl_affixed_macro(Dtr))
morphs
     X becomes X.
    

plur_noun_infl_rule ##
   Dtr
**>
  (lr:lex_rule_infl_affixed,
      needs_affix:plus,
      synsem:local: @plur_noun,
      @lex_rule_infl_affixed_macro(Dtr))
morphs
%suffix (!s !ss) (!ss !ssses) (ss sses) (!ty !ties) (ch ches) (sh shes) (x xes) (z zes)
     X      becomes  Y when irregplur(X,Y), 
    (X,S,s) becomes (X,S,ssess) when letter_set_s(S),
    (X,ss)  becomes (X,sses),  
    (X,T,y) becomes (X,T,ies) when letter_set_t(T), 
    (X,ch)  becomes (X,ches),
    (X,sh)  becomes (X,shes),
    (X,x)   becomes (X,xes),
    (X,z)   becomes (X,zes),    
    (X,C)   becomes (X,C,s) when letter_set_s(C).     

%**********************RELEVANT MACROS******************************
%% nominal inflections

sing_noun :=  (local,
   stemhead:countnstem,   %countnstem %was nhead, now nstem
   cat:val:spr:[local:agr:(png:pn:thirdsg, %3sg
                           divisible:minus)],
   cont:index:(png:(png,pn:thirdsg_star,  %%3sg*
			gen:neut_star),
 	       divisible:minus_star)).

%%%For nouns like time.  Specifies that the value of the person/number
%%%agreement feature for its specifier is third singular, and the value
%%%of its divisible feature is plus. Additionally, its own index feature
%%%includes the values third singular and neuter.

mass_noun := (local,
    stemhead:massnstem,
    cat:val:spr:(hd:local:agr:(png:pn:thirdsg,
			       divisible:plus),
                 tl:e_list),
    cont:index:(png:(png,
		     pn:thirdsg_star,
		     gen:neut_star))).

mass_count_noun := (local,
   stemhead:masscountnstem,
   cat:val:spr:[local:agr:png:pn:thirdsg],
   cont:index:png:(png,
		   pn:thirdsg_star,
		   gen:neut_star)).

plur_noun := (local,
    stemhead:count_or_masscount_nstem,
    cat:val:spr:[local:agr:(png:pn:thirdpl, %3pl
			    divisible:plus)],
    cont:index:(png:(png,
		     pn:thirdpl_star), %3pl*
		divisible:plus_star)).
 		    
%**************************************************************************
%   Rules for adjectives
%*************************************************************************
pos_adj := (local,
	       stemhead:astem,
	       cat:val:spr:[local:(local,
				   keys:key:very_deg_rel)]).

pos_adj_infl_rule ##
   Dtr
**>
   (lr:lex_rule_infl_affixed,
    needs_affix:minus,
    synsem:local: @pos_adj,
    @lex_rule_infl_affixed_macro(Dtr))
morphs
   X  becomes  X.

letter_set_s([a]).
letter_set_s([b]).
letter_set_s([c]).
letter_set_s([d]).
letter_set_s([e]).
letter_set_s([f]).
letter_set_s([g]).
letter_set_s([h]).
letter_set_s([i]).
letter_set_s([j]).
letter_set_s([k]).
letter_set_s([l]).
letter_set_s([m]).
letter_set_s([n]).
letter_set_s([o]).
letter_set_s([p]).
letter_set_s([q]).
letter_set_s([r]).
letter_set_s([t]).
letter_set_s([u]).
letter_set_s([v]).
letter_set_s([w]).
letter_set_s([x]).
letter_set_s([y]).
letter_set_s([z]).


letter_set_t([b]).
letter_set_t([c]).
letter_set_t([d]).
letter_set_t([f]).
letter_set_t([g]).
letter_set_t([h]).
letter_set_t([j]).
letter_set_t([k]).
letter_set_t([l]).
letter_set_t([m]).
letter_set_t([n]).
letter_set_t([o]).
letter_set_t([p]).
letter_set_t([q]).
letter_set_t([r]).
letter_set_t([s]).
letter_set_t([t]).
letter_set_t([v]).
letter_set_t([w]).
letter_set_t([x]).
letter_set_t([z]).

letter_set_v([a]).
letter_set_v([e]).
letter_set_v([i]).
letter_set_v([o]).
letter_set_v([u]).

letter_set_c([b]).
letter_set_c([d]).
letter_set_c([f]).
letter_set_c([g]).
letter_set_c([l]).
letter_set_c([m]).
letter_set_c([n]).
letter_set_c([p]).
letter_set_c([r]).
letter_set_c([d]).
letter_set_c([t]).
letter_set_c([z]).


%% irreg(bse,thirdsg,past,perf)
irregpres([d,o],[d,o,e,s]).
irregpres([g,o],[g,o,e,s]).
irregpres([h,a,v,e],[h,a,s]).


irregpast([d,o],[d,i,d],[d,o,n,e]).
irregpast([g,o],[w,e,n,t],[g,o,n,e]).
irregpast([r,u,n],[r,a,n],[r,u,n]).
irregpast([s,l,e,e,p],[s,l,e,p,t],[s,l,e,p,t]).
irregpast([b,e,c,o,m,e],[b,e,c,a,m,e],[b,e,c,o,m,e]).
irregpast([s,a,y],[s,a,i,d],[s,a,i,d]).
irregpast([l,a,y],[l,a,i,d],[l,a,i,d]).
irregpast([b,e,t],[b,e,t],[b,e,t]).
irregpast([s,h,o,w],[s,h,o,w,e,d],[s,h,o,w,n]).
irregpast([v,i,s,i,t],[v,i,s,i,t,e,d],[v,i,s,i,t,e,d]).
irregpast([h,a,v,e],[h,a,d],[h,a,d]).
irregpast([m,a,k,e],[m,a,d,e],[m,a,d,e]).
irregpast([k,n,o,w],[k,n,e,w],[k,n,o,w,n]).
irregpast([s,e,e],[s,a,w],[s,e,e,n]).
irregpast([g,e,t],[g,o,t],[g,o,t,t,e,n]).
irregpast([l,e,a,v,e],[l,e,f,t],[l,e,f,t]).
irregpast([f,i,n,d],[f,o,u,n,d],[f,o,u,n,d]).
irregpast([t,h,i,n,k],[t,h,o,u,g,h,t],[t,h,o,u,g,h,t]).
irregpast([w,i,n],[w,o,n],[w,o,n]).
irregpast([e,a,t],[a,t,e],[e,a,t,e,n]).
irregpast([r,u,n],[r,a,n],[r,a,n]).
irregpast([a,p,p,e,a,r],[a,p,p,e,a,r,e,d],[a,p,p,e,a,r,e,d]).
irregpast([d,e,l,i,v,e,r],[d,e,l,i,v,e,r,e,d],[d,e,l,i,v,e,r,e,d]).
irregpast([o,f,f,e,r],[o,f,f,e,r,e,d],[o,f,f,e,r,e,d]).
irregpast([s,t,a,n,d],[s,t,o,o,d],[s,t,o,o,d]).
irregpast([e,m,p,l,o,y],[e,m,p,l,o,y,e,d],[e,m,p,l,o,y,e,d]).
irregpast([w,o,n,d,e,r],[w,o,n,d,e,r,e,d],[w,o,n,d,e,r,e,d]).
irregpast([s,a,y],[s,a,i,d],[s,a,i,d]).
irregpast([p,a,y],[p,a,i,d],[p,a,i,d]).
irregpast([c,o,m,e],[c,a,m,e],[c,a,m,e]).
irregpast([w,i,n],[w,o,n],[w,o,n]).
irregpast([r,e,p,a,y],[r,e,p,a,i,d],[r,e,p,a,i,d]).
irregpast([s,e,l,l],[s,o,l,d],[s,o,l,d]).
irregpast([a,r,i,s,e],[a,r,o,s,e],[a,r,i,s,e,n]).

irregprp([v,i,s,i,t],[v,i,s,i,t,i,n,g]).
irregprp([d,e,l,i,v,e,r],[d,e,l,i,v,e,r,i,n,g]).
irregprp([o,f,f,e,r],[o,f,f,e,r,i,n,g]).
irregprp([h,a,p,p,e,n],[h,a,p,p,e,n,i,n,g]).
irregprp([o,p,e,n],[o,p,e,n,i,n,g]).

irregplur([w,o,m,a,n],[w,o,m,e,n]).
irregplur([m,a,n],[m,e,n]).
irregplur([p,e,r,s,o,n],[p,e,o,p,l,e]).
irregplur([y,e,n],[y,e,n]).



