%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  $RCSfile: principles.pl,v $
%% $Revision: 1.9 $
%%     $Date: 2004/01/02 02:50:58 $
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%   Milca English Resource Grammar (MERGE) for the Trale system
%%
%%   Authors: Kordula De Kuthy, Vanessa Metcalf, Detmar Meurers  
%%            Department of Linguistics, The Ohio State University 
%%            http://ling.osu.edu/~dm/merge/
%%
%%            Based on the English Resource Grammar (ERG)
%%            Version of Jan 16, 2002, developed at CSLI, Stanford
%%            University by Dan Flickinger in collaboration with 
%%            colleagues on the German Verbmobil project and with 
%%            member institutions of the the LinGO consortium, cf.
%%            http://lingo.stanford.edu/
%%
%%   Principles and fundamental type constraints
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile if/2.
:- multifile fun/1.
:- multifile '*>'/2.

:- discontiguous if/2.
:- discontiguous fun/1.
:- discontiguous '*>'/2.

%-------------------------
% nonlocal amalgamation constraint
%------------------------

%%% corresponds to the lingo types
%%  basic_zero_arg, basic_one_arg, basic_two_arg,
%%  basic_three_arg, basic_four_arg

%% We need this principle not only on non_derived words, but also on
%% derived word, because of lexical rules like dative shift. In these
%% lexical rules there is no syntactic connection between the input
%% and the output word with the effect that the slashes of the output
%% word cannot be collected if the constraint only applies to
%% non_derived words.

(word,
 synsem:amalgamating_synsem)
*>
(synsem:(local:arg_s: collect_slash_rel_que(Slash,Rel,Que),
         nonlocal:(slash: Slash,
		   rel: Rel,
		   que: Que
		  ))).

% collect_slash_rel_que(-Slash,-Rel,-Que,+Arg-S)
fun collect_slash_rel_que(+,+,+,-).
collect_slash_rel_que(Slash,Rel,Que,ArgS) if 
   when( ArgS = (e_list;ne_list),
	 undelayed_collect_slash_rel_que(Slash,Rel,Que,ArgS) ).

%undelayed_collect_slashes(+list-of-synsem,-list-of-local)
undelayed_collect_slash_rel_que([],[],[],[]) if true.
undelayed_collect_slash_rel_que(Ss,Rs,Qs,[(nonlocal: (slash:S,
					              rel:R,
				                      que:Q))|As])
 if collect_slash_rel_que(RestSs,RestRs,RestQs,As),
    append(S,RestSs,Ss),
    append(R,RestRs,Rs),
    append(Q,RestQs,Qs).

   
 % *****************************
 %   list manipulation utilities
 % *****************************

% append(+,+,-)
% This append assumes that the first or the third argument
% are known to be non_empty or empty lists. 
%

fun append(+,+,-).
append(X,Y,Z) if 
   when( (X=(e_list;ne_list);
	  Z=(e_list;ne_list))
       , undelayed_append(X,Y,Z)
       ).

undelayed_append([],L,L) if true.
undelayed_append([H|T1],L,[H|T2]) if append(T1,L,T2).


fun valence_append(+,+,+,-).
valence_append(Subj,Spr,Comps,ArgSt) if
   append(Spr,Comps,Result),
   append(Subj,Result,ArgSt).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Other functional relations
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%In ERG, the type *prolist* is like this:

%%%             *prolist*
%%%	         /\
%%%		/  \
%%%	       /    \
%%%	 *pronull*  *procons*
%%%	               [(pro_ss,nonlocal:slash:e_list)]
%%%We define a functional relation prolist to encode this specification.

fun prolist(-).
prolist(X) if
   when( (X=(e_list;ne_list) ),
         (X=([];[(pro_ss,nonlocal:slash:e_list)])) ).


fun unexplist(-).
unexplist(X) if
   when( (X=(e_list;ne_list) ),
	 (X=([];[unexpressed])) ).


%----------------------------------------------------------------------
% Some fundamental constraints on types:

% *substlist* is used in the adv_addition lexical rule, to prevent spurious
% re-application of the rule to its own output by requiring the input to
% be a (possibly empty) list of substantive synsems.
%*substlist* :< *list*.

fun substlist(-).

substlist(X) if
    when( (X=(e_list;ne_list) ),
           und_substlist(X)).

und_substlist([]) if true.
und_substlist([(local:cat:head:subst)|T]) if substlist(T).




ind_or_mod_subj_tam *> (mood:ind_or_mod_subj,
			   tense:real_tense).

past_or_subj_tam *> aspect:no_aspect_star.

subjnct_tam *> mood:subjunctive.

past_tam *> (tense:past_star,
		mood:indicative_star).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


nomod_local *> cat:head:mod:e_list.

phrase *>
  ( synsem:( canonical_synsem,
	     local:cont:( top:Hand,		
			  index:Index,
                          e_index:Event)),
    c_cont:( top:Hand,
	     index:Index,
             e_index:Event)).

phrase *> (synsem:local:arg_s:[]).


non_derived_word *>
  ( synsem:local:cont:(top:Hand,
			topkey:handel:Hand),
    posscl:minus,
    root:minus).

non_canonical *>
  (local:cont:index:non_expl).

gap *>
   (local:Local,
    nonlocal:(rel:e_list,
	      que:e_list,
	      slash:(hd:Local,
		     tl:e_list))).

unexpressed *>
   (nonlocal: ( slash:e_list,
		rel:e_list,
		que:e_list)).

pro_ss *>
   (local:cat:head:(noun,
		    case:acc),
       
    nonlocal:(rel:e_list,
	      que:e_list)).

%% Constraints for strict_head:bool

glbtype1 *> strict_head:minus.
glbtype9 *> strict_head:minus.


%%constraint for list type
o_nelist *> (hd:(unexpressed,
                 opt:plus),
             tl:o_list).

one_list *> tl:e_list.


%%constraints for stuff in KEYS

it_ind *> (png: (pn:thirdsg_star,
		 gen:no_gend_it)).

there_ind *> (png:gen:no_gend_there).

non_expl_ind *> (png:gen:real_gender).


basic_poss_rel *> (event:e:tense:no_tense).

%-----------------------------------
% DPF 11-Feb-01 - For now, make all nom-objs have INDEX and E-INDEX the same, 
% to keep coordination working now that we want to treat coordination of 
% predicative phrases via their E-INDEX.  Probably will have to adjust this
% once we get more interesting temporal semantics for some nouns.

nom_obj *>
  ( index:Ind,
    e_index:Ind).


% -------------------------------------------------
% constraints originally expressed in the signature
% expressed here since they are homomorphism violations

arg14_rel *> arg:non_expl_ind.

v_event_arg3_rel *> arg3:non_expl_ind.
superl_rel *> arg3:event_or_index.
comp_rel *> arg3:event_or_index.
meas_adj_rel *> arg3:ref_ind.
prep_rel *> arg3:non_expl.
dofm_rel *> arg3:non_expl_ind.

basic_hcomp_nom_rel *> arg4:handle.

abstr_adj_rel *> arg:non_expl.
integer_rel *> arg:individual.

recip_pro_rel *> inst:ref_ind.
gerund_rel *> inst:ref_ind.
pron_rel *> inst:ref_ind.
generic_nom_rel *> inst:ref_ind.
nom_rel *> inst:non_expl_ind.
generic_nonpro_rel *> inst:ref_ind.

%%%Added so that relative pronoun "that" not recognized as a filler to a
%%%to a temporal adjunct gap, for example (spec. as sort:time).
non_temp_nom_rel *> inst:sort:entity.
%%%Ditto for "where".
place_rel *> inst:sort:entity.  %was abstr_place_rel
temp_abstr_rel *> inst:sort:time.

prpstn_to_prop_rel *> prop:non_expl_ind.

%%%%% Mobile
%%% This is a first approximation; may not be exhaustive.

partn_acc *> (case:acc,
		 mobile:minus).

det *> mobile:minus.

verb *> mobile:minus.

comp_star *> mobile:minus.


