%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  $RCSfile: ps_mapping.pl,v $
%% $Revision: 1.1 $
%%     $Date: 2003/05/25 02:15:14 $
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%   Milca English Resource Grammar (MERGE) for the Trale system
%%
%%   Authors: Kordula De Kuthy, Vanessa Metcalf, Detmar Meurers  
%%            Department of Linguistics, The Ohio State University 
%%            http://ling.osu.edu/~dm/merge/
%%
%%            Based on the English Resource Grammar (ERG)
%%            Version of Jan 16, 2002, developed at CSLI, Stanford
%%            University by Dan Flickinger in collaboration with 
%%            colleagues on the German Verbmobil project and with 
%%            member institutions of the the LinGO consortium, cf.
%%            http://lingo.stanford.edu/
%%
%%   Definitions for mapping extra-logical like the string and the
%%   edge structure of the parser into the feature structure for
%%   ease of reference by the user. Also specifies the key:id of
%%   lexical elements.
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% This additionally specifies the "phon" and the 
% "synsem:local:keys:key:id" path of lexical entries.

% This file only maps the tree_extension syntax to the ordinary
% syntax (i.e. it does not introduce the dtrs and phon attribute).

:- multifile term_expansion/2.
:- discontiguous term_expansion/2.

% ------------------------------------------------------
% new operators

:-op(1150,xfx,~~>).  % lexical entries
:-op(1150,xfx,~~~>). % lexical entries without key:id
:-op(1150,xfx,~~~~>). % non-amalgamating lexical entries
:-op(1150,fx,trace). % empty element
:-op(1175,xfx,##).   % used for rule and lex_rule

% ------------------------------------------------------
% translating new lexical entry syntax

term_expansion((Phon ~~> Desc),
	       (Phon ---> (PFeat:[(a_ Phon)],
                           synsem:(amalgamating_synsem,
				   local:keys:key:id:(a_ Phon)), 
                           Desc))) :-
      phon_feat_(PFeat).

%-------------------------------------------------------
% translating new lexical entry syntax for lexical entries without
% key:id

term_expansion((Phon ~~~> Desc),
	       (Phon ---> (PFeat:[(a_ Phon)],
			   synsem:amalgamating_synsem,   
			      Desc))) :-
      phon_feat_(PFeat).

% ------------------------------------------------------
% translating new lexical entry syntax for non-amalgamating lexical
% entries

term_expansion((Phon ~~~~> Desc),
	       (Phon ---> (PFeat:[(a_ Phon)],
                           synsem:(non_amalgamating_synsem,
				   local:keys:key:id:(a_ Phon)), 
                           Desc))) :-
      phon_feat_(PFeat).

% ------------------------------------------------------
% translating empty elements

term_expansion((trace Desc),
	       (empty (Desc,
		   PFeat:[(a_ 'EMPTY')],
                           synsem:local:keys:key:id:(a_ 'EMPTY'))))
  :-  phon_feat_(PFeat).

% ------------------------------------------------------
% translating new lexical rule syntax

% matches both of the following: 
% ##(Name,morphs(if(**>(DescIn,DescOut),Cond),Morphs))
% ##(Name,morphs(**>(DescIn,DescOut),Morphs))

term_expansion(##(Name,morphs(Rule0,Morphs0)),_,lex_rule(Name,morphs(Rule,Morphs)),[]) :-
   phon_feat_(PFeat),
   DescOut = (DescOut0, PFeat:[(a_ Phon)],synsem:local:keys:key:id:(a_ Id)),
   DescIn = (DescIn0,                     synsem:local:keys:key:id:(a_ Id)),
   (  functor(Rule0,if,_)
   -> Rule0 = (DescIn0 **> DescOut0 if Cond),
      Rule  = (DescIn **> DescOut  if Cond)
   ;  Rule0 = (DescIn0 **> DescOut0),
      Rule  = (DescIn **> DescOut)
   ),
   phonify_morphs(Morphs0,Morphs,Phon).

phonify_morphs((Morph,Morphs),(PMorph,PMorphs),Phon) :- !,
    phonify_morphs(Morph,PMorph,Phon),
    phonify_morphs(Morphs,PMorphs,Phon).

phonify_morphs((PattIn becomes PattOut),X,Y) :- !,
   phonify_morphs((PattIn becomes PattOut when true),X,Y).

phonify_morphs((PattIn becomes PattOut when Cond),
   (PattIn becomes PattOut 
           when (Cond,when(ground(PattOut),(morph_pattern(PattOut,Chars),
                    make_char_list(Codes,Chars),
                    name(Phon,Codes))))),
           Phon).

% ------------------------------------------------------
% translating new phrase structure rule syntax

term_expansion((RuleName ## Moth ===> Dtrs),
	       (RuleName rule Moth ===> Dtrs)).
