%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  $RCSfile: ps_rules.pl,v $
%% $Revision: 1.7 $
%%     $Date: 2004/01/02 03:20:42 $
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%   Milca English Resource Grammar (MERGE) for the Trale system
%%
%%   Authors: Kordula De Kuthy, Vanessa Metcalf, Detmar Meurers  
%%            Department of Linguistics, The Ohio State University 
%%            http://ling.osu.edu/~dm/merge/
%%
%%            Based on the English Resource Grammar (ERG)
%%            Version of Jan 16, 2002, developed at CSLI, Stanford
%%            University by Dan Flickinger in collaboration with 
%%            colleagues on the German Verbmobil project and with 
%%            member institutions of the the LinGO consortium, cf.
%%            http://lingo.stanford.edu/
%%
%%   Phrase structure rules (cf. syntax.pl for the macro definitions)
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile '##'/2. 


subjh ## @head_subj_phrase(HeadDtr,NonheadDtr) ===>
cat> NonheadDtr,
cat> HeadDtr.


hcomp ## @head_comp_phrase(HeadDtr,NonheadDtr) ===>
cat> HeadDtr,
cat> NonheadDtr.


noptcomp ## @noun_opt_comp_phrase(Dtr) ===>
cat> Dtr.


hmarkev ## @head_marker_phrase_event(HeadDtr,NonheadDtr) ===>
cat> HeadDtr,
cat> NonheadDtr.


hmarknom ## @head_marker_phrase_nom(HeadDtr,NonheadDtr) ===>
cat> HeadDtr,
cat> NonheadDtr.


extracomp  ## @extracted_comp_phrase(Dtr) ===>
cat> Dtr.


extrasubj_f  ## @extracted_subj_phrase_fin(Dtr) ===>
cat> Dtr.


extrasubj_i  ## @extracted_subj_phrase_inf(Dtr) ===>
cat> Dtr.


hspec ## @head_spec_phrase(HeadDtr,NonheadDtr) ===>
cat> NonheadDtr,
cat> HeadDtr.

adjh_s ## @adj_head_scop_phrase(NonheadDtr,HeadDtr) ===>
cat> NonheadDtr,
cat> HeadDtr.


hadj_s ## @head_adj_scop_phrase(HeadDtr,NonheadDtr)
 ===>
cat> HeadDtr,
cat> NonheadDtr.


adjn_i ## @adj_n_int_phrase(HeadDtr,NonheadDtr) ===>
cat> NonheadDtr,
cat> HeadDtr.


adjh_i ## @adj_h_int_phrase(HeadDtr,NonheadDtr) ===>
cat> NonheadDtr,
cat> HeadDtr.


nadj_rc ## @n_adj_relcl_phrase(HeadDtr,NonheadDtr) ===>
cat> HeadDtr,
cat> NonheadDtr.


nadj_rr_nt ## @n_adj_redrel_nontemp(HeadDtr,NonheadDtr) ===>
cat> HeadDtr,
cat> NonheadDtr.


nadj_rr_t ## 
     @n_adj_redrel_temp(HeadDtr,NonheadDtr) ===>
cat> HeadDtr,
cat> NonheadDtr.


hadj_i_s ## @hadj_i_h(HeadDtr,NonheadDtr) ===>
cat> HeadDtr,
cat> (NonheadDtr,synsem:nonlocal:slash:one_list).


hadj_i_uns ## @hadj_i_h(HeadDtr,NonheadDtr) ===>
cat> (HeadDtr,synsem:local:keys:key:nonaux_event_rel),
cat> (NonheadDtr,synsem:nonlocal:slash:e_list).  % 0-dlist


hadj_i_uns_aux ## @hadj_i_h(HeadDtr,NonheadDtr) ===>
cat> (HeadDtr,synsem:local:keys:key:aux_event_rel),
cat> (NonheadDtr,synsem:nonlocal:slash:e_list). % 0-dlist


extradj_i_subj  ## @extracted_adj_int_phrase(Dtr) ===>
cat> (Dtr,
      synsem:local:(cat:val:subj:[(synsem, %rules out unexpressed_synsem
				   nonlocal:slash:[])],
		    keys:key:nonaux_event_rel)).


extradj_i_aux_subj ## @extracted_adj_int_phrase(Dtr) ===>
cat> (Dtr,synsem:local:( cat:val:subj:[( synsem,
                                            nonlocal:slash:[])],
                            keys:key:aux_event_rel)).


extradj_i_aux_nosubj ## @extracted_adj_int_phrase(Dtr) ===>
cat> (Dtr,synsem:local:( cat:( head:inv:plus_star,
                                  val:subj:[anti_synsem]),
                            keys:key:aux_event_rel)).


extradj_t ## @extracted_adj_temp_phrase(Dtr) ===>
cat> (Dtr,synsem:local:keys:key:nonaux_event_rel).


extradj_t_aux ## @extracted_adj_temp_phrase(Dtr) ===>
cat> (Dtr,synsem:local:keys:key:aux_event_rel).


fin_non_wh_rel ## @fin_non_wh_rel_cl(Dtr) ===>
cat> Dtr.


inf_non_wh_rel ## @inf_non_wh_rel_cl(Dtr) ===>
cat> Dtr.


% For nouns like "time" which can occur without a specifier.  Mass
% nouns, plurals, etc..
bare_np ## @bare_np_phrase(Dtr) ===>
cat> Dtr.


proper_np ## @proper_np_phrase(Dtr) ===> 
cat> Dtr.


bare_vger ## @bare_vger_phrase(Hdtr)  ===>
cat> Hdtr.   


np_n_cmpnd ## @np_n_cmpnd_phr(HeadDtr,NonheadDtr)  ===>
cat>  NonheadDtr,
cat>  HeadDtr.


np_name_cmpnd ## @np_name_cmpnd_phr(HeadDtr,NonheadDtr) ===>
cat>  NonheadDtr,
cat>  HeadDtr.


noun_n_cmpnd ## @noun_n_cmpnd_phr(HeadDtr,NonheadDtr) ===>
cat>  NonheadDtr,
cat>  HeadDtr.


%%%for things like "everyone is here"
appos ## @appos_phr(Hdtr,NHdtr) ===>
cat> Hdtr,
cat> NHdtr.

temp_nwh ## @temp_mod_nonwh_phrase(Dtr) ===>
cat> Dtr.


fillhead_non_wh ## @filler_head_rule_non_wh(NHdtr,Hdtr) ===>
cat> NHdtr,
cat> Hdtr.


fillhead_wh_r ## @filler_head_rule_wh_root(NHdtr,Hdtr) ===>
cat> NHdtr,
cat> Hdtr.


fillhead_wh_subj_r ## @filler_head_rule_wh_subj(NHdtr,Hdtr) ===>
cat> NHdtr,
cat> Hdtr.


fillhead_wh_nr_f ## @filler_head_rule_wh_nr_fin(NHdtr,Hdtr) ===>
cat> NHdtr,
cat> Hdtr.


fillhead_wh_nr_i ## @filler_head_rule_wh_nr_inf(NHdtr,Hdtr) ===>
cat> NHdtr,
cat> Hdtr.  


fillhead_rel ## @filler_head_rule_rel(LDtr,RDtr) ===>
cat> LDtr,
cat> RDtr.


freerel_inf ## @free_rel_inf_phrase(HeadDtr,NonheadDtr) ===>
cat> HeadDtr,
cat> NonheadDtr.

freerel_fin ## @free_rel_fin_phrase(HeadDtr,NonheadDtr) ===>
cat> HeadDtr,
cat> NonheadDtr.

top_coord_e ## @top_coord_event_rule(LConjDtr,RConjDtr) ===>
cat> LConjDtr,
cat> RConjDtr.


mid_coord_e ## @mid_coord_event_rule(LConjDtr,RConjDtr) ===>
cat> LConjDtr,
cat> RConjDtr.


top_coord_nom ## @top_coord_nom_rule(LConjDtr,RConjDtr) ===>
cat> LConjDtr,
cat> RConjDtr.


mid_coord_nom ## @mid_coord_nom_rule(LConjDtr,RConjDtr) ===>
cat> LConjDtr,
cat> RConjDtr.


imper ## @imp(Dtr) ===>
cat> Dtr.  


yesno ##  @yesno_phrase(Dtr) ===>
cat> Dtr.  


measure_np ## @measure_np_phrase(Dtr1,Dtr2) ===>
cat> Dtr1,
cat> Dtr2.

np_s ## @np_cp_phrase(Dtr) ===>
cat> Dtr.




