%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  $RCSfile: syntax.pl,v $
%% $Revision: 1.58 $
%%     $Date: 2004/01/02 03:18:56 $
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%   Milca English Resource Grammar (MERGE) for the Trale system
%%
%%   Authors: Kordula De Kuthy, Vanessa Metcalf, Detmar Meurers  
%%            Department of Linguistics, The Ohio State University 
%%            http://ling.osu.edu/~dm/merge/
%%
%%            Based on the English Resource Grammar (ERG)
%%            Version of Jan 16, 2002, developed at CSLI, Stanford
%%            University by Dan Flickinger in collaboration with 
%%            colleagues on the German Verbmobil project and with 
%%            member institutions of the the LinGO consortium, cf.
%%            http://lingo.stanford.edu/
%%
%%   Macros for phrasal specification and constraints on phrases
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile '*>'/2.
:- multifile ':='/2.
:- multifile fun/1.
:- multifile if/2.

:- discontiguous '*>'/2.
:- discontiguous ':='/2.
:- discontiguous ':='/2.
:- discontiguous fun/1.
:- discontiguous if/2.

%% Headed phrases must obey the Head Feature Principle and the Revised Marking
%% Principle.  They do not all obey the NLFP with respect to QUE, but it
%% appears that all CLAUSE phrases account for QUE on mother and non-head-dtr.
%% Hence moved the QUE coreference to NON-CLAUSE.  Headed phrases also identify
%% the value of AGR on mother and head daughter, unlike e.g. the coordination 
%% schemata which identify HEAD but not AGR.  

headed_phrase *>
   (root:minus,
    synsem:local:( cat:( head:Head,
                         hc_lex:Hclex),
                   agr:Agr,
                  conj:Conj,
                  keys:key:Key ),
    head_dtr:synsem:local:(cat: (head:Head,
                                 hc_lex:Hclex ),
                           agr:Agr,
                          conj:Conj,
                          keys:key:Key ) ).

non_headed_phrase *> root:minus.

phrasal := (phrase,
    synsem: @phr_synsem).


head_nexus_rel_phrase := (headed_phrase,
    synsem:nonlocal:rel:Rel,
    head_dtr:synsem:nonlocal:rel:Rel).

head_nexus_que_phrase := (headed_phrase,
    synsem:nonlocal:que:Que,
    head_dtr:synsem:nonlocal:que:Que).

head_nexus_phrase := (@head_nexus_rel_phrase,@head_nexus_que_phrase).

head_valence_phrase := (@head_nexus_phrase,
    synsem:nonlocal:slash:Slash,
    head_dtr:synsem:nonlocal:slash:Slash).



%% constraint for basic_unary_phrase is now also on unary_phrase
unary_phrase *>
   (dtrs:[ @dtr_macro(Posscl,Robust,Stem,ContentFirst,SCFirst) ],
    robust:Robust,
    posscl:Posscl,
    stem:Stem,
    c_cont: (liszt:ContentLast,
	     h_cons:SCLast ),
    synsem:local:cont: (liszt: append(ContentFirst,ContentLast),
			h_cons:append(SCFirst,SCLast))).

binary_phrase *>
  (dtrs:[ @dtr_macro(minus, Robust,_,ContentMiddle1,SCMiddle1),
	  @dtr_macro(Posscl,Robust,_,ContentMiddle2,SCMiddle2) ],
   robust:Robust,
   posscl:Posscl,
   c_cont: (liszt:ContentLast, 
            h_cons:SCLast ),
   synsem:local:cont: (liszt: append(append(ContentMiddle1,ContentMiddle2),ContentLast),
		       h_cons:append(append(SCMiddle1,SCMiddle2),SCLast)) ).

dtr_macro(Posscl,Robust,Stem,Liszt,HCons) :=
   (inflected:plus,
    root:minus,
    posscl:Posscl,
    robust:Robust,
    stem:Stem,
    synsem:local:cont: (liszt:Liszt,
			h_cons:HCons)).

head_only_phrase *>  head_dtr:synsem:local:conj:cnil.
head_initial *> non_head_dtr:synsem:local:conj:cnil_or_numconj.
head_final *> non_head_dtr:synsem:local:conj:cnil.

% mapping from dtrs to the separate dtr attributes
% (used for the general semantics principles above):

head_only_phrase *>  (head_dtr:H,dtrs:[H]).
head_initial     *>  (head_dtr:H, non_head_dtr:N,dtrs:[H,N]).
head_final       *>  (head_dtr:H, non_head_dtr:N,dtrs:[N,H]).
non_head_only_phrase *> (non_head_dtr:N,dtrs:[N]).
non_headed2_phrase *> (non_head_dtr:N1,non_head_dtr2:N2,dtrs:[N1,N2]).

head_compositional := (headed_phrase,
   c_cont:( top:Hand,
            index:Index,
            e_index:Event),
   head_dtr:synsem:local:cont:( top:Hand,
                                index:Index,
                                e_index:Event)).

non_clause := (@head_nexus_phrase,
   synsem:local:(cat:mc:na,
                 keys:message:e_list)). %0-dlist


clause := (@phrasal,
    synsem:( local:(cat:( head:v_or_g,
                           val:comps:o_list), % *olist*
                     conj:cnil),
             nonlocal:que:e_list)).  % 0-dlist

mc_phrase := (phrase,
   synsem:( local:cat:mc:plus,
	     nonlocal:( slash:[], % 0-dlist
			 que:[]))). % 0-dlist

non_rel_phrase := (@head_nexus_rel_phrase,
   synsem: ( local:keys:message:[(message,Msg,
                                  (handel:Mhand,
                                    soa:Soahand))],
             nonlocal:rel:e_list),            % 0-dlist
    head_dtr:synsem: (local:cont: (top:Hdhand,
                                   index:Ind ),
                      nonlocal:( que:e_list, % 0-dlist
                                 rel:e_list )), % 0-dlist
    c_cont:(top:Mhand,
           index:Ind,
           liszt:hd:Msg,
           h_cons:hd:(sc_arg:Soahand,
                      outscpd:Hdhand))).

non_rel_clause := (@non_rel_phrase,@clause).

decl_phrase := (@non_rel_phrase,
    synsem:local:( cat:( head:inv:minus_star,
                         mc:bool ),
                   keys:message:[prpstn_rel]),
    c_cont:(liszt:[relation],
             h_cons:[qeq])).

decl := (@decl_phrase,@clause).

imp(Dtr) := (@non_rel_clause,@head_valence_phrase,imp,
   synsem:local:( cat:( head:(  inv:minus_star,
				vform:imp_vform_star,
				tam:( tense:present_star,
				      aspect:no_aspect_star)),
			 val:( subj:(o_list,[anti_synsem]),
			       spr:o_list,
			       comps:[]),
			 mc:plus),
		   keys:message:[imp_rel]),
    head_dtr:(Dtr,synsem:( local: cat:(  head:verb,
				    mc:na,
				    val:( subj:[( unexpressed_reg,
					         local:( cat:head:case:acc,
                                                         cont:index:(Inst,
                                                         ref_ind, 
							  png:pn:secondper)))],
                                          comps:o_list)))),
    c_cont:( liszt:[relation,
                    (def_rel, restr:Rhand,
                                bv:Inst),
                    (pron_rel, handel:Prohand,
				 inst:(Inst,full_ref_ind,
				       prontype:zero_pron))],
             h_cons:[qeq,(qeq,sc_arg:Rhand,
                                    outscpd:Prohand)])).

interrog := (@non_rel_clause, 
   synsem:( local:keys:message:[ int_rel],
	     nonlocal:slash:[] ), % 0-dlist
    c_cont:( liszt:[relation],
             h_cons:[qeq ])).



wh_interrog(NHDtr) := (@interrog,% & binary_headed_phrase &
   synsem:local:( cat:( head:( verbal,
			      tam:mood:(strict_ind_or_mod_subj))),
				% ind_or_mod_subj & strict_sort
		   keys:message:[( params:[(Que, handle)])]),
    non_head_dtr:(NHDtr,synsem:( nonlocal:que:[(Que,handle)]))).


wh_interrog_fin(NHDtr) := (@wh_interrog(NHDtr),
   synsem:local:cat:( head:( verb, vform:fin_star),
		       val:subj:o_list,
		       mc:bool)).


yesno_phrase(Dtr) := (@interrog,@head_valence_phrase,yesno_phrase,
   synsem:local:( cat:( head:inv:plus_star,
			 val:( subj:(o_list,[anti_synsem]),
			       spr:Spr,
			       comps:[]),
			 mc:plus),
                   keys:message:[Msg]),
    c_cont:( top:Top,
             liszt:[(Msg,
                       handel:Top,
                        soa:Soahand)],
             h_cons:[( qeq,
                      sc_arg:Soahand,
                       outscpd:Dtrhand)]),
    head_dtr:(Dtr,synsem:local:( cat:( head:( verb, vform:fin),
				  mc:na,
				  val:( subj:o_list,
					spr:(Spr,o_list),
					comps:o_list)),
                            cont:( top:Dtrhand,
                                   index:e:tense:real_tense)))).

%%subjh_rule_decl := binary_rule_right_to_left & head_subj_phrase & decl &
%%  [ SYNSEM.LOCAL.CAT.MC bool ].

%% put the MC specification and decl from subjh_rule_decl in
%% this macro
head_subj_phrase(HeadDtr,NonheadDtr) := (head_subj_phrase,
                                            @head_valence_phrase,
                                              @decl, %head_final,
     synsem:local:( cat:( head:( v_or_g,
				 strict_head:plus,
				 %% strict_type, 
				 vform: fin_star,
				 prd:minus,
				 tam:ind_or_mod_subj_tam ), %@basic_ind_or_mod_subj_tam
                         posthead:plus,
                         mc:bool,
                         val:( subj:(o_list,[anti_synsem]), 
                               comps:e_list,
                               spr:Spr)),
                   keys:altkey:Altkey,
                   conj:cnil ),
    head_dtr:(HeadDtr,synsem:local:( cat:( val:( subj:[Synsem],
                                        spr:Spr,
                                        comps:o_list), 
                                    mc:na ),
                              keys:altkey:Altkey)),
    non_head_dtr:(NonheadDtr,synsem:( Synsem,canonical_synsem ,
                   local:( cat:( head:(subst,poss:minus),
                                 val:( subj:o_list,  
                                       comps:o_list, 
                                       spr:o_list ))),
                   nonlocal:( slash:e_list,   
                              rel:e_list,  
                              que:e_list 
                                           )))).


head_comp_or_marker_phrase(NonheadDtr) := (@head_valence_phrase, @head_compositional,
                                              head_initial,
    synsem:( canonical_synsem,
             local: (cat:( mc:Mc,
                           val:( subj:Subj,
                                 comps:Comps,
                                 spr:Spr,
				 keycomp:Keycomp) ),
                     keys:( altkey:Altkey,
                            message:Hmsg ) ) ),
    head_dtr:synsem:local:( cat:( mc:Mc,
                                  val:( subj:Subj,
                                        comps: select_first_realized(Synsem,Comps),  % revised opt theory, was: [Synsem|Comps],
                                        spr:Spr,
					keycomp:Keycomp ) ), %added
				%for pseudoclefts VGM, may be removed
                            keys:( altkey:Altkey,
                                   message:Hmsg ) ),
    non_head_dtr:(NonheadDtr,synsem:(Synsem,canonical_synsem)),
    c_cont:(liszt:e_list,
            h_cons:e_list)).

% select_first_realized only proceeds when the comps list is a known list. This is necessary since
% the conjunctions attract the comps value of their argument, i.e., their comps list is not bounded
% in the lexicon.
fun select_first_realized(+,+,-).
select_first_realized(Synsem,MotherComps,Comps) if when( Comps = (e_list;ne_list),
							 undelayed_select_first_realized(Synsem,MotherComps,Comps) ).

% Case 1: eliminate synsem which gets realized
undelayed_select_first_realized(Synsem,Rest,   [(Synsem,canonical_synsem)   |Rest]) if true.
% Case 2: drop unrealized optional element, and continue looking for a comps element that gets realized 
undelayed_select_first_realized(Synsem,NewRest,[(unexpressed,opt:plus)      |Rest]) if
  select_first_realized(Synsem,NewRest,Rest).
   

%%hcomp_rule := binary_rule_left_to_right & head_comp_phrase.

head_comp_phrase(HeadDtr,NonheadDtr) := (head_comp_phrase,
                                            @head_comp_or_marker_phrase(NonheadDtr),
    synsem: (local:( cat:posthead:Ph,
                     conj:cnil),
             lex:Lex),
    head_dtr: (HeadDtr, synsem:local:cat:( posthead:Ph,
                                           hc_lex:Lex )) ).

%%%Used for coordination (but not for complemetizers!).  The
%%%marker/complementizer is the head of the phrase.  The Synsem value of
%%%the nonhead daughter matches that of first item on the comps list of
%%%the head daughter.  Subj and Spr inherited from the head dtr.


%%%In a head-marker phrase, Nonlocal, Lex and Hc_lex feature values are
%%%inherited from the nonhead daughter.

head_marker_phrase := (@head_comp_or_marker_phrase(NonheadDtr),
   synsem:(local:(cat:hc_lex:Hclex,
		  conj:strict_conj),
	   nonlocal:Nonlocal,
	   lex:Lex),
   head_dtr:(word, %word_or_lexrule
	     synsem:local:cont:top:Ctop),
   non_head_dtr:(NonheadDtr,synsem:(local:cat:hc_lex:Hclex,
			nonlocal:Nonlocal,
			lex:Lex)),
   c_cont:top:Ctop).

%%%This variety of head-marker phrase semantically picks out those
%%%phrases with event-type content as the nonhead daughter.

head_marker_phrase_event(HeadDtr,NonheadDtr) := 
  (@head_marker_phrase,
   head_marker_phrase_event,
   head_dtr:(HeadDtr,
	     synsem:local:keys:altkey:r_handel:Rhand),
   non_head_dtr:(NonheadDtr,
		 synsem:(local:(cont:top:Rhand,
				keys:key:event_or_degree_or_no_rel)))).

%%%This variety of head-marker phrase semantically picks out those
%%%phrases with non-event-type content as the nonhead daughter.

head_marker_phrase_nom(HeadDtr,NonheadDtr) := (@head_marker_phrase,
   head_marker_phrase_nom,						     
   head_dtr:HeadDtr,
   non_head_dtr:(NonheadDtr,
		 synsem:local:keys:key:non_event_rel)).
	     

%%%noun_opt_comp_phrase removes the only element of a noun's
%%%Comps list, provided that item is opt:plus, and empty nonlocal feature
%%%lists. This is still needed since nominal arguments are required to have
%%%comps:e_list by the selecting heads - the situation thus is different
%%%from verbal arguments, which can still have an unrealized element on comps
%%%since it is required to have comps:o_list, e.g. in the head subject rule.
%%%This is something that should be changed to make it uniform, e.g.
%%%by requiring all arguments only to be comps:o_list instead of e_list.

noun_opt_comp_phrase(Dtr) := (noun_opt_comp_phrase,
    @head_valence_phrase,
    @head_compositional,
    inflected:Infl,
    posscl:Posscl,
    synsem:(canonical_synsem,
            local:(cat:(val:(comps:Comps,
			     subj:Subj,
                             spr:Spr,
                             spec:Spec),
                        hc_lex:Lex,
                        mc:Mc,
                        posthead:Ph),
                   conj:cnil,
                   keys:(altkey:Altkey,
                         message:Msg )),
            lex:Lex,
            modified:Mod),
    c_cont:(liszt:e_list,
	    h_cons:e_list),
    head_dtr:(Dtr,
	      inflected:Infl,
              posscl:Posscl,
              synsem:(local:(cat:(head:(n_or_p,
					strict_head:plus),
                                  val:(comps:(hd:(opt:plus,
                                                  nonlocal:(slash:e_list,
                                                            que:e_list,
                                                            rel:e_list)),
					      tl:(Comps,e_list)),
				       subj:Subj,
				       spr:Spr,
				       spec:Spec),
                                  mc:Mc,
                                  hc_lex:Lex,
                                  posthead:Ph),
                             keys: (message:Msg,
                                    altkey:Altkey)),
                      lex:Lex,
                      modified:Mod))).


%%%Head-specifier phrases exhibit co-selection between head and
%%%specifier: the synsem value of the nonhead daughter is
%%%structure-shared with the (first) item on the head's Spr list, while
%%%the Spec feature of the nonhead daughter is consistent with the head
%%%in terms of Head features, Comps list (which must only contain
%%%optional elements), the Modif feature, and several semantic features.
%%%The mother inherits the Subj and Spec feature values of the head
%%%daughter, but the Comps feature value of the nonhead daughter.

head_spec_phrase(HeadDtr,NonheadDtr) := (head_spec_phrase,
   @head_valence_phrase,
   @non_clause,@phrasal,
   inflected:plus,
   synsem:(local:(cat:(val:(subj:Subj,
                           comps:SpComps,
                           spr:Spr,
                           spec:Spec),
                      posthead:Ph),
                  keys:altkey:Altkey),
           modified:Modif),
   head_dtr:(HeadDtr,
             inflected:plus,
             synsem:(local:(cat:(head:Head,
                                 val:(subj:Subj,
                                      comps:(Comps,o_list), 
                                      spr:(hd:(Synsem,canonical_synsem),
                                           tl:Spr),
                                      spec:Spec),
                                 posthead:Ph,
                                 mc:na),
                             cont:( top:Htop,
                                    index:Ind,
                                    e_index:Event),
                             conj:cnil,
                             keys:( key:Key,
                                    altkey:Altkey )),
                      modified:Hmodif)),
   non_head_dtr:(NonheadDtr,
        (synsem:(Synsem,
            local:(cat:(mc:na,
                   val:(spec:(hd:(local:(cat:(head:Head,
                                              val:comps:Comps),
                                        keys:key:Key,
                                        cont: (top:Htop,
                                              index:Ind) ),
                                  modified:Hmodif), 
                             tl:e_list),     
                       comps:SpComps)),
                   cont:top:Top),
       modified:Modif))),
   c_cont:( top:Top,
            index:Ind,
            e_index:Event,
            liszt:e_list, 
            h_cons:e_list)). 


				  
%%%In a head-mod phrase, the Comps feature value of the head daughter
%%%must be an o_list (though the specifation of the mother is simply
%%%e_list, since once the phrase has been modified no more optional
%%%complements may be realized).  The mother is specified as
%%%modified:hasmod, and inherits the Subj and Spr specifications from the
%%%head.  This macro says nothing about the nonhead daughter or the
%%%relationship between the sisters.

head_mod_phrase := (@head_nexus_phrase,
    synsem:(local:(cat:val:(subj:Subj,
                            spr:Spr,
                            comps:e_list),
		   keys:altkey:Altkey),
            modified:hasmod),
    head_dtr:synsem:(local:(cat:val:(subj:Subj,
                                    spr:Spr,
                                    comps:o_list),
			    cont:e_index:Event,
			    keys:altkey:Altkey),
                     nonlocal:rel:e_list), 	%0-dlist
    c_cont:e_index:Event).

%%%Here the head daughter is mentioned primarily to establish the
%%%relationship between the head and the Mod feature of the nonhead
%%%daughter, which must be consistent in a variety of respects, including
%%%the Head feature value, Valence feature value, Agreement feature
%%%value, Nonlocal feature value, various semantic feature values, etc..
%%%Further the nonhead daughter's Comps and Spr lists must be of type
%%%o_list, and the Slash list of the mother is the result of appending
%%%the lists of the daughters.  Que list of the nonhead daughter is empty.

basic_head_mod_phrase_simple := (@head_mod_phrase, %@binary_headed_phrase,
    synsem:(local:(cat:mc:Mc, 
		   keys:message:Msg),
            nonlocal:(slash: append(First,Middle),
                       rel:e_list)), %0-dlist
    head_dtr:synsem:(local:(cat:(head:Head,
                                 val:Val,
                                 posthead:Ph,
                                 hc_lex:Hclex,
                                 mc:Hmc),
                             agr:Agr,
			    cont:index:Hind,
			    conj:Conj,
			    keys:(key:Key,
				  altkey:Altkey,
				  message:Hmsg)),
                        nonlocal:(Nonloc,
			          slash:Middle),
                       modified:Modif),
    non_head_dtr:synsem:(local:(cat:(head:(head,
					   strict_head:plus,
					   mod:(hd:(local:(local,
                                                           cat:(head:Head,
                                                                val:Val,
                                                                posthead:Ph,
                                                                hc_lex:Hclex,
                                                                mc:Hmc),
                                                           agr:Agr,
							   cont:index:Hind,
							   conj:Conj,
							   keys:(key:Key,
								 altkey:Altkey,
								 message:Hmsg)),
                                                     nonlocal:Nonloc,
                                                     modified:Modif),
                                                 tl:e_list)),
                                       val:(comps:o_list,
                                            spr:o_list),
                                       mc:Mc),
                                conj:cnil,
				keys:(key:independent_rel,
				      message:Msg)),
                           nonlocal:(slash:First,
				     que:e_list)),
       c_cont:liszt:e_list).



head_mod_phrase_simple := (@basic_head_mod_phrase_simple,
    head_dtr:synsem:local:cont:top:Htop,
    non_head_dtr:synsem:local:(cat:head:mod:(hd:local:cont:top:Htop,
					   tl:e_list),
			     cont:top:Hand),
    c_cont:top:Hand).


%%%In an adj-head phrase, the nonhead daughter must be specified as
%%%nonpredicative, and have empty Slash and Rel lists.  Comps list is
%%%also empty.

adj_head_phrase := (@basic_head_mod_phrase_simple, %head_final,
    synsem:(local:cat:posthead:Ph,
            modified:(lmod_star, periph:Periph), %lmod*
            lex:Lex),
    head_dtr:synsem:(local:cat:posthead:Ph,
                     lex:Lex),
    non_head_dtr:synsem:(local:cat:(head:prd:minus,
	                            val:comps:e_list),
                         nonlocal:(slash:e_list,  %0-dlist
                                    rel:e_list),   %0-dlist
                         modified:periph:Periph)).


%%%A head-adj phrase is head-initial, the nonhead daughter must be
%%%posthead:plus.

head_adj_phrase := (head_initial, @basic_head_mod_phrase_simple, @phrasal,
    synsem:(local:cat:posthead:plus,
            modified:rmod_star),
    head_dtr:synsem:modified:notmod_or_rmod,
    non_head_dtr:synsem:(local:cat:posthead:plus,
                         nonlocal:que:e_list)).  

scopal_mod_phrase := (@head_mod_phrase_simple,
    non_head_dtr:synsem:local:( cat:head:mod:[(local:scopal_mod)],
				cont:index:Index),
    c_cont:( index:Index,
	     h_cons:[])).

isect_mod_phrase := (@head_mod_phrase_simple,
    head_dtr:synsem:local:(cont:(top:Hand,
				 index:Index),
			   keys:message:e_list),
    non_head_dtr:synsem:local:(cat:head:mod:(hd:local:intersective_mod,
					   tl:e_list),
			     cont:top:Hand),
    c_cont:(index:Index,
	    h_cons:e_list)).

adj_head_scop_phrase(NonheadDtr,HeadDtr) := (adj_head_scop_phrase,
			 @adj_head_phrase,@scopal_mod_phrase,
   non_head_dtr:(NonheadDtr,synsem:local:cat:posthead:minus),
   head_dtr:HeadDtr).

head_adj_scop_phrase(HeadDtr,NonheadDtr) := (head_adj_scop_phrase,
					     @head_adj_phrase,@scopal_mod_phrase,
   non_head_dtr:(NonheadDtr,synsem:nonlocal:rel:[]),
   head_dtr:HeadDtr).
%% I added the head restrictions for head here to rule out phrases
%% like "kim sleeps" being recognized as a noun modified by a VP.
%% this specification is taken from the macro
%% hadj_i_h(HeadDtr,NonheadDtr). 



%%%Nonhead dtr must be posthead:minus.
adj_head_int_phrase := (@adj_head_phrase, @isect_mod_phrase,
    (non_head_dtr:synsem:local:cat:(head:tam:tense:no_tense,
                                    posthead:minus))).

head_adj_int_phrase := (@head_adj_phrase,@isect_mod_phrase).

%%%For all postnominal modification.  Head daughter's Head value is noun,
%%%and it has an empty Comps list.  The nonhead daughter is a phrase
%%%(lex:minus), predicative, and has an empty Slash list.

n_adj_int_phrase := (@head_adj_phrase, 
    head_dtr:synsem:(local:cat:(head:noun,
                                val:comps:e_list),
                     modified:periph:na_or_minus),
    non_head_dtr:(phrase, %added to filter out lexical items, since
		           % phr_synsem is not a type
		  synsem:(@phr_synsem,
                         local:cat:(head:prd:plus,
                                    mc:na),
                         nonlocal:slash:e_list))).

%%%All postnominal modification not considered a relative clause falls
%%%under the heading "reduced relative", including prepositional phrases
%%%and present participial verb phrases.  These phrases have in common
%%%the tense:no_tense specification, and the existence of a single
%%%unexpressed element on their Subj list.  They are distinguished from
%%%relative clauses by the fact that they have an empty Rel value.

n_adj_redrel_phrase := (@n_adj_int_phrase,
    head_dtr:synsem:local:(cont:(top:Htop,
				 index:Index),
			   keys:key:handel:Hand),
    non_head_dtr:synsem:(local:(cat:(head:(mod:(hd:local:intersective_mod,
                                               tl:e_list),
                                          tam:tense:no_tense),
                                    val:subj:(hd:unexpressed,
                                              tl:e_list)),
				cont:top:Hand),
                         nonlocal:rel:e_list),  
     c_cont:(top:Htop,
	     index:Index,
	     h_cons:e_list)). 



%%%Nontemporal reduced relatives are distinguished from the temporal
%%%variety only by the Keys value (that is, semantically).

n_adj_redrel_nontemp(HeadDtr,NonheadDtr) := (n_adj_redrel_nontemp,
    @n_adj_redrel_phrase,
    head_dtr:HeadDtr,
    non_head_dtr:(NonheadDtr,
		  synsem:local:keys:(key:nontemp_rel,
				     altkey:nontemp_or_conj_rel))).
                  

%%%The head daughter of phrase involving pre-nominal modification must be
%%%unspecified (its Spr list must be nonempty), but the Comps list must
%%%be empty.

adj_n_int_phrase(HeadDtr,NonheadDtr) := (adj_n_int_phrase, 
    @adj_head_int_phrase, 
    head_dtr:(HeadDtr, 
	      synsem:local:cat:(head:noun,
		                val:(spr:(hd:local:keys:key:quant_rel,
				          tl:e_list),
                                     comps:e_list))),
    non_head_dtr:NonheadDtr).

adj_h_int_phrase(HeadDtr,NonheadDtr) := (@adj_head_int_phrase,adj_h_int_phrase,
   head_dtr:(HeadDtr,synsem:local:cat:head:adverbee),
    non_head_dtr:(NonheadDtr,synsem:( local:cat:head:tam:tense:no_tense,
                                      nonlocal:rel:[]))).

hadj_i_h(HeadDtr,NonheadDtr) := (h_adj_int_phrase,@head_adj_int_phrase,
    head_dtr:(HeadDtr,
	      synsem:local:cat:head:adverbee),
    non_head_dtr:(NonheadDtr,
		  synsem:(local:cat:head:tam:tense:no_tense,
                          nonlocal:rel:e_list))).

% This unary phrase rule effectively erases the specifier from the
% daughter's spr list, but adds to the semantics via the c_cont
% feature, taking the (unrealized) specifier's key value as the
% relation type of the liszt value, which binds the daughter's index.

% Since we have made this a head_only_phrase, we can probably simplify
% somewhat.
% Changed back to a nonhead-only phrase, because the dtr needs the
% specification agr:divisible:minus to rule out unification with
% divisible:plus_star, but the mother needs agr:divisible:minus_star
% for coordination, and a constraint on headed_phrase specifies that
% the agr values of mother and dtr are structure-shared.
generic_bare_np_phrase := (generic_bare_np_phrase,
    synsem:(synsem, 
            local:( cat:(  head:Head,
                           hc_lex:Hclex,
                           val:( subj:e_list,
                                 comps:e_list,
                                 spr:e_list),
                           mc:na ),
                     agr:( ref_ind,
                           png:Png),
                     conj:Conj,
                     keys:( key:(Key,nonpro_rel),  
                            message:(Msg,e_list), %% & 0-dlist,
                            altkey:implicit_quant_rel) ),
             nonlocal:(Nonloc,
		       que:[],  %added these specifications for nonloc
		       rel:[]), %feature amalgamation on nonheaded phrases
             modified:Modif,
             lex:Lex ),
    non_head_dtr: (synsem:(local:(cat:(head:(Head, noun),
				      hc_lex:Hclex,
				      val:( subj:o_list,
					    comps:e_list,
					    spr:[(canonical_synsem,
						  opt:minus,
						  local:( local,
							  keys:key:Quant),
						  nonlocal:(  slash:[],
							      rel:[],
							      que:[]) ) ] ) ),
				 agr:png:Png,
				 conj:(Conj,cnil),
				 cont:( index:Index,
					e_index:Event),
				 keys:( key:(Key,
					     basic_nom_rel,
					     handel:Nhand),%%& basic_nom_rel & 
					message:Msg) ),
			  nonlocal:(Nonloc,slash:e_list),
			  modified:Modif,
			  lex:Lex )),
   c_cont:( index:Index,
	    e_index:Event,
	    liszt:[(Quant,
		    bv:Index,
		    restr:Rhand)],
            h_cons:[(qeq,
                     sc_arg:Rhand,
                     outscpd:Nhand)])).

% Licenses NPs that don't need specifiers, like mass nouns and
% plurals.  Eligibility for this depends on the feature
% specification divisible:plus. The specifier's key value is specified
% as udef_rel, which will essentially be a ghost quantifier, discussed
% by Sag.

bare_np_phrase(Dtr)  := (@generic_bare_np_phrase,bare_np_phrase,
    synsem:local:agr:divisible:plus_star,
    non_head_dtr: (Dtr, synsem:local:(agr:divisible:plus, 
			      cat:val:spr:[local:keys:key:udef_rel]))).

%%%Eligibility for this unary phrase is primarily semantic. The
%%%daughter's Key value must be of type abstr_named_np_rel.  The daughter
%%%must also be specified as divisible:minus_star (singular count nouns).
%%%The mother inherits the agreement features of the daughter.

proper_np_phrase(Dtr) := ( @generic_bare_np_phrase,proper_np_phrase,
    synsem:local:agr:(Agr, divisible:minus_star),    
    non_head_dtr: (Dtr, synsem:( local:(cat:val:spr:[local:keys:key:def_np_rel],
                               agr:Agr,
                               keys:( key:abstr_named_np_rel,  
                                     altkey:basic_nom_rel))) ) ).

bare_vger_phrase(Hdtr) := (bare_vger_phrase,@head_valence_phrase,@phrasal,
   synsem:( local:( cat:( val:( subj:[],
				 spr:[],
                                 comps:[]),
			   mc:na),
		    
		     keys:( message:[],
			    altkey:Altkey))),
    head_dtr:(Hdtr, 
          synsem: 
	   ( local:( cat:( head:gerund,
			   val:comps:o_list),
		     conj:cnil,
		     cont:( top:Hand,
			    index:(Index, divisible:plus),
                            e_index:Event),
		     keys:( key:gerund_rel,
			    altkey:no_rel)))),
    c_cont:( index:Index,
             e_index:Event,
	     liszt:[( udef_rel,Altkey,
		     bv:Index,
		      restr:Rhand)],
	     h_cons:[( qeq,
		      sc_arg:Rhand,
		       outscpd:Hand)])).

np_cp_phrase(Dtr) := (np_cp_phrase, @phrasal,
   synsem:(local:(cat:(head:(noun,
			     case:nom,
			     mod:[]),
		       val:(subj:[],
			    spr:[],
			    comps:[]),
		       mc:na),
		  agr:png:pn:thirdsg,
		  conj:cnil,
		  keys:(message:[],
			key:Key,
			altkey:Altkey)),
	   nonlocal:(slash:[],
		     que:[],
		     rel:[])),
   non_head_dtr:(Dtr,
		 synsem:(local:(cat:(head:(comp,
					   vform:fin,
					   tam:mood:ind_or_mod_subj),
				     val:comps:o_list,
				     mc:minus),
				conj:cnil,
				cont:top:Chand,
				keys:message:[prpstn_rel]),
			 nonlocal:(slash:[],
				   que:[],
				   rel:[]))),
   c_cont:(index:Index,
	   liszt:[(Altkey,
		   udef_rel,
		   bv:Index,
		   restr:Rhand),
		  (Key,
		      nominalize_rel,
		      handel:Nhand,
		      inst:Index,
		      arg4:Chand)],
	   h_cons:[(qeq,
		    sc_arg:Rhand,
		    outscpd:Nhand)])).
		   
					   
		     
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Noun compounds
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%Compound nouns are head-final, inheriting the entire Valence feature
%%%value and all nonlocal feature values from the head daughter, which
%%%must be lexical.  The Comps lists of both daughters must be empty.  In
%%%addition, the nonlocal feature lists of the nonhead daughter must be
%%%empty, and its Spr list must either be emtpy, or contain an
%%%unexpressed element.  By default, the nonhead daughter may be lexical
%%%or phrasal.

basic_n_n_cmpnd_phr := (head_final,
   synsem:(local:(cat:(val:Valence,
		       mc:Mc),
		  keys:message:Msg),
	   nonlocal:(slash:Slash,
		     que:Que,
		     rel:Rel)),
   head_dtr:synsem:(canonical_synsem,
		    lex:plus_star, %@lex_synsem,
		    local:(cat:(val:(Valence,
				     comps:[]),
				mc:Mc),
			   cont:(top:Top,
				 index:(Hind,
					ref_ind),
				 e_index:Eind),
			   keys:(message:Msg,
				 key:nonpro_rel),
			   conj:cnil),
		    nonlocal:(slash:Slash,
			      que:Que,
			      rel:Rel),
		    modified:notmod_or_lmod),
   non_head_dtr:synsem:(local:(cat:val:(comps:[],
					spr:unexplist), %functional
			       %relation corresponding to *unexplist*
			       cont:index:(Modind,
					   ref_ind,
					   png:pn:thirdsg),
			       keys:key:nonpro_rel),
			nonlocal:(slash:[],
				  que:[],
				  rel:[])),
   c_cont:(top:Top,
	   index:Hind,
	   e_index:Eind,
	   liszt:[(unspec_rel,
		   handel:Top,
		   hinst:Hind,
		   nhinst:Modind)|_])).
						    

%%%Additionally, the result of a noun compound construction is lexical
%%%(lex:plus), and the head daughter must have a Spr list whose single
%%%element is nonoptional and has a Key value quant_rel.

n_n_cmpnd_phr := (@basic_n_n_cmpnd_phr,
   synsem:(canonical_synsem,
	   lex:plus_star, %@lex_synsem,
	   local:cat:head:mod:[]),
   head_dtr:synsem:local:cat:(head:noun_star,
			      val:spr:[(synsem,
					opt:minus,
					local:keys:key:quant_rel)])).

%%%In NP-noun compounds, the nonhead daughter has a Key value
%%%abstr_named_rel, and an empty Spr list.  Thus, the nonhead daughter
%%%will be some sort of proper noun phrase.  For things like "CSLI
%%%engineers."


np_n_cmpnd_phr(HeadDtr,NonheadDtr) := (@n_n_cmpnd_phr,
   np_n_cmpnd_phr,
   synsem:modified:periph:na,
   head_dtr:(HeadDtr,
	     synsem:(lex:plus,
		     modified:periph:na_or_minus,
		     local:keys:altkey:no_rel)),
   non_head_dtr:(NonheadDtr,
		 synsem:(local:(cat:val:spr:[],
				keys:(key:abstr_named_rel,
				      altkey:implicit_quant_rel)),
			 lex:plus)),
   c_cont:(liszt:[unspec_rel],  
	   h_cons:[])).   

%%%For things like Lee Browne.  Both daughters have the Key value
%%%named_np_rel, and both daughters are lexical (though the nonhead
%%%daughter has and empty Spr list).

np_name_cmpnd_phr(HeadDtr,NonheadDtr) := (@n_n_cmpnd_phr,
   np_name_cmpnd_phr,						
   synsem:modified:periph:na,
   head_dtr:(HeadDtr,
	     synsem:(lex:plus,
		     local:keys:key:named_np_rel,
		     modified:periph:plus)),
   non_head_dtr:(NonheadDtr,
		 synsem:(local:(cat:val:spr:[],
				keys:(key:named_np_rel,
				      altkey:implicit_quant_rel)),
			 modified:periph:plus,
			 lex:plus)),
   c_cont:(liszt:[unspec_rel],
	   h_cons:[])).


%%%For things like "department manager".  In a noun-noun compound, the
%%%nonhead daughter is lexical, but it also has a nonempty Spr list (with
%%%one nonoptional unexpressed element).  

noun_n_cmpnd_phr(HeadDtr,NonheadDtr) := (@n_n_cmpnd_phr,
   noun_n_cmpnd_phr,					       
   synsem:modified:periph:Periph,
   head_dtr:(HeadDtr,
	     synsem:(canonical_synsem,
		     lex:plus_star, %@lex_synsem,
		     modified:periph:minus,
		     local:keys:altkey:no_rel)),
   non_head_dtr:(NonheadDtr,
		 synsem:(local:(cat:(head:(noun_star,
					  prd:minus),
				    val:spr:[(unexpressed,
					      opt:minus)]), %*unexpcons*
			       keys:altkey:no_rel,
			       cont:(top:Ntop,
				     index:Nind)),
			 lex:plus,
			 modified:periph:Periph)),
   c_cont:(liszt:[unspec_rel,(udef_rel,
			      bv:Nind,
			      restr:Rhand)],  
	   h_cons:[(qeq,
		    sc_arg:Rhand,
		    outscpd:Ntop)])).   


appos_phr(Hdtr,NHdtr) := (appos_phr,
   synsem:( @phr_synsem,
	    local:cat:( head:prd:Prd,
                         val:Valence),
	     nonlocal:( slash:[],
			 que:[],
			 rel:[])),
    head_dtr:(Hdtr,synsem:( canonical_synsem,
	    local:( cat:( head:( noun, prd:(Prd,plus)),
			   val:(Valence,
			        spr:o_list,
				 comps:[])),
		     cont:( top:Top,
			    index:(Hind, ref_ind)),
		     keys:( key:( reg_nom_rel, handel:Hand),
                            altkey:explicit_quant_rel),
		     agr:png:pn:Agr,
		     conj:cnil),
	     nonlocal:( slash:[],
			 que:[],
			 rel:[]))),
    non_head_dtr:(NHdtr,synsem:( canonical_synsem,
	    local:( cat:( head:( noun,
                                 case:nom),
			   val:( spr:o_list,
				 comps:[])),
		     cont:( top:Top,
			    index:(Modind, ref_ind)),
		     keys:( key:apposition_rel,
                            altkey:non_conj_rel),
		     agr:png:pn:Agr),
	     nonlocal:( slash:[],
			 que:[],
			 rel:[]), 
             modified:notmod)),
    c_cont:( top:Top,
	     index:Hind,
	     liszt:[( appos_id_rel, handel:Hand,
                                       arg:Modind,
                                       arg3:Hind)],
	     h_cons:[])).

	   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Temporal NP modifiers
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%A temporal modifying phrase is a unary phrase whose daughter is an
%%%ordinary NP (head:noun, inflected:plus, spr:o_list, comps:[]), and
%%%whose own head value is of type modnp_star, and has a nonempty mod
%%%value, specifying that the thing it modifies should have a nominal or
%%%verbal head value, a nonempty spr list, and a comps list of type
%%%o_list.  Further, this phrase subcategorizes for a nonoptional NP
%%%subject, and an optional adverbial specifier.  It has an empty comps
%%%list. It's key value, contributed to the semantics of the phrase
%%%via c_cont, unspec_loc_rel.   

temp_mod_phrase := (@phrasal,
   non_head_only_phrase,
   synsem:(local:(cat:(head:(modnp_star,
			     mod:[local:(intersective_mod,
					 cat:(@n_or_v_cat,
					      mc:Mc),
					 conj:cnil,
					 cont:index:Ind,
					 keys:message:[])],
			     prd:Prd,
			     tam:Tam),
		       posthead:plus,
		       val:(subj:[(synsem,
				   local:(cat: @nomp_cat, %nomp_cat_min,
					  conj:cnil,
					  cont:index:Ind),
				   nonlocal:(slash:[],
					     rel:[],
					     que:[]),
				   opt:minus)],
			    spr:[(local:(local_min,
					 cat:(head:adv,
					      val:spr:o_list),
					 cont:top:Khand,
					 keys:key:(degree_rel,
						   darg:Darg)),
				  nonlocal:que:[],
				  opt:plus)],
			    comps:Comps),
		       mc:Mc),
		  cont:index:Ind,
		  conj:cnil,
		  agr:Ind,
		  keys:(key:(unspec_loc_rel,
			     Key,
			     handel:Khand,
			     event:(Event,
				    e:Tam),
			     arg:(Ind,
				  event_or_index),
			     arg3:Index,
			     dim:Darg),
			altkey:Argkey,
			message:[])),
	   nonlocal:(Nonloc,
		     rel:[])),
   root:minus,
   non_head_dtr: (inflected:plus,
	  synsem:(local:(cat:(head:(noun,
				    prd:Prd),
			      val:(spr:o_list,
				   comps:(Comps,
					  []))),
			 cont:index:Index,
			 conj:cnil,
			 keys:key:(modable_rel,
				   Argkey)),
		  nonlocal:Nonloc,
		  modified:hasmod)),
   c_cont:(top:Khand,
	   e_index:Event,
	   liszt:[Key],
	   h_cons:[])).

%%%A non-wh temp-mod phrase has an anti-synsem on its spr list, and
%%%its daughter's slash and que lists are empty.  For things like "the
%%%first of January 1984".
temp_mod_nonwh_phrase(Dtr) := (@temp_mod_phrase,
   temp_mod_nonwh_phrase,
   synsem:local:cat:val:spr:[anti_synsem],
   non_head_dtr: (Dtr,
		 synsem:nonlocal:(slash:[], que:[]))).


basic_measure_np_phrase := (non_headed2_phrase,
   inflected:Bool,
    synsem:( @phr_degree_spec_synsem,
            local:( cat:val:spec:[( local:cat:head:(adj, prd:Bool))],
                     conj:cnil,
                     keys:key:Key,
                     agr:Agr),
             nonlocal:( slash:[],
                         que:[],
                         rel:[]),
             modified:Modif),
    root:minus,
    non_head_dtr:( inflected:plus,
           synsem:( local:( cat:( head:intadj,
                                  val:( spr:o_list,
                                        comps:[],
                                        spec:o_list)),
                            cont:index:Index,
                            keys:( key:const_rel,
                                   altkey:handel:Nhand),
                            conj:cnil),
                    modified:Modif)),
    non_head_dtr2:( inflected:Bool,
           synsem:( @lex_synsem,
                      local:( cat:( head:noun,
                                     val:( subj:[],
                                           spr:[( canonical_synsem,
                                                  opt:minus,
                                                   local:(local,
                                                        keys:key:Quant ),
                                                   nonlocal: 
                                                       ( slash:[],
                                                         rel:[],
                                                         que:[]))])),
                               conj:cnil,
                               cont:( top:Nhand,
                                      index:(Index,
					     png:pn:(strict_nonthirdsg;strict_firstorthirdsg))), %strict_pernum
                               agr:Agr,
                               keys:( key:nonpro_rel,
                                      altkey:no_rel,
                                      message:[])),
                       nonlocal:slash:[])),
    c_cont:( liszt:[(Key, deg_rel,dim:Index),
                    (udef_rel,Quant,
                       bv:Index,
                        restr:Rhand)],
             h_cons:[( qeq,
                      sc_arg:Rhand,
                       outscpd:Nhand)])).

measure_np_phrase(Dtr1,Dtr2) := (measure_np_phrase,@basic_measure_np_phrase,
   non_head_dtr:Dtr1,
   non_head_dtr2:(Dtr2,
          synsem:local:cat:val:comps:[])).



%%%A free relative has a nominal or prepositional head value, empty
%%%valence lists, and empty nonlocal feature lists.  A wh-phrase is
%%%the head of a free relative, and has a nonempty que list, and a slash
%%%values shared with the slash value of the nonhead daughter.  The
%%%nonhead daughter is a finite or infinitive uninverted clause or VP, whose
%%%slash value is specified as structure sharing its key, altkey and
%%%index values with the head daughter.  Thus, the relationship between
%%%the gap and the wh-phrase is semantic, while the purely syntactic
%%%specifications of the nonhead daughter's slash value are tied to the
%%%slash value of the free relative pronoun, specified in the lexical
%%%entry.  
free_rel_phrase := (@head_compositional,
   head_initial,			  
   synsem:(local:(cat:(head:(n_or_p,
			     strict_head:plus),
			%strict_head
		       mc:na,
		       val:(subj:[],
			    comps:[],
			    spr:[]),
		       posthead:plus),
		  conj:cnil,
		  keys:message:[]),
	   nonlocal:(slash:[],
		     que:[],
		     rel:[])),
   head_dtr:synsem:(local:(local, %local_min
			   cat:val:(comps:[],
				    spr:o_list,
				    subj:o_list),
			   cont:e_index:Ind,
			   keys:(key:(Key,
				      handel:Hand),
				 altkey:Altkey)),
		    nonlocal:(que:[ref_ind],  
			      slash:[(local,Loc)])), %local_min,
				 
   non_head_dtr:synsem:(local:(cat:(head:(verbal,
					  vform:fin_or_inf,
					  inv:minus),
				    val:(spr:o_list,
					 comps:o_list)),
			       cont:top:Hand,
			       keys:message:one_list),
			nonlocal:(slash:[(Loc,  
					  cat:val:(comps:o_list,
						   spr:o_list),
					  cont:index:Ind,
					  keys:(key:Key,
						altkey:Altkey))],
				  que:[],
				  rel:[])),
   c_cont:(liszt:[],  
	   h_cons:[])).  

%%%In an infinitive free relative, the daughter is an infinitive VP.
free_rel_inf_phrase(HeadDtr,NonheadDtr) := (@free_rel_phrase,
   free_rel_inf_phrase,						  
   head_dtr:HeadDtr,
   non_head_dtr:(NonheadDtr,
		 synsem:local:cat:(head:(comp,
					 vform:inf),
				   val:subj:[(synsem,
					      nonlocal:slash:[])]))).

%%%In a finite free relative, the nonhead daughter is a finite clause.
free_rel_fin_phrase(HeadDtr,NonheadDtr) := (@free_rel_phrase,
   free_rel_fin_phrase,						   
   head_dtr:HeadDtr,
   non_head_dtr:(NonheadDtr,
		 synsem:local:cat:(head:(verb,
					 vform:fin),
				   val:subj:o_list))).



   
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Licensing Postnominal Modification
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%-----------------------------------------------------------------
% Modification by a reduced relative
%-----------------------------------------------------------------


		      
%%%In a temporal reduced relative, the nonhead daughter is semantically
%%%temporal in some way.  
n_adj_redrel_temp(HeadDtr,NonheadDtr) := (@n_adj_redrel_phrase,
    n_adj_redrel_temp,						
    head_dtr:HeadDtr,						   
    non_head_dtr:(NonheadDtr,
                 synsem:local:keys:(key:temp_loc_abstr_rel,
				    altkey:temp_abstr_or_conj_rel))).

%------------------------------------------------------------------
% Modification by a relative clause
%------------------------------------------------------------------

%%%In the case that an N' is modified by a relative clause, the resulting
%%%phrase is marked as periph:plus.  This blocks iterative modification
%%%by relative clauses, since the mod value of a relative clause
%%%specifies that it will only modify things marked
%%%modified:periph:na_or_minus.  The nonhead daughter (the relative
%%%clause) must be a finite or infinitive clause, and the head daughter
%%%must subcategorize for a specifier whose key value is of type
%%%i_or_e_quant_or_deg_rel.  As noted in the ERG grammar itself:


%%% DPF 26-Mar-01 - Added [SPR..KEY impl_or_expl_quant_rel] to provide basis
%%% for blocking application of proper_np (non-branching) rule, to avoid e.g.
%%% "*I saw Abrams I had hired" - cf. "I saw the Abrams I had hired"
%%%All other requirements for this construction fall out of the
%%%description @n_adj_int_phrase and the relative clause itself.  For
%%%example, the mod value of the relative clause must be consistent with
%%%the head daughter, and non-relative clauses do not have such a mod value.
n_adj_relcl_phrase(HeadDtr,NonheadDtr) := (@n_adj_int_phrase,
						 @isect_mod_phrase,
    n_adj_relcl_phrase,						 
    synsem:modified:periph:plus,
    non_head_dtr:(NonheadDtr,
		 synsem:local:cat: @s_cat_fin_or_inf_unspec),
    head_dtr:(HeadDtr,
	      synsem:local:cat:val:spr:[local:keys:key:i_or_e_quant_or_deg_rel])).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Licensing Extraction
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%----------------------------------------------------------------
% Argument extraction
%----------------------------------------------------------------
%%%Extracted-argument phrases are headed phrases, so the HFP applies, and
%%%are instances of head-valence phrase, so nonlocal features are passed
%%%from daughter to mother.

extracted_arg_phrase := (@head_valence_phrase,
    head_only_phrase,
    synsem:(local:(cat:(head:tam:mood:ind_or_mod_subj,
			hc_lex:minus),
		   conj:cnil),
	    lex:minus),
    head_dtr:synsem:local:conj:cnil).			       
		   

%%%%%%% Subject extraction %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%In an extracted-subject phrase, the head daughter is a finite or
%%%infinitive VP that has a comps list of type o_list, and the element on
%%%the subj list is a gap whose local value is equated with the element
%%%on the slash list of the daughter.  The mother has all empty valence
%%%lists.

extracted_subj_phrase := (@extracted_arg_phrase,
    synsem:local:cat:(head:tam:ind_or_mod_subj_tam,
		      val:(subj:e_list,
			   spr:e_list,
			   comps:e_list),
		      mc:minus),
    head_dtr:synsem:(local:cat:(head:(verbal,
				      strict_head:plus, % & strict_type,
				      vform:fin_or_inf,
				      mod:[synsem_min]), 
				val:(subj:[(gap,
					    local:(Local,
						   local,
						   cont:index:ref_ind))],
				     comps:o_list),
				mc:na),
		     nonlocal:slash:[Local])).

%%%In a finite extracted-subject phrase, the result is a declarative
%%%clause.  The head daughter is a finite VP subcategorizing for a
%%%nominative subject.

extracted_subj_phrase_fin(Dtr) := (@extracted_subj_phrase, @decl,
    extracted_subj_phrase_fin,					 
    head_dtr:(Dtr,
	      synsem:local:(cat:(head:vform:fin_star,
				 val:subj:[local:cat:head:case:nom]),
			    keys:message:e_list))).

%%%In an infinitive extracted-subject phrase, the head daughter's vform
%%%value is inf.

extracted_subj_phrase_inf(Dtr) := (@extracted_subj_phrase,
    extracted_subj_phrase_inf,					 
    head_dtr:(Dtr,
	      synsem:local:(cat:head:vform:inf,
			    cont:top:Top,
			    keys:message:one_list)), %1-dlist
    c_cont:(top:Top,
	    liszt:e_list,
	    h_cons:e_list)).   
	      
%%%%%%% Complement extraction %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%In an extracted complement phrase, the head of the comps list is a gap
%%%whose slash value is structure-shared with the slash value of the
%%%head.  The rest of the comps list, as well as the subj and spr values,
%%%are passed up to the mother.
%%%v_or_g_or_p is a type in fundamentals.tdl not in our signature.
%%%It has subtypes v_or_g and prep_star, which are.

extracted_comp_phrase(Dtr) := (@extracted_arg_phrase,
				     @head_compositional,
    extracted_comp_phrase,				     
    synsem:(canonical_synsem,
	    local:(cat:(val:(subj:Subj,
			     spr:Spr,
			     comps:Comps),
			mc:Mc),
		   keys:message:Msg),
	    lex:Lex),
    head_dtr:(Dtr,
	      synsem:(local:(cat:(head:(v_or_g_or_p,
					strict_head:plus), % & strict_type
				  val:(subj:Subj,
				       spr:Spr,
				       comps:(hd:(gap,
						  local:(local,
						  cat:head:mobile:plus),
					      nonlocal:slash:Slash),
					      tl:Comps)),
				  mc:Mc,
				  hc_lex:Lex),
			     keys:message:Msg),
		      nonlocal:slash:Slash)),
    c_cont:(liszt:e_list,
	    h_cons:e_list)).   
	     
%------------------------------------------------------------------
% Adjunct extraction
%------------------------------------------------------------------

basic_extracted_adj_phrase := (@head_mod_phrase, @phrasal,
    head_only_phrase,
    head_dtr:synsem:local:(cat:head:mod:(hd:local:cat:head:noun,
					 tl:e_list),
			   keys:key:relation)).

%%%In an extracted adjunct phrase, the mother's slash value (which need
%%%   not be inherited from the daughter, since this is not a
%%%   head-valence phrase) has a mod value consistent with the head
%%%   daughter in a variety of respects (head, valence, etc.).  The
%%%   daughter has a nonempty subj list and an empty slash list.

extracted_adj_phrase := (@basic_extracted_adj_phrase,
    synsem:(local:(cat:(posthead:Ph,
			mc:Mc),
		   keys:(key:Modkey,
			 message:Msg)),
	    nonlocal:slash:(hd:(cat:(posthead:plus,
				     head:(mobile:plus, %mobile, not in our
				%signature-- used to
				% exclude nominative NPs, gerunds
					   mod:(hd:local:(cat:(head:Head,
							       val:Val,
							       posthead:Ph,
							       hc_lex:Hclex,
							       mc:Mc),
							  cont:(top:Htop,
								index:Hind),
							  conj:Conj,
							  keys:key:Modkey,
							  ctxt:Ctxt),
						tl:e_list)),
				     val:(subj:prolist, %functional relation
					  comps:o_list,
					  spr:o_list)),
				cont:top:Hand,
				keys:(key:independent_rel,
				      message:Msg)),
			    tl:e_list)),
     head_dtr:synsem:(canonical_synsem,
		      local:(local, %local_basic
			     cat:(head:(Head,
					verb,
					tam:mood:ind_or_mod_subj),
				  val:(Val,
				       subj:(hd:(synsem_min,
						 nonlocal:slash:e_list),
					    tl:e_list)),
				  posthead:Ph,
				  hc_lex:Hclex,
				  mc:Mc),
			     cont:(top:Htop,
				   index:Hind),
			     conj:Conj,
			     ctxt:Ctxt),
		      nonlocal:slash:e_list, %0-dlist
		      modified:notmod),
     c_cont:(top:Hand,
	     h_cons:e_list)).   

extracted_adj_int_phrase(Dtr) := (@extracted_adj_phrase,
    extracted_adj_int_phrase,					
    synsem:nonlocal:slash:(hd:(local,
			       cat:head:mod:(hd:local:(intersective_mod,
						       cont:index:Index),
					     tl:e_list),
			       cont:(top:Hand,
				     index:Index)),
					   % sort:entity was
			   %specified, but does no work, since nouns
			   %have no such specification.  In any case,
			   %entity would be wrong -- only subtype
			   %human.  So we do not include this.
			   tl:e_list),  
    head_dtr:(Dtr,
	      synsem:local:cont:(top:Hand,
				 index:(Index,
					individual))),
    c_cont:(index:Index,
	    liszt:e_list)).  

extracted_adj_temp_phrase(Dtr) := (@basic_extracted_adj_phrase,extracted_adj_temp_phrase,
   synsem:( local:( cat:( posthead:Ph,
                           mc:Mc ),
                     keys:message:Msg),
	     nonlocal:slash:[( cat:( @nomp_cat,head:noun),
                      cont:( top:Hand,
                             index:(Ind,sort:time)),
                      keys:key:modable_rel)]),
    head_dtr:(Dtr,synsem:( canonical_synsem,
	    local:( local_basic,
		    cat:( head:( verb, vform:fin_or_bse,
                                         tam:mood:ind_or_mod_subj),
			   val:subj:[( synsem_min,
                                       nonlocal:slash:[])],
                           posthead:Ph,
                           mc:Mc),
                     cont:( top:Hand,
                            index:Event),
                     keys:message:Msg),
             nonlocal:slash:[],
	     modified:notmod)),
    c_cont:( top:Hand,
             index:Event,
             liszt:[( unspec_loc_rel,
                     handel:Hand,
                      event:e:tense:no_tense,
                      arg:(Event, event_or_index),
                      arg3:Ind)],
	     h_cons:[])).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Licensing Relative Clauses
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%All relative clauses are noninverted finite or infinitive clauses,
%%%specified as posthead:plus and prd:plus.  Unlike other clauses,
%%%they have a nonempty mod value.

rel_cl := (@clause,
    root:minus,
    synsem:local:(cat:(head:(verb,
			     vform:fin_or_inf,
			     inv:minus,
			     prd:plus,
			     tam:mood:strict_ind_or_mod_subj,
			     %(ind_or_mod_subj, strict_sort)
			     mod:(hd:local:(intersective_mod,
					    cont:index:Ind),
				  tl:e_list)),
		       posthead:plus,
		       mc:na),
		  cont:index:Ind,
		  keys:message:e_list, %0-dlist
		  conj:cnil)).

%-------------------------------------------------------------------
% Non-Wh-Relatives
%-------------------------------------------------------------------
%%%Non-wh-relatives are unary phrases, and are non-headed.  Thus, all the
%%%head feature specifications that they want to be passed from daughter
%%%to mother are mentioned explicitly.  Also, since this is not a
%%%head-valence phrase, nonlocal features need not be shared between
%%%mother and daughter.  The mother has an empty slash list and a
%%%nonempty rel list.

%%%The mod value of the mother (structure-shared with that of the
%%%daughter) specifies that the relative clause modifies something with a
%%%nonempty spr list, marked modified:periph:na_or_minus, which means
%%%that it cannot modify an N' already modified by a relative clause
%%%(which will be marked as periph:plus).

non_wh_rel_cl := (@rel_cl,
    non_head_only_phrase,
    synsem:(local:(cat:(head:(vform:Vform,
			      tam:Tam,
			      aux:Aux,
			      inv:Inv,
			      mod:(Mod,
				   hd:(local:(keys:key:Mkey,
					      cat:val:spr:(hd:synsem,
							   tl:e_list),
					      cont:index:Ind),
				       nonlocal:que:e_list, 
				       modified:periph:na_or_minus),
				   tl:e_list)),
			val:(subj:e_list,
			     spr:Spr,
			     comps:e_list)),
		   keys:key:Key),
	    nonlocal:(slash:e_list, 
		      rel:one_list)), 
    non_head_dtr: (synsem:(local:(cat:(head:(verbal,
				       vform:Vform,
				       tam:Tam,
				       aux:Aux,
				       inv:Inv,
				       mod:Mod),
				 val:(spr:Spr,
				      comps:o_list)),
			    cont:top:Top,
			    conj:cnil,
			    keys:(key:Key,
				  message:one_list)), 
		     nonlocal:(slash:(hd:(cat:(head:(noun,
						     prd:minus,
						     mod:e_list),
					       val:comps:e_list),
					  agr:Ind,
					  cont:index:Ind,
					  keys:key:Mkey),
				      tl:e_list),
			       que:e_list, 
			       rel:e_list),
		     modified:rmod)), %notmod_or_rmod & strict_sort
    c_cont:top:Top).


%%%% Finite non-wh-relatives %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%A finite non-wh-relative clause wants to modify an N'

fin_non_wh_rel_cl(Dtr) := (@non_wh_rel_cl,
    fin_non_wh_rel_cl,				 
    non_head_dtr: (Dtr,
	     synsem:local:(cat:(head:(verb,
				      vform:fin,
				      mod:(hd:local:cat: @nbar_cat,
					   tl:e_list)),
				val:subj:(hd:anti_synsem,
					  tl:e_list),
				mc:plus),
			   cont:index:e:tense:real_tense)),
    c_cont:(liszt:e_list,  
	    h_cons:e_list)).   
				 
%%%% Infinitive non-wh-relatives %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%An infinitive non-wh-relative wants to modify something whose key
%%%value is of type nom_temp_nom_rel.  The daughter either has an empty
%%%subj list or is subcategorizing for a pro_ss subject with an empty
%%%slash list (not a pro_gap).

inf_non_wh_rel_cl(Dtr) := (@non_wh_rel_cl,
    inf_non_wh_rel_cl,				 
    synsem:local:cat:head:mod:(hd:local:keys:key:non_temp_nom_rel,
			       tl:e_list),
    non_head_dtr: (Dtr,
	     synsem:local:(cat:(head:(comp,
				      vform:inf),
				val:subj: prolist), 
			   keys:message:one_list),
	     c_cont:(liszt:e_list,
		     h_cons:e_list)),	 
    c_cont:(liszt:e_list, %added this for residues
	    h_cons:e_list)). %ditto

%-------------------------------------------------------------------
% Wh-Relatives and Wh-Interrogatives
%-------------------------------------------------------------------

%%%A basic head-filler phrase is not headed, so it has only a dtrs list.
%%%The left daughter has a local value structure shared with the
%%%item on the slash list of the right daughter, which has a verbal head
%%%and a comps list of type o_list.  

% basic_filler_phrase(FillerDtr,OtherDtr,Mother)
% defined as relation here since the OtherDtr is a head_dtr for one
% and a non_head_dtr2 for the other kind of filler phrases
fun basic_filler_phrase(+,+,-). 
basic_filler_phrase(synsem:(local:(Slash,
                                        local,
					cat:val:(subj:prolist, %functional relation
						 comps:o_list,
						 spr:o_list),
					ctxt:activated:plus),
				 nonlocal:slash:e_list),
			 synsem:(local:cat:(head:(verbal,
						  strict_head:plus),
				                  % strict_type
					    val:comps:o_list),
				 nonlocal:(slash:[Slash],
					   que:e_list,
					   rel:e_list)),
			 (@phrasal,
			     synsem:(local:(cat:(val:(comps:e_list,
						      spr:[anti_synsem]),
						 posthead:plus),
					    conj:cnil),
				     nonlocal:slash:e_list)))
			if true.


%% A) Headed variety

head_filler_phrase *> (basic_filler_phrase(FillerDtr,HeadDtr),
		       non_head_dtr:FillerDtr,
		       head_dtr:HeadDtr,
	               @head_nexus_que_phrase).

head_filler_phrase_fin := (head_filler_phrase,
   synsem:local:cat:val:subj:(o_list,[anti_synsem]),
    head_dtr:synsem:local:cat:( head:( verb, vform:fin_star,
                                              tam:tense:real_tense),
				val:subj:o_list)).

head_filler_phrase_inf := (head_filler_phrase,
   head_dtr:synsem:local:( cat:head:(verbal,vform:inf),
			    keys:message:[hypo_rel])).

filler_head_rule_non_wh(NHdtr,Hdtr) := (filler_head_rule_non_wh, @head_filler_phrase_fin,
                           @head_compositional,@mc_phrase,
   synsem:local:keys:message:Msg,
    head_dtr:(Hdtr,synsem:( local:( cat:( head:( verbal,
						 strict_head:plus,
						 inv:minus), % & strict_type 
                                          mc:plus),
                              keys:message:Msg ),
                      modified:notmod_or_rmod)),
    non_head_dtr:(NHdtr, synsem:( local:cat:head:(n_or_p_or_adv,
						  strict_head:plus),
				                  % & strict_type
				  nonlocal:( que:[], 
					     rel:[])), 
		  robust:minus),
					   c_cont:( liszt:[],
						    h_cons:[])).

filler_head_rule_wh_root(NHdtr,Hdtr) :=  (filler_head_rule_wh_root,@head_filler_phrase_fin,  
                                           @wh_interrog_fin(NHdtr), @mc_phrase,
   synsem:local:cat:head:( inv:plus_star,
                            aux:plus_star),
    head_dtr: (Hdtr,synsem:local:cat:mc:na)).

filler_head_rule_wh_subj(NHdtr,Hdtr) := (filler_head_rule_wh_subj, 
			    @head_filler_phrase_fin, @wh_interrog_fin(NHdtr), 
			    @mc_phrase,
    synsem:local:cat:head:inv:minus,
    head_dtr: (Hdtr,synsem:local:( cat:val:subj:[],
			    keys:message:[_])),	
    non_head_dtr: (NHdtr,synsem:local:cat:head:(noun,case:nom))).

filler_head_rule_wh_nr_fin(NHdtr,Hdtr) := (filler_head_rule_wh_nr_fin,
			      @head_filler_phrase_fin,@wh_interrog_fin(NHdtr),
    synsem:local:cat:( head:inv:minus,
		       mc:minus),
    head_dtr:(Hdtr,synsem:local:keys:message:[_])). 


filler_head_rule_wh_nr_inf(NHdtr,Hdtr) := (filler_head_rule_wh_nr_inf,
			      @head_filler_phrase_inf,@wh_interrog(NHdtr),
   synsem:local:cat:( head:inv:minus,
		       val:subj:[unexpressed],
		       mc:minus),
    head_dtr:(Hdtr,synsem:local:cat:val:subj:[( pro_ss, nonlocal:slash:[])])).

%% B) Non-Headed variety
%%%A relative filler-head construction (wh-relative clause) inherits a
%%%number of head features from the right daughter.  The left daughter
%%%cannot be a conjoined phrase, and must have a nonempty rel value.

filler_head_rule_rel(LDtr,RDtr) := (@rel_cl,
    filler_head_rule_rel,					  
    basic_filler_phrase(LDtr,RDtr),
    synsem:(local:(cat:(head:(vform:Vform,
			      tam:Tam,
			      aux:Aux,
			      inv:Inv,
			      mod:(Mod,
				   hd:local:cont:index:Ind,
				   tl:e_list)),
			val:subj:(Subj,
				  o_list)),
		   keys:key:Key),
	    nonlocal:rel:one_list),
    non_head_dtr:(LDtr,
		  synsem:(local:conj:cnil,
			  nonlocal:(que:e_list,
				    rel:(one_list,
					 hd:index:Ind)))),
    non_head_dtr2:(RDtr,
		  synsem:(local:(cat:(head:(verb,
					    vform:(Vform,
						   fin),
					    tam:Tam,
					    aux:Aux,
					    inv:Inv,
					    mod:Mod),
				      val:subj:Subj,
				      mc:minus),
				 conj:cnil,
				 keys:(key:Key,
				       message:(one_list,
						hd:handel:Mhand))),
			  nonlocal:(que:e_list,
				    rel:e_list))),
    c_cont:(top:Mhand,
	    liszt:e_list,
	    h_cons:e_list)).   

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Coordinate Structures
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

basic_coord_phr
*>
(synsem:(local:(cat:Cat,
		agr:(divisible:minus_star,
		     png:Png)),
	 nonlocal:Nonlocal,
	 lex:Lex,
	 modified:Modif),
 non_head_dtr:(sign,
	    inflected:plus,
	    synsem:(local:(cat:Cat,
			   cont:index:individual,
			   keys:key:independent_rel),
		    nonlocal:Nonlocal,
		    modified:Modif,
		    lex:Lex)),
 non_head_dtr2:(phrase,
	    inflected:plus,
	    synsem:(local:(cat:Cat,
			   cont:index:individual,
			   agr:png:Png,
			   keys:key:independent_rel),
		    nonlocal:Nonlocal,
		    modified:Modif,
		    lex:Lex))).

coord_phr := (basic_coord_phr,
   synsem:local:keys:key:Key,
   non_head_dtr:synsem:local:keys:key:Key).

top_coord_rule := (@coord_phr,
   root:minus,
   synsem:local:(cont:(index:Ind,
		       e_index:Event),
		 conj:cnil,
		 keys:altkey:Altkey),
   non_head_dtr:synsem:local:(local,
			   conj:(conj,Left),
			   cont:e_index:Lind),
   non_head_dtr2:synsem:local:(local,
			   cont:(top:Ctop,
				 index:Ind,
				 e_index:Event),
			   conj:(complex_conj,
				 chead:left:hd:Left),
			   keys:altkey:(Altkey,
					l_index:Lind)),
   c_cont:(top:Ctop,
	   index:(Ind,
		  conj_ind),
	   liszt:[],
	   h_cons:[])).

mid_coord_rule := (@coord_phr,
   root:minus,
   synsem:local:(conj:(phr_conj,
		       chead:Chead),
		 keys:altkey:Altkey),
   non_head_dtr:synsem:local:(conj:(conj,Left),
			   cont:e_index:Lind),
   non_head_dtr2:synsem:local:(cont:(top:Ctop,
				 index:Ind),
			   keys:altkey:l_index:Lind,
			   conj:(complex_conj,
				 chead:(Chead,
					left:[bot,Left]))),
   c_cont:(top:Ctop,
	   index:(Cind,
		  conj_ind),
	   liszt:[(conj_rel,
		   Altkey,
		   c_arg:(Cind,
			  non_expl),
		   r_index:Ind)],
	   h_cons:[])).

top_coord_event_rule(LConjDtr,RConjDtr) := (@top_coord_rule,
   top_coord_event,						  
   synsem:local:(cat:val:comps:o_list,
		 cont:index:conj_event),
   non_head_dtr:(LConjDtr,
	      synsem:local:(cont:top:Lhand,
			    cat:val:spr:[local:keys:key:relation],
			    keys:key:event_or_degree_or_no_rel)),
   non_head_dtr2:(RConjDtr,
	      synsem:local:keys:(key:event_or_degree_or_no_rel,
				 altkey:l_handel:Lhand))).

mid_coord_event_rule(LConjDtr,RConjDtr) := (@mid_coord_rule,
   mid_coord_event,						  
   synsem:local:cont:index:conj_event,
   non_head_dtr:(LConjDtr,
	      synsem:local:(cont:top:Lhand,
			    keys:key:event_rel)),
   non_head_dtr2:(RConjDtr,
	      synsem:local:keys:(key:event_rel,
				 altkey:l_handel:Chand)),
   c_cont:liszt:[(handel:Chand,
		  r_handel:Lhand)]).

nom_coord_rule := (@coord_phr,
   synsem:(synsem,
	   local:(cont:e_index:ref_ind,
		  keys:message:[])),
   non_head_dtr:synsem:local:(cat:(head:(n_or_a,
					 strict_head:plus),
				         %strict_type
				   val:comps:[]),
			      cont:index:ref_ind,
			      agr:divisible:Div),
   non_head_dtr2:synsem:local:(cont:index:ref_ind,
			       agr:divisible:Div)).

top_coord_nom_rule(LConjDtr,RConjDtr) := (@top_coord_rule,
   @nom_coord_rule,
   top_coord_nom,						
   non_head_dtr:LConjDtr,
   non_head_dtr2:RConjDtr).

mid_coord_nom_rule(LConjDtr,RConjDtr) := (@mid_coord_rule,
   @nom_coord_rule,
   mid_coord_nom,						
   non_head_dtr:(LConjDtr,
	      synsem:local:keys:key:basic_nom_rel),
   non_head_dtr2:(RConjDtr,
	      synsem:local:keys:key:basic_nom_rel),
   c_cont:index:png:pn:nonfirstsg).
					
			      
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Macros for test suites
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%These are macros we use in the test suites to specify what kind of
%%%solutions we want.

noSlash := synsem:nonlocal:slash:e_list.

noRel := synsem:nonlocal:rel:e_list.

np := synsem:(local:cat:(head:nominal,
			 val:spr:[]), 
	      nonlocal:slash:[]).			

pp := synsem:local:cat:(head:prep_star,
			   val:comps:[]).

noConj := synsem:local:conj:cnil.

root := (phrase,
   inflected:plus,
    root:minus,
    robust:minus,
    posscl:minus,
    synsem:(  local:( cat:( head:( verbal,
                                 tam:ind_or_mod_subj_tam),
                           val:( subj:o_list,
                                 spr:o_list,
                                 comps:o_list),
                           mc:plus),
                     cont:index:e:tense:real_tense,
		      keys:message:one_list, %otherwise clausal mod. solutions
                     conj:cnil),
              nonlocal:( slash:[],
                         rel:[],
                         que:[]))).
