%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  $RCSfile: theory.pl,v $
%% $Revision: 1.34 $
%%     $Date: 2004/01/02 04:47:30 $
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%   Milca English Resource Grammar (MERGE) for the Trale system
%%
%%   Authors: Kordula De Kuthy, Vanessa Metcalf, Detmar Meurers  
%%            Department of Linguistics, The Ohio State University 
%%            http://ling.osu.edu/~dm/merge/
%%
%%            Based on the English Resource Grammar (ERG)
%%            Version of Jan 16, 2002, developed at CSLI, Stanford
%%            University by Dan Flickinger in collaboration with 
%%            colleagues on the German Verbmobil project and with 
%%            member institutions of the the LinGO consortium, cf.
%%            http://lingo.stanford.edu/
%%
%%   Main theory file loading grammar and some declarations.
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% ------------------------------------------------------
% Include some definitions to allow Gerald to run the grammar 
% without loading the Milca TRALE environment:

:- (  current_predicate(user:phon_feat_/1)
   -> true
   ;  assert(user:phon_feat_(phon)),
      op(850,xfy,<<<),
      op(850,fx,<<<),
      op(850,fx,>>>)
   ).

% ------------------------------------------------------

% Load mapping of extra-logical string/tree to fs
:- [ps_mapping].

% load lexicon and lexical macros
:- [lexicon].
:- [lex_macros].

% load lexical rules
:- [lexrules].

% load principles and fundamental constraints
:- [principles].

% load phrase structure rules and macros/phrasal principles
:- [ps_rules].
:- [syntax].

% load a test sequence (trale test suites, used if one doesn't start itsdb)
:- [csli_items].

% load tokenization rules for parsing ordinary strings and atoms
:- [tokenization].

% Declare which signature file to use
signature(signature).


% -----------------------------

% Declare which features to hide in display:
hidden_feat(dtrs).      % hide the dtrs attribute (shown by tree)
hidden_feat(head_dtr).  % hide the head_dtr attribute (shown by tree)
hidden_feat(non_head_dtr). % hide the non_head_dtr attribute ("")

% Declare the order in which features of a type are shown
% if nothing is declared, features are ordered alpabetically
>>> phon.        % show phon as first feature
phon <<< synsem.   
synsem <<< c_cont.


% Declare some features and paths for specialized output of mrs
% semantics (used by print_mrs/0)
pred_feat(specific_name).
ind_feat(index).
cont_path([synsem,local,cont]).

% Declare version and root symbols for tsdb test suites (and go/0)
grammar_version('Merge v-1-0-0').
root_symbol(@root).
imp_symbol(@root). 
decl_symbol(@root).
que_symbol(@root).
