%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  $RCSfile: lex_macros.pl,v $
%% $Revision: 1.73 $
%%     $Date: 2004/01/02 03:39:11 $
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%   Milca English Resource Grammar (MERGE) for the Trale system
%%
%%   Authors: Kordula De Kuthy, Vanessa Metcalf, Detmar Meurers  
%%            Department of Linguistics, The Ohio State University 
%%            http://ling.osu.edu/~dm/merge/
%%
%%            Based on the English Resource Grammar (ERG)
%%            Version of Jan 16, 2002, developed at CSLI, Stanford
%%            University by Dan Flickinger in collaboration with 
%%            colleagues on the German Verbmobil project and with 
%%            member institutions of the the LinGO consortium, cf.
%%            http://lingo.stanford.edu/
%%
%%   Macros for lexical specification 
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile ':='/2.


lex_synsem := (canonical_synsem, 
                  lex:plus_star, % for coordination
		  local:(cat:val:(subj:Subj,
				  spr:Spr,
				  comps:Comps),
			 arg_s: valence_append(Subj,Spr,Comps))).	

phr_synsem := (canonical_synsem, 
                  lex:minus_star). % for coordination



% could also be encoded as type under sign
non_affix_bearing := (non_derived_word,
                         inflected:plus).

%%%%%%%%%%%%%%%%%%%%%%%%%%

nonslash := (non_derived_word,
                synsem:nonlocal:slash:e_list).  

nonque := (non_derived_word,
              synsem:nonlocal:que:e_list).   

nonrel :=  (non_derived_word,
               synsem:nonlocal:rel:e_list).   

nonconj := (non_derived_word,
               synsem:local:conj:cnil).

mcna := (non_derived_word,
            synsem:local:cat:mc:na).

nonmsg := (non_derived_word,
             synsem:local:keys:message:e_list).

topkey := (non_derived_word,
              synsem:local:( keys:key:Key,
                             cont:topkey:Key) ).

hc_to_phr := (non_derived_word,
                 synsem:local:cat:hc_lex:minus_star). % for coordination

basic_nontopkey := (@nonconj, @nonslash, @nonrel,
                       @mcna, @non_affix_bearing).

nontopkey := (@basic_nontopkey, @nonque, @nonmsg).

hcons_amalg_word := (@mcna,
                        @nonconj,
                        @nonmsg,
                        @topkey,
                        @hc_to_phr).

basic_norm_word := (@hcons_amalg_word, @nonque, @nonslash,
			  @nonrel).

basic_norm_no_affix_word := (@basic_norm_word,@non_affix_bearing).

norm_word := (@basic_norm_word,
   synsem: @lex_synsem).

norm_no_affix_word := (@norm_word, @non_affix_bearing).

norm_mod_no_affix_word := (@nonconj,@nonslash,@nonrel,@mcna,@topkey,
		 @non_affix_bearing,
    synsem: (@lex_synsem,
	     local:( cat:head:mod:[(local:keys:message:Msg)],
		      keys:message:Msg))).

norm_mod_nonque_no_affix_word := (@norm_mod_no_affix_word,@nonque).

basic_mod_no_affix_notopkey_word := (@nonconj,@nonslash,@nonrel,
		                     @non_affix_bearing).


norm_mod_no_affix_notopkey_word := (@basic_mod_no_affix_notopkey_word,
    synsem:( @lex_synsem,
	     local: ( cat:head:mod:[ ( local:keys:message:Msg ) ],
		      keys:message:Msg ) ) ).

que_word := (@nonconj,
                @non_affix_bearing,
                @mcna,
                @nonslash,
                @nonrel,
                @hc_to_phr,
                @nonmsg).

rel_word := (@nonque,
		@non_affix_bearing,
		@mcna,
		@nonslash,
		@nonconj,
		@nonmsg,
		@topkey,
		@hc_to_phr).

%%% added for wsj
%%%pseudocleft_word := (@nonque,
%%%			@nonrel,
%%%			@nonslash,
%%%			@non_affix_bearing,
%%%			@mcna,
%%%			@nonslash,
%%%			@nonconj,
%%%			@nonmsg,
%%%			@topkey,
%%%			@hc_to_phr).

msg_word := (@nonque,@non_affix_bearing,
            @nonrel,
            @nonconj,
            @hc_to_phr).


% These are exactly the same.
hcons_amalg_basic_affixed_word := (@hcons_amalg_word,inflected:minus).
hcons_amalg_affixed_word := (@hcons_amalg_word, inflected:minus).

hcons_amalg_non_affixed_word := (@hcons_amalg_word,@non_affix_bearing).


amalg_word := (@mcna,
		  @nonconj,
		  @nonmsg,
		  @non_affix_bearing,
		  @topkey,
		  @hc_to_phr).

msg_amalg_word := (@nonconj,
                      @non_affix_bearing, 
                      @topkey,
                      @hc_to_phr).

hc_word := (% word_or_lexrule,
  synsem:(local:(cat:mc:na,
		 cont:topkey:Key,
		 keys:(key:Key,
		       message:e_list),
		 conj:cnil),
	  nonlocal:(que:e_list,
		    rel:e_list,
		    slash:e_list)),
   root:minus,
   posscl:minus).		  

que_nolabel_word := (@nonconj,
   			   @mcna,
			   @nonslash,
			   @nonrel,
			   @nonmsg,
			   @hc_to_phr,
			   inflected:plus).

%% In ERG this is used for slash amalgamation on words
%% since there are no relations (e.g. append) in
%% lkb, this is done with difference list encoding
%% we can formulate a general constraint on words (or synsems)

% whenever basic_one_arg, basic_two_arg, etc, occurs, we probably need
% to use the macros one_arg, two_arg, etc. The corresponding types are
% subtypes of the basic_ types and can therefore be inferred from the
% general types, whereas our macros cannot.

zero_arg :=
   ( local:cont:h_cons:e_list).

basic_one_arg := canonical_synsem. %amalgamating_synsem.

one_arg := (@basic_one_arg,
    local:cont:h_cons:e_list).

basic_two_arg := @lex_synsem.  %amalgamating_synsem

two_arg := (@basic_two_arg,
   local:cont:h_cons:e_list).

basic_three_arg := @lex_synsem.  %amalgamating_synsem

three_arg := (@basic_three_arg,
   local:cont:h_cons:e_list).

four_arg := local:cont:h_cons:e_list. %amalgamating_synsem


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% SUBCATEGORIZATIONS -- synsems for verbs, adjectives, prepositions,
%% nouns
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

nomod_synsem := (@lex_synsem,
                    local:cat:(head:mod:e_list,
                               val:subj:e_list)).

%scopal_mod := local.		%local_min

%intersective_mod := local. %%local_min
%%%These specifications have been moved from nomp_cat.
nomp_cat_min := (cat, %%cat_min.
    head:( nominal,strict_head:plus,
           poss:minus,
           tam:mood:ind_or_mod_subj ),
    val:( subj:o_list,%% *olist*,
          spr:o_list,%% *olist*,
          comps:e_list),
    mc:na_or_minus).   		    

nomp_cat := @nomp_cat_min.

%%% Moved nom specification from nomp_cat_nom.
nomp_cat_nom_min := (@nomp_cat_min,
   head:case:nom).			

%%% Moved acc specification from nomp_cat_acc.
nomp_cat_acc_min := (@nomp_cat_min,
   cat,
   head:(mobile:plus,
	 case:acc)).  %nominal, strict_head:plus, %mobile:plus
	 %in erg -- expanded type np_cat_acc specifies head type
	 %glbtype1072 (partn_mobile,noun_acc)

nomp_cat_nom := (@nomp_cat_nom_min,@nomp_cat).

nomp_cat_acc := (@nomp_cat_acc_min, @nomp_cat). 

np_cat_nom_min := @nomp_cat_nom_min.
np_cat_acc_min := @nomp_cat_acc_min.%redundant -- only nomp_cat_acc_min needed.

np_cat_nom := (@nomp_cat_nom,@np_cat_nom_min).
%%%               head:noun  is redundant.

np_cat_acc := (@nomp_cat_acc,@np_cat_acc_min).
%%%               head:noun is redundant.

s_cat_unspec := 
  ( head: (verbal, strict_head:plus), % & strict_type,
    val: (subj:o_list,
          comps:o_list)).

s_cat_v_c := (@s_cat_unspec,
    head:inv:minus,
    val:spr:o_list,
    mc:minus).

s_cat_fin_or_inf_unspec := (@s_cat_unspec,
    head:vform:fin_or_inf).

s_cat_fin_unspec := (@s_cat_fin_or_inf_unspec,
    head: (vform:fin,
           tam: (ind_or_mod_subj_tam,
                 tense:real_tense))).

s_cat_inf_unspec := (@s_cat_fin_or_inf_unspec,
    head: (vform:inf,
           tam:ind_or_mod_subj_tam)).

s_cat_fin_or_inf_v_c := (@s_cat_v_c,@s_cat_fin_or_inf_unspec,
    head:tam:mood: (ind_or_mod_subj,strict_sort)).

s_cat_fin_v_c := (@s_cat_v_c,@s_cat_fin_unspec,
    head:tam:mood: (ind_or_mod_subj,strict_sort)).

s_cat_inf_v_c := (@s_cat_v_c,@s_cat_inf_unspec,
    head:tam:mood: (ind_or_mod_subj,strict_sort)).

s_cat := (@s_cat_unspec,
   head:verb).

s_cat_fin := (@s_cat, @s_cat_fin_unspec,
   head:inv:minus,
    mc:plus ).

s_cat_fin_or_imp := (@s_cat,
    head: (vform:fin_or_imp,
	   tam:mood:ind_or_mod_subj),
    mc:plus).

n_or_v_cat := (cat,
    head:(nominal_or_verbal,strict_head:plus), 
    val:(spr:[(synsem_min,local:keys:key:quant_or_deg_rel)],
         comps:o_list)).

vp_cat := (@n_or_v_cat,
    head:(verbal,
	  inv:minus),
    val:subj:[synsem_min],
    mc:na).

vp_inf_cat := (@vp_cat,
    head: (vform:inf,
	   prd:minus)).

%%%Created for the wsj_lexicon
%vp_prp_cat := (@vp_cat,
%   head:(vform:prp,
%	 prd:minus)).

vp_bse_unspec_cat := (@vp_cat,
    head: (verb,
	   vform:bse_only,
	   prd:minus)).

vp_bse_cat := (@vp_bse_unspec_cat,
    head:tam:mood:indicative).

nbar_cat := (@n_or_v_cat,
    head:(noun,
          poss:minus),
    val:(subj:e_list,
         spr:[synsem],
         comps:e_list),
    mc:na).

adverbee_cat := (cat,
   head:(adverbee,strict_head:plus )).		%, strict_type

%Only subtype, prd_cat.  Used in one desc.
basic_prd_cat := (cat,
    head:( strict_head:plus, 
           prd:plus),
    val: (subj:[synsem],
          spr:o_list, 
          comps:o_list), 
    mc:na ).

%No subtypes.  Used in descs.
prd_cat := (@basic_prd_cat,
    head:tam:tense:no_tense).

%No subtypes.  Used in descs.
pp_cat := 
   (head: (prep_or_modnp, prd:minus),
    val: (spr:o_list,
          comps:[]),
    mc:na).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Linking Types
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

linking_type := @lex_synsem.

atrans_lt := (@linking_type,
   local:(cat:val:subj:[local:(local_min,
			       cont:index:it_ind)],
	  keys:key:no_role_rel)).

arg1_subj_lt := (@linking_type,
    local: (cat:val:subj:[  (local: (local_min, %local_min
                                     cont:index: (Subjind,non_expl_ind),
                                     keys:key:nom_rel,
                                     agr:divisible:strict_bool ))], %%strict_sort
            keys:key: (arg1_rel, arg:Subjind))).

unacc_lt := (@linking_type,
   local: ( cat:val:subj:[ ( local:( local_min, 
                                    cont: ( index:(Subjind, 
                                                  non_expl_ind )),
                                     agr:divisible:strict_bool ) ) ], %strict_sort
            keys:key:( arg3_event_rel,  arg3:Subjind ) ) ).

basic_arg13_lt := (@arg1_subj_lt, 
    local: (cat:val:comps:hd:local: (local_min, %local_min
                                     cont:index: (Objind,non_expl_ind )),
            keys:key: (arg13_rel,arg3:Objind))).

arg13_lt := (@basic_arg13_lt,
    local: (cat:val:comps:hd:local:cont:top:Top,
            cont:top:Top)).

trans_lt := @basic_arg13_lt.

%%%I added @basic_arg12_lt and @arg12_lt to differentiate passivizable
%%%from non-passivizable verbs semantically, rather than by a (synsem)
%%%type distinction, as in ERG.  They are modelled directly after
%%%@basic_arg13_lt and @arg13_lt.  VM 9.27.03

basic_arg12_lt := (@arg1_subj_lt,
   local:(cat:val:comps:[local:(local_min,
				cont:index:(Objind,
					    non_expl_ind))],
	  keys:key:(arg12_rel,
		    arg2:Objind))).

arg12_lt := (@basic_arg12_lt,
   local:(cat:val:comps:[local:cont:top:Top|_],
	  cont:top:Top)).

arg14_lt := (@arg1_subj_lt, 
   local: ( cat:val:comps:hd: ( local:( local_min,
				     keys: ( key:verb_aspect_rel,
					     message:list),   
				      cont:top:Mhand ) ),
	    keys:key:( arg14_rel,  arg4:Mhand ) ) ).

%%%Changed from arg13_rel to arg12_rel to distinguish between trans_subst
%%%and non transitives--input to the passive lr.
poss_lt := (@linking_type,         
    local:( cat:val:( subj:[( local:(local_min,
				      cont:index:(Subjind,ref_ind)))],
		      comps:hd: 
                       ( local:( local_min,
                                cont:index:(Objind,ref_ind)))),
	    cont:liszt:[( arg12_rel, 
                         arg:Subjind,
                          arg2:Objind)])).

ditrans_lt := (@arg1_subj_lt,
    local: (cat:val:comps:(hd:(local:(local_min, %local_min
                              cont:(top:Top,
                                    index:(Obj2ind,non_expl_ind)))), 
                           tl:hd:(local:(local_min, %local_min
                                cont:(top:Top,
                                      index:(Objind,non_expl_ind))))),
            cont:top:Top,
            keys:key:(arg123_rel, arg2:Obj2ind,
                                  arg3:Objind))).

tritrans_lt := (@ditrans_lt,
    local: (cat:val:comps: [_,_, % top,top,
                            ( local:(local_min,
                                   keys: (key:v_event_rel,
                                          message:one_list),  
                                   cont:top:Mhand))],
            keys:key: (arg1234_rel,arg4:Mhand))).

%%%Added for wsj
%tritrans_prep_lt := (@ditrans_lt,
%   local:(cat:val:comps:[_,_,
%			 (local:(local_min,
%				 keys:key:(prep_rel,
%					   arg3:Arg)))],
%	  keys:key:(arg1234_rel,
%		    arg4:Arg))).

basic_prep_intrans_lt := (@linking_type,
   local: ( cat:val:comps:hd:
			 ( local:( local_min,
				   cat:head:tam:tense:no_tense,
                                    keys:key:( prep_rel, independent_rel),
				    cont:index:Index ) ),
	    cont: ( index:Index,
		   liszt:hd:Key ),
	    keys:key:Key ) ).

prep_intrans_unerg_lt := (@basic_prep_intrans_lt, @arg1_subj_lt).
prep_intrans_lt := (@prep_intrans_unerg_lt,
   local: ( cat:val:comps:hd: ( local:cont:top:Top ),
            cont: ( top:Top,
                   liszt:[ relation] ) ) ).

empty_prep_intrans_lt := (@arg1_subj_lt,
    local: (cat:val:comps:hd:local: (local_min,
                                       keys:key: (prep_rel,selected_rel,
                                                      arg3:Objind),
                                        cont:top:Top),
            cont:top:Top,
            keys:key: (arg13_rel,arg3:Objind ))).

basic_prep_trans_lt := (@arg13_lt,
    local: (cat:val:comps:(hd:synsem,
                           tl:hd:(local: (local_min,
                                      cat:head: (mod:[(synsem_min)],
                                                 tam:tense:no_tense),
                                      keys:key: (prep_rel,independent_rel)))),
            cont:liszt:hd:Key,
            keys:key:Key)).

prep_trans_lt := (@basic_prep_trans_lt,
   local:( cat:val:comps:(hd:( local:cont:index:Objind), 
                          tl:(hd:local:cont:( top:Ctop,
                                          index:Objind))),
            cont:( liszt:[relation, (hypo_rel, handel:Hand,
                                                   soa:Arghand)],
                   h_cons:[( qeq, sc_arg:Arghand,
                                     outscpd:Ctop)]),
            keys:key:arg4:Hand)).

prep_trans_nomsg_lt := (@basic_prep_trans_lt,
    local: (cat:val:comps:(hd:synsem,
                           tl:hd: (local:cont:(top:Ctop,
                                               index:Index))),
            cont: (top:Ctop,
                   index:Index,
                   liszt:[(relation)],
                   h_cons:[]))).

empty_prep_trans_lt := (@arg13_lt,
   local:(cat:val:comps:[bot,
			 (local:(local_min,
				 keys:key:(prep_rel,
					   selected_rel,
					   arg3:Objind),
				 cont:top:Top))|_],
	  cont:top:Top,
	  keys:key:(arg123_rel,
		    arg2:Objind))).

empty_prep_trans_of_lt := (@arg13_lt,
   local:(cat:val:comps:[_,
			 (local:(local_min,
				 keys:key:(prep_rel,
					   %selected_rel, does not
					   %unify with x_of_rel
					   arg3:Objind),
				 cont:top:Top))|_],
	  cont:top:Top,
	  keys:key:(arg123_rel,
		    arg2:Objind))).

prd_comp_lt := (@linking_type,
    local: (cat:val: (subj:[(local:cont:nom_obj)],
                      keycomp:local: (cont:top:Chand,
                                      keys:key:independent_rel)),
            cont: (liszt:[Key, (hypo_rel,handel:Arghand,
                                               soa:Soa)],
                   h_cons:[ (qeq, sc_arg:Soa,
                                     outscpd:Chand)]),
            keys:key: (Key, arg4:Arghand))).


basic_prep_particle_intrans_lt := (@arg1_subj_lt,
   local:(cat:val:comps:[bot,
			 (local:(local_min,
				 cat:head:tam:tense:no_tense,
				 keys:key:(prep_rel,
					   arg3:Arg3),
				 cont:(top:Top,
				       index:Event)))|_],
	  cont:top:Top,
	  keys:key:(arg13_rel,
		    event:Event,
		    arg3:Arg3))).

prep_particle_intrans_lt := (@basic_prep_particle_intrans_lt,
   local:cat:val:comps:[synsem,
			(local:keys:key:independent_rel)]).

%wsj
%cp_trans_lt := (@arg13_lt,
%   local:(cat:val:comps:[bot,
%			 (local:(local_min,
%				 keys:(key:v_event_rel,
%				       message:[_]),
%				 cont:top:Mhand))|_],
%	  keys:key:(arg134_rel,
%		    arg4:Mhand))).

pp_cp_lt := (@empty_prep_intrans_lt,
    local: (cat:val:comps:tl:[local:(local_min,
                                   keys: (key:v_event_rel,
                                           message:one_list),  
                                    cont:top:Mhand)],
            keys:key: (arg134_rel,arg4:Mhand))).

double_pp_lt := (@arg1_subj_lt,
   local: ( cat:val:comps:(hd: ( local:( local_min,
				     cat:head:tam:tense:no_tense,
                                      keys:key:( prep_rel, independent_rel),
				      cont: ( top:Top,
					     index:Event ) ) ), 
			    tl:hd:( local:( local_min,
				     cat:head:tam:tense:no_tense,
                                      keys:key:( prep_rel, independent_rel),
                                      cont: ( top:Top,
                                             index:Event ) ) )),
	    cont: ( top:Top,
		   index:Event ) ) ).

s_equi_lt := (@linking_type,
   local:( cat:val:subj:[( local:(local_min,
				   cont:( top:Top,
					  index:(Index,ref_ind))))],
	    cont:top:Top,
	    keys:key: (arg14_rel,arg:Index))).
		   

equi_prd_lt := (@linking_type,
   local:( cat:val:keycomp:local:( keys:key:independent_rel,
				      cont:e_index:Event),
	    cont:liszt:[relation],
	    keys:key:arg4:Event)).


subj_equi_lt := (@s_equi_lt,
   local:cat:val:( subj:[( local:cont:index:Index)],
		   keycomp:local:(local_min,
				     cat:val:subj: 
                                       [( local:cont:index:Index,
                                           nonlocal:slash:[])]))).	 

% 'try to leave'
subj_equi_inf_lt := (@subj_equi_lt,
   local:( cat:val:keycomp:local:(local_min,
				     keys:message:[hypo_rel],
                                      cat:val:subj:[pro_ss],
				      cont:top:Hand),
	    keys:key:arg4:Hand)).

subj_equi_prp_or_bse_lt := (@subj_equi_lt,
   local: ( cat:val:keycomp:local:( local_min,
				     cont:top:Hand ),
	    cont: ( liszt: [ relation, (hypo_rel,  handel:Chand,
                                                   soa:Shand )],
                   h_cons: [( qeq,
			    sc_arg:Shand,
			     outscpd:Hand ) ] ),
	    keys:key:arg4:Chand ) ).

obj_equi_lt := (@arg1_subj_lt,
   local:( cat:val:( comps:[( local:( local_min,
				     cont:index:(Index,non_expl_ind ))),
			      (Comp,
			       local:( local_min,
				       cat:val:subj: 
					 [( pro_ss,
                                            local:cont:index:Index,
                                             nonlocal:slash:[])]))],
		      keycomp:Comp),
	    keys:key:(arg134_rel, arg3:Index))).

obj_equi_inf_lt := (@obj_equi_lt,
   local:( cat:val:keycomp:local:( local_min,
				     cont:top:Hand,
				      keys:message:one_list ), 
	    keys:key:arg4:Hand)).

obj_equi_prd_lt := (@prd_comp_lt, @obj_equi_lt,
   local:cat:val:comps:[ ( local:( local_min,
				   keys:key:basic_nom_rel,
				    cont:index:Index ) ),
			  ( local:( local_min,
				   cat:val:subj:
                                    [ (pro_ss,
                                       local:( local_min,
                                              cont:index:Index ),
                                        nonlocal:slash:[] ) ] ) ) ] ). 

anom_equi_lt := (@s_equi_lt,
   local:( cat:val: 
		   ( subj:[( local:cont:index:Subjind)],
		     comps:[( local:( local_min,
				  cont:( top:Top,
                                          index:(Objind,non_expl_ind)))),
			     ( local:(local_min,
				 cat:val:subj:[( pro_ss,
						  local:(local_min,
						    cont:index:Subjind),
                                                   nonlocal:slash:[])],
				  keys:message:list,  
				  cont:top:Hand))]),
	    cont:top:Top,
	    keys:key:( arg134_rel,
		     arg4:Hand,
		      arg3:Objind ))).

basic_ssr_expr_lt := (@linking_type,
   local: ( cat:val:keycomp:local:cont:top:Chand,
	    cont:h_cons: [( qeq,
			    sc_arg:Arghand,
			     outscpd:Chand )],
	    keys:key:( arg24_event_rel, arg4:Arghand ) ) ).


ssr_expr_lt := (@basic_ssr_expr_lt,
   local: ( cat:val: (keycomp:Comp,
		      comps:(hd:( local:keys:key:arg3:Arg4 ), 
			      tl:hd:Comp )),
	    keys:key:arg2:Arg4 ) ).


ssr_prdp_expr_lt := (@basic_ssr_expr_lt,
   local: ( cat:val: ( subj:[ ( local:cont:nom_obj ) ],
                      keycomp:Comp,
                      comps:(hd:Comp,
                             tl:hd:(  local: ( keys:key:(x_to_rel_s,
                                                  arg3:Arg2 ),
                                        cont:top:Top ) ))),
            cont: ( top:Top,
		   liszt:[Key] ),
	    keys:key:(Key,  arg2:(Arg2, non_expl_ind) ) ) ).

sor_lt := (@linking_type,
   local: ( cat:val: ( subj:[ ( local:( local_min,
				      cont: ( top:Top,
					      index:Index ) ) ) ],
                      comps:[ (synsem,  local:( local_min,
                                                cont:top:Top ) ), 
                              ( local:( local_min,
                                       cont:top:Chand ) ) ] ),
	    cont: ( top:Top,
		   h_cons: [( qeq,
			    sc_arg:Arghand,
			     outscpd:Chand ) ] ),
	    keys:key:( arg14_rel,  arg4:Arghand,
				   arg:Index ) ) ).

expl_it_subj_lt := (@linking_type,
   local: ( cat:val: ( subj:[ ( local:( local_min,  cont: ( top:Hand,
							  index:it_ind ) ) ) ],
		      comps:(hd:synsem,tl:hd:Comp),
		      keycomp:(Comp, 
			    local:( local_min,
				    keys:message:list,
				     cont:top:Chand ) ) ),
	    cont:h_cons:[ ],
	    keys:key:( arg4_rel,
		     handel:Hand,
		      arg4:Chand ) ) ).

expl_it_subj_pp_cp_lt := (@expl_it_subj_lt,
   local: ( cat:val:comps:hd:( local:( local_min,
                                     keys:key:arg3:Arg2 ) ),
            keys:key:( arg24_event_rel,
		     arg2:Arg2 ) ) ).

particle_np_lt := (@arg1_subj_lt,
    local:( cat:val:comps:[( local:( cont:top:Top,
                                      keys:key:selected_rel)),
                            ( local:(local_min,
				   cont:index:(Index, 
                                               non_expl_ind)))|_],
            cont:top:Top,
	    keys:key:(arg13_rel,arg3:Index))).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Val Types
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%% Valence macros (from valence types)

valence_type := canonical_synsem.

unsat_subst := (@valence_type,
                local:cat:val:subj:[(synsem_min,local:(cat: @nomp_cat, %@nomp_cat_min
                                                   conj:cnil))]).

intrans_subst := (@unsat_subst,@one_arg,
                     local:cat:val:comps:e_list).

unsat_two_arg_subst := (@unsat_subst,
    local:(cat:val:comps:hd:(synsem,(local:(local_min,keys:key:Ckey))), %local_min
           keys:compkey:Ckey)).

two_arg_subst := (@unsat_two_arg_subst,
    local:cat:val:comps:tl:e_list).


trans_subst := (@unsat_subst,
    local:cat:val:comps:hd:(synsem,  (local:(cat: @nomp_cat_acc, %@nomp_cat_acc_min
                                             conj:cnil) ))) .
% We must use nomp_cat_acc here insted of the less specific
%     nomp_cat_acc_min that is used in LKB. With the type hierarchy
%     below nomp_cat the most specific type is correctly inferred, but
%     with our macro hierarchy this would not happen. And we need to
%     have this specific macro here to ensure that the NP on the comps
%     list is saturated, i.e. spr:e_list.


np_trans_subst := (@trans_subst,@two_arg_subst,@two_arg,
    local:cat:val:comps:[synsem] ).

non_trans_subst := (@unsat_two_arg_subst,
    local:cat:val:comps:hd:(synsem,local: (keys:message:e_list,  
                                           conj:cnil))).
  
np_non_trans_subst := (@non_trans_subst,@two_arg_subst, 
    local:cat:val:comps:[(synsem,local:cat: @nomp_cat_acc)]). %nomp_cat_acc_min

basic_cp_intrans_subst := (@two_arg_subst,
    local:cat:val: (keycomp:Comp,
                    comps:[(Comp,synsem,
                             local: ( cat: @s_cat_v_c,
                                      conj:cnil))])).

cp_intrans_subst := (@basic_cp_intrans_subst,
   local:cat:val:keycomp:local:cat:head:tam:tense:real_tense ).

prep_intrans_subst := (@two_arg_subst, 
    local:cat:val:comps:[ (synsem,
                           local: (cat: @pp_cat,
                                   conj:cnil))] ).

unsat_three_arg_subst := (@unsat_two_arg_subst,
    local:( cat:val:comps:(hd:synsem, 
                           tl:hd:(local: (local_min, %local_min
                                           keys:key:Ckey))),
            keys:ocompkey:Ckey)).


three_arg_subst := (@unsat_three_arg_subst,@three_arg).

basic_three_arg_subst := (@unsat_three_arg_subst,@basic_three_arg).

three_arg_trans_subst := (@unsat_three_arg_subst,@three_arg,@trans_subst).

basic_three_arg_trans_subst := (@unsat_three_arg_subst, @basic_three_arg,
                               @trans_subst).

three_arg_nontrans_subst := (@unsat_three_arg_subst, @three_arg,
				@non_trans_subst).

three_arg_nontrans_raising_subst := (@unsat_three_arg_subst, @basic_three_arg,
   local:cat:val:comps:hd: (synsem,  local: ( cat: @nomp_cat_acc, %nomp_cat_acc_min
					     keys:message:[],  
					     conj: cnil ) ) ).

prep_trans_subst := (@basic_three_arg_trans_subst, 
    local:cat:val:comps: [(synsem,  local: ( cat: @nomp_cat_acc, %nomp_cat_acc_min
                                             keys:message:[],  
                                             conj:cnil)), 
                          (synsem,
                           local: ( cat: @pp_cat,
                                    conj:cnil))]).

prep_non_trans_subst := (@three_arg_nontrans_subst, 
			    local:cat:val:comps: [(@lex_synsem,
						   local:(cat: @nbar_cat,
							  keys:message:[], 
							  conj:cnil),
						   lex:plus), 
						  (synsem,
						      local:(cat: @pp_cat,
							     conj:cnil))]).

prd_non_trans_subst := (@basic_three_arg_subst, @non_trans_subst,
   local:cat:val:comps:[ (synsem,  local: ( cat: @nomp_cat_acc, %nomp_cat_acc_min,
					     keys:message:[],  
					     conj:cnil ) ), 
			  (synsem, 
			   local: ( cat: (@basic_prd_cat,
                                         head:mod:
                                          [ ( local:keys:key:norm_relation )]),
                                    conj:cnil ) ) ] ).

ditrans_subst :=  (@three_arg_trans_subst, 
   local:cat:val:comps:[ (synsem, local:( cat: @nomp_cat_acc,
                                          keys:message:e_list, % 
                                          conj:cnil ) ), 
                         (synsem, local:( cat: @nomp_cat_acc,
                                          conj:cnil,
                                          keys:message:e_list ) ) ] ).  

%wsj
%cp_trans_subst := (@three_arg_trans_subst,
%   local:cat:val:(keycomp:Comp,
%		  comps:[(synsem,
%			  local:(cat: @nomp_cat_acc_min,
%				 keys:message:[],
%				 conj:cnil)),
%			 (synsem,
%			     Comp,
%			     local:(cat: @s_cat_v_c,
%				    conj:cnil))])).
			     
pp_cp_subst := (@three_arg_subst,
    local:cat:val: (keycomp:Comp,
                    comps:[% synsem &
                            (local: (cat: @pp_cat,
                                     conj:cnil)),
                            (Comp,% & synsem &
                             local: (cat: @s_cat_fin_v_c,
                                     conj:cnil))])).

np_comp_subst := (@three_arg_trans_subst, 
   local:cat:val:comps:[ (synsem,  local: ( cat: @nomp_cat_acc, %nomp_cat_acc_min
					     keys:message:[],  
					     conj:cnil ) ),
			  ( local:( local_min,
				  cat: ( head:( prep, tam:tense:no_tense ),
                                         val: ( subj:[ synsem ],
					       comps:o_list ) ) ) ) ] ).

double_pp_subst := (@three_arg_subst, 
   local:cat:val:comps:[ (synsem,
			   local: ( cat: @pp_cat,
				    conj:cnil ) ), 
			  (synsem,
			   local: ( cat: @pp_cat,
				    conj:cnil ) ) ] ).

inf_or_prp_intrans_subst := (@unsat_two_arg_subst,
   local:cat:val: (keycomp:Comp,
		    comps:[(Comp,synsem,
			     local:( cat: (@vp_cat,
					   head:vform:inf_or_prp),
                                      cont:index:e:tense:no_tense,
                                      conj:cnil))] )).

inf_intrans_subst := (@inf_or_prp_intrans_subst,
   local:cat:val:comps:[( local:(local_min,
				  cat:head:vform:inf))]).

inf_trans_subst := (@three_arg_trans_subst,
   local:cat:val:( keycomp:Comp, 
		    comps:[_,(Comp,synsem,
			            local:( cat: @vp_inf_cat,
					     conj:cnil))])).

inf_trans_raising_subst := (@basic_three_arg_trans_subst,
   local:cat:val: ( keycomp:Comp, 
		    comps:[_, 
			    (Comp, synsem,
			     local: ( cat: @vp_inf_cat,
				      conj: cnil ) ) ] ) ).

prp_trans_raising := (@basic_three_arg_trans_subst,
   local:cat:val: ( keycomp:Comp, 
		    comps:[_, 
			    (Comp, synsem,
			     local: ( cat: @vp_prp_cat,
				      conj: cnil ) ) ] ) ).

prp_intrans_subst := (@inf_or_prp_intrans_subst, @basic_two_arg,
   local:cat:val:comps:[ ( local:( local_min,
				   cat:head:vform:prp ) ) ] ).

bse_intrans_subst := (@unsat_two_arg_subst, @basic_two_arg,
   local:cat:val: (keycomp:Comp,
		    comps:[ (Comp, synsem,
			     local: ( cat:(@vp_cat,
					   head:vform:bse ),
                                      cont:index:e:tense:no_tense,
                                      conj: cnil ) ) ] ) ).

bse_nontrans_raising_subst := (@three_arg_nontrans_raising_subst, 
   local:cat:val:comps:[_, 
			  (synsem,
			   local: ( cat: @vp_bse_cat,
				    conj: cnil ) ) ] ).

inf_non_trans_subst := (@basic_three_arg_subst,@non_trans_subst,
   local:cat:val:( keycomp:Comp,
		    comps:[( synsem, local:cat: @nomp_cat_acc), %nomp_cat_acc_min
			    (Comp,synsem,
			     local:( cat: @vp_inf_cat,
				      conj:cnil))])).

%One subtype.
pp_inf_subst := (@unsat_three_arg_subst,
   local:cat:val:(keycomp:Comp,
		    comps:[( synsem,
			     local:( cat: @pp_cat,
				      conj:cnil,
				      keys:key:selected_rel)),
			    (Comp,synsem,
			     local:( cat: @vp_inf_cat,
				      conj:cnil))])).

ssr_subst := (@two_arg_subst,
    local:cat:val: (subj:[  local:(local,cont:index:Sind )  ],
                    comps: [ ( local:(local,
                                      cat:val: ( subj:[( local:cont:index:Sind,
                                                         nonlocal:( slash:e_list, 
                                                                    rel:e_list,  
                                                                    que:e_list ) ) ],  
                                                 comps:o_list ), % *olist*
                                      keys:message:e_list )) ] ) ).      


ssr_two_arg_subst := (@ssr_subst,@basic_two_arg).  %% basic_two_arg - amalgamation

ssr_inf_subst := (@ssr_subst, @inf_intrans_subst).

ssr_pp_inf_subst := ( @basic_three_arg_subst,
   local: ( cat:val: 
	   ( subj:[ ( local:cont: ( top:Top,
				   index:Subj) ) ],
	     comps:[ (synsem,
		      local: ( cat: @pp_cat,
			       conj:cnil ) ) ,
		     ( local:( local_min,
			      cat: ( head:(verbal,
					   strict_head:plus, % strict_type,
					   vform:inf ),
				     val: ( subj:[ ( local:cont:index:Subj,
						    nonlocal:( slash:[],
								rel:[],
								que:[] )) ],
						   comps:o_list ) ),
					  keys:message:[] ) ) ] ),
	    cont:top:Top ) ).

ssr_prdp_pp_subst := (@basic_three_arg_subst,
   local: ( cat:val: 
              ( subj:[ ( local:( local_min, cont: ( top:Top,
						index:Subj) ) ) ],
		comps:[ ( local:( local_min,
			   cat: ( head: ( prd:plus,
                                         tam:tense:no_tense ),
				  val: ( subj:[ ( local:cont:index:Subj,
						 nonlocal: ( slash:[],
							     rel:[],
							     que:[] ) ) ],
					spr:o_list,
					comps:o_list ),
				  mc:na ) ) ),
			(synsem,
			 local: ( cat: @pp_cat,
				  conj:cnil ) ) ] ),
	    cont:top:Top ) ).

expl_pp_cp_subst := ( @basic_three_arg_subst,
   local: ( cat:val:comps:[ (synsem,
			     local: ( cat: @pp_cat,
				      conj:cnil ) ), 
			    (synsem,
			            local: ( cat: @s_cat_fin_v_c,
                                             conj:cnil ) ) ],
	    keys:compkey:x_to_rel_s ) ).

sor_inf_subst := (@inf_trans_raising_subst, 
   local:cat:val:comps:[ (synsem,
			   local: ( cont:index:Subj,
                                    agr:Agr ),
			    opt:minus ), 
			  ( local:( local_min,
				   cat:val:subj:
					     [ ( local: ( cont:index:Subj,
                                                         agr:Agr ),
                                                 nonlocal:( slash:[],  
                                                             rel:[],  
                                                             que:[] ) ) ],  
                                    keys:message:[]),   
				opt:minus ) ] ).

%%%Created for wsj_lexicon.
%sor_prp := (@prp_trans_raising, 
%   local:cat:val:comps:[ (synsem,
%			   local: ( cont:index:Subj,
%                                    agr:Agr ),
%			    opt:plus ), 
%			  ( local:( local_min,
%				   cat:val:subj:
%					     [ ( local: ( cont:index:Subj,
%                                                         agr:Agr ),
%                                                 nonlocal:( slash:[],  
%                                                             rel:[],  
%                                                             que:[] ) ) ],  
%                                    keys:message:[]),   
%				opt:minus ) ] ).

sor_bse_subst := (@bse_nontrans_raising_subst,
   local:cat:val:comps:[ ( local:cont:index:Subj,
			    opt:minus), 
			  ( local:( local_min,
				   cat:val:subj:
					     [ ( local:cont:index:Subj,
						 nonlocal: ( slash:[],  
							     rel:[],  
							     que:[] ) ) ] ),  
			    opt:minus) ] ).

particle_subst := (@unsat_two_arg_subst,
    local:( cat:val:comps:[( synsem,
                             local:(local_min,
				     cat:head:prd:minus,
				      cont:( top:Hand,
                                             liszt:[relation ]),
				      keys:key:selected_rel),
			      nonlocal:( slash:[],  
					  rel:[],  
					  que:[]))|_],  
	    keys:key:(handel:Hand))).

generic_particle_np_subst := (@particle_subst,
    local:cat:val:comps:[ synsem,
			  (synsem, 
                           local:( cat: @nomp_cat_acc_min,
                                    conj: cnil,
                                    keys:( key:nonpro_rel,
                                           message:[])))|_]).  

particle_np_subst := (@generic_particle_np_subst,@three_arg,
   local:cat:val:comps:[synsem,synsem]).

particle_plus_subst := (@particle_subst, @three_arg_subst).

particle_pp_subst := (@particle_plus_subst,
   local:cat:val:comps:[bot,
			(synsem,
			    local:(cat: @pp_cat,
				   conj:cnil))]).

unsat_four_arg_subst := (@unsat_three_arg_subst,
    local:cat:val:comps: [synsem, 
                          synsem,
                          synsem]).

np_np_cp_subst := (@unsat_four_arg_subst,@trans_subst,@four_arg,
    local:cat:val: (keycomp:Comp,
                    comps:[ (synsem,local: (   cat: @nomp_cat_acc, %_min
                                               keys:message:[],  
                                               conj:cnil)),
                            (synsem, local: (  cat: @nomp_cat_acc, %_min
                                               keys:message:[],  
                                               conj:cnil)),
                            (Comp,synsem,
                             local: ( cat: @s_cat_fin_v_c,
                                      conj:cnil),
                             nonlocal:slash:[])])).      

%%%Added for wsj
%%%modelled after @np_np_cp_subst
%np_np_pp_subst := (@unsat_four_arg_subst,@trans_subst,@four_arg,
%    local:cat:val: (keycomp:Comp,
%                    comps:[ (synsem,local: (   cat: @nomp_cat_acc, %_min
%                                               keys:message:[],  
%                                               conj:cnil)),
%                            (synsem, local: (  cat: @nomp_cat_acc, %_min
%                                               keys:message:[],  
%                                               conj:cnil)),
%                            (Comp,synsem,
%                             local: ( cat: @pp_cat,
%                                      conj:cnil))])).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% VERB SYNSEMS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

verb_synsem := (@lex_synsem,
   local:(stemhead:vstem,
            agr:Agr,
            cat:(head:(verb_star, %coordination
		       tam:mood:Mood),
                  val:( subj:[(synsem_min,
                               (local:agr:Agr))],
                        spr:[anti_synsem])),
            cont:( index:(Event,e:mood:Mood),
                   e_index:Event)),
    nonlocal:( que:e_list,   
                rel:e_list)).  

atrans_verb := (@verb_synsem, @intrans_subst, @atrans_lt).

unerg_verb := (@verb_synsem, @intrans_subst, @arg1_subj_lt).

passive_or_unacc_synsem := @unsat_subst.


unacc_verb := (@verb_synsem, @intrans_subst, @unacc_lt, @passive_or_unacc_synsem).

poss_verb := (@verb_synsem,@two_arg_subst,@two_arg,@poss_lt,
   local:cat:val:comps:[( synsem, local:( cat: @nomp_cat_acc_min, %nomp_cat_acc_min,
					  keys:message:[],
					  conj:cnil))]). 

np_trans_verb := (@verb_synsem,@np_trans_subst,@trans_lt).

%%%Change linking type, because non-transitives are not passivizable.
%%%VM 9.27.03
np_non_trans_verb :=
(@verb_synsem,@np_non_trans_subst,@two_arg,@arg12_lt). %@trans_lt

basic_prep_intrans_verb := (@verb_synsem, @prep_intrans_subst, @basic_two_arg).

prep_intrans_verb := (@basic_prep_intrans_verb, @prep_intrans_lt, @two_arg).

empty_prep_intrans_verb := (@verb_synsem,@prep_intrans_subst,@two_arg, 
                           @empty_prep_intrans_lt).

empty_prep_trans_verb := (@verb_synsem, @prep_trans_subst,
			     @empty_prep_trans_lt,
   local:cont:h_cons:[]).

%%% added for wsj
%empty_prep_trans_of_verb := (@verb_synsem, @prep_trans_subst,
%			     @empty_prep_trans_of_lt,
%   local:cont:h_cons:[]).

empty_prep_non_trans_verb := (@verb_synsem, @prep_non_trans_subst,
			     @empty_prep_trans_lt).

prep_trans_verb := (@verb_synsem,@prep_trans_subst,@prep_trans_lt).

prep_trans_nomsg_verb := (@verb_synsem,@prep_trans_subst,@prep_trans_nomsg_lt).

%No subtypes.  Used in one desc.
np_comp_verb := (@verb_synsem, @np_comp_subst, @obj_equi_lt,
   local: ( cat:val:keycomp:local:cont:top:Top,
	    cont:top:Top ) ).

%I added the key/ocompkey structure-sharing to enforce that the NP
%object of 'to' is an argument of the verb in the output of the
%dative-shift lexical rule. (That lr is the only place this macro is used.)
to_trans_verb := (@prep_trans_nomsg_verb,
    local:keys:(key:arg2:Index,
		ocompkey:(x_to_rel,
			 arg3:Index))).

ditrans_verb :=  (@verb_synsem,@ditrans_subst,@ditrans_lt).

ditrans_only_verb := (@verb_synsem, @ditrans_subst, @ditrans_lt,
   local:cat:val:comps:[ synsem, synsem ] ).

double_pp_verb := (@verb_synsem, @double_pp_subst, @double_pp_lt).

ssr_verb := (@verb_synsem, @ssr_inf_subst, @basic_two_arg,
   local: ( cat:val:keycomp:local:cont:top:Chand,
	    cont:h_cons: [( qeq,
			    sc_arg:Arghand,
			     outscpd:Chand )],
	    keys:key:arg4:Arghand ) ).

ssr_pp_inf_verb := (@verb_synsem, @ssr_pp_inf_subst, @ssr_expr_lt).

ssr_prdp_pp_verb := (@verb_synsem, @ssr_prdp_pp_subst, @ssr_prdp_expr_lt).

sor_verb := (@verb_synsem, @sor_inf_subst, @sor_lt).

%%%Created for wsj_lexicon.
%sor_prp_verb := (@verb_synsem, @sor_prp, @sor_lt).

sorb_verb := (@verb_synsem, @sor_bse_subst, @sor_lt).

sorbpass_verb := (@verb_synsem, @sor_inf_subst, @sor_lt).

subj_equi_prp_verb := (@verb_synsem, @prp_intrans_subst, 
                      @subj_equi_prp_or_bse_lt,
   local:cat:val:keycomp:local:cat:val:subj:[ pro_ss ] ).

subj_equi_bse_verb := (@verb_synsem, @bse_intrans_subst,
                      @subj_equi_prp_or_bse_lt).

%% "K became quiet"
subj_prd_verb := (@verb_synsem, @ssr_two_arg_subst,@prd_comp_lt,
    local:cat:val: (comps:[(synsem,Comp,
                            local:( cat: @prd_cat,
                                    conj:cnil)) ],
                   keycomp:Comp)).

subj_equi_prd_verb := (@subj_prd_verb,@subj_equi_lt,
   local:cat:val:keycomp:local:cat:val:subj:[pro_ss]).

obj_equi_non_trans_prd_verb := (@verb_synsem, @prd_non_trans_subst, 
			       @obj_equi_prd_lt).

basic_cp_prop_ques_verb := (@verb_synsem,
    local: (cat:val: (keycomp:local:(local_min,
                                    cat:head:(verbal,
					      strict_head:plus,	
                                               inv:minus),
                                    keys:message:[message] 
                                         )),
            cont:liszt:(hd:relation,tl:e_list))). %% added e_list

cp_prop_ques_verb := (@basic_cp_prop_ques_verb,
    local:cat:val:keycomp:local:keys:message:[prop_ques_rel]).

fin_cp_prop_ques_verb := (@cp_prop_ques_verb,
    local:cat:val:keycomp:local:cat: @s_cat_fin_unspec).

fin_or_inf_cp_prop_ques_verb := (@cp_prop_ques_verb,
   local:cat:val:keycomp:local:cat: @s_cat_fin_or_inf_v_c ).

cp_intrans_verb := (@fin_cp_prop_ques_verb, @cp_intrans_subst, @two_arg,
		   @arg14_lt,
   local:cat:val:comps:[ ( local:cat:head:tam:mood:ind_or_mod_subj) ] ).

cp_fin_inf_intrans_verb := (@fin_or_inf_cp_prop_ques_verb, @cp_intrans_subst,
                              @two_arg, @arg14_lt).

cp_prop_intrans_verb := (@cp_intrans_verb,
   local:cat:val:comps:[ ( local:keys:message:[prpstn_rel]  ) ] ).

%wsj
%np_trans_cp_fin_or_inf_verb := (@fin_or_inf_cp_prop_ques_verb,
%				   @cp_trans_subst,
%				   @cp_trans_lt).

np_np_cp_verb := (@fin_cp_prop_ques_verb,@np_np_cp_subst,@tritrans_lt).

%%%added for wsj
%np_np_pp_verb := (@verb_synsem, @np_np_pp_subst, @tritrans_prep_lt).

pp_cp_verb := (@fin_cp_prop_ques_verb,@pp_cp_subst,@pp_cp_lt,
    local:cat:val:comps:[synsem, 
                         (local:keys:message:one_list)]).  


subj_equi_verb := (@cp_prop_ques_verb,@inf_intrans_subst,@two_arg, 
                  @subj_equi_inf_lt).

obj_equi_verb := (@cp_prop_ques_verb,@inf_trans_subst,@obj_equi_inf_lt).

oeq_pp_inf_verb := (@verb_synsem,@pp_inf_subst,@three_arg,@obj_equi_inf_lt,
		   @empty_prep_intrans_lt).

anom_equi_verb := (@cp_prop_ques_verb,@inf_non_trans_subst,@anom_equi_lt,
   local:cont:h_cons:[]).

anom_equi_trans_verb := (@cp_prop_ques_verb,@inf_trans_subst,@anom_equi_lt,
   local:cont:h_cons:[]).

expl_it_subj_pp_cp_verb := (@basic_cp_prop_ques_verb, @expl_pp_cp_subst, 
		     @expl_it_subj_pp_cp_lt).

particle_verb := (@verb_synsem, @particle_subst, @arg1_subj_lt,
		     @two_arg,
		     local:cat:val:comps:[_]).

particle_np_verb := (@verb_synsem,@particle_np_subst,@particle_np_lt).

particle_pp_verb := (@verb_synsem,@particle_pp_subst,
			@prep_particle_intrans_lt).

passive_synsem := (@verb_synsem,@passive_or_unacc_synsem).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Modifier synsems
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%Has subtypes.  Not used in descs.
isect_synsem := (canonical_synsem,
    local: (cat:head:mod:[( local:intersective_mod)],
            cont:top:Hand,
            keys:key:handel:Hand)).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% VERBS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

main_verb_sans_key := (@nonconj, @hc_to_phr,
                          synsem:local:(cat:head:(verb_star,
                                                  aux:minus_star,
                                                  inv:minus_star),
                                        cont:liszt:(hd:v_event_rel),%%.LISZT.LIST < v_event_rel, ... >,
                                        keys:altkey:role_rel)).

main_verb := (@main_verb_sans_key, @mcna, @nonmsg, @topkey, 
                 inflected:minus,
                 synsem:local:( keys:key:Key,
                                cont:liszt:[Key])).

main_verb_std := @main_verb.

main_verb_mliszt := (@main_verb_sans_key, @mcna, @nonmsg, @topkey,
    inflected:minus,
    synsem:local:(keys:key:Key,
                  cont:liszt:hd:Key)).



v_atrans_le := (@main_verb,
   synsem: @atrans_verb).		   

v_cp_fin_inf_non_trans_le := (@main_verb, 
  synsem: (@cp_fin_inf_intrans_verb, 
            local:cat:val:comps:[ (opt:minus ) ] ) ).

v_cp_ques_fin_inf_non_trans_le := (@main_verb,
   synsem:(@cp_fin_inf_intrans_verb,
	   local:cat:val:comps:[(opt:minus,
				 local:keys:message:[int_rel])])).

v_cp_prop_non_trans_le := (@main_verb, 
  synsem: (@cp_prop_intrans_verb, 
            local:cat:val:comps:[ (opt:minus ) ] ) ).

v_cp_propstar_non_trans_le := (@main_verb,
   synsem:(@cp_prop_intrans_verb,
	   local:cat:val:comps:[opt:plus])).

%wsj
%v_np_trans_cp_fin_or_inf_le := (@main_verb,
%   synsem:(@np_trans_cp_fin_or_inf_verb,
%	   local:cat:val:comps:[opt:minus,opt:minus])).

% try
v_subj_equi_le := (@main_verb, 
  synsem: (@subj_equi_verb,
            local:cat:val:comps:[ (opt:minus ) ] ) ).


v_subj_equi_prd_le := (@main_verb_mliszt, 
  synsem: (@subj_equi_prd_verb,
	   local:cat:val:comps:[ (opt:minus ) ] ) ).

v_subj_equi_prp_le := (@main_verb_mliszt, 
  synsem: (@subj_equi_prp_verb,
	   local:cat:val:comps:[ (opt:minus ) ] ) ).

v_subj_equi_bse_le := (@main_verb_mliszt, 
  synsem: (@subj_equi_bse_verb,
	   local:cat:val:comps:[ (opt:minus ) ] ) ).

v_obj_equi_le := (@main_verb, 
  synsem: (@obj_equi_verb,
            local:cat:val:comps:[ (opt:minus ), (opt:minus ) ] ) ).

v_obj_equi_non_trans_prd_le := (@main_verb_mliszt, 
  synsem: (@obj_equi_non_trans_prd_verb,
	   local:cat:val:comps:[ (opt:minus ), (opt:minus ) ] ) ).

v_anom_equi_le := (@main_verb, 
  synsem: (@anom_equi_verb,
            local:cat:val:comps:[ (opt:plus ), (opt:minus ) ] ) ).


v_anom_equi_trans_le := (@main_verb, 
  synsem: (@anom_equi_trans_verb,
            local:cat:val:comps:[ (opt:minus ), (opt:minus ) ] ) ).

v_oeq_pp_inf_le := (@main_verb, 
  synsem: (@oeq_pp_inf_verb,
            local:cat:val:comps:[ (opt:minus ), (opt:minus ) ] ) ).

v_expl_it_subj_pp_cp_le := (@main_verb, 
  synsem: (@expl_it_subj_pp_cp_verb,
	   local:cat:val:comps:[ (opt:plus ), 
				   (opt:minus,
				     local:keys:message: 
					 [ prpstn_or_like_rel ] ) ] ) ).

v_np_np_cp_le := (@main_verb,
    synsem: (@np_np_cp_verb,
	     local:cat:val:comps:[(opt:plus),(opt:plus),(opt:plus)])).

%%%added for wsj
%%%for "pay"
%v_np_np_pp_le := (@main_verb,
%   synsem:(@np_np_pp_verb,
%	   local:cat:val:comps:[(opt:plus),(opt:plus),(opt:plus)])).

np_prd_subst := (@three_arg_trans_subst,
   local:(cat:val:comps:[(synsem,
			  local:(cat: @nomp_cat_acc_min,
				 cont:index:Index,
				 keys:message:[],
				 conj:cnil)),
			 (synsem,
			     local:(local_min,
				    cat:(head:prd:plus, 
					 val:(subj:[(synsem,
						     local:cont:index:Index)],
					      comps:o_list,
					      spr:o_list)),
				    keys:key:independent_rel))])).


np_prd_lt := (@trans_lt,
   local:(cat:val:comps:[_,
			 (local:(local_min,
				 cont:top:Hand))|_],
	  keys:key:(arg14_rel,
		    arg4:Hand))).
				      
np_prd_verb := (@verb_synsem, @np_prd_subst, @np_prd_lt).

%%%added for wsj
%%% for "find" ("I find him easy to please")
%v_np_prd_le := (@main_verb,
%   synsem:(@np_prd_verb,
%	   local:cat:val:comps:[(opt:minus),(opt:minus)])).

v_pp_cp_le := (@main_verb,
    synsem: (@pp_cp_verb,
	     local:cat:val:comps:[(opt:plus),(opt:minus)])).

v_sor_le := (@main_verb, 
  synsem: (@sor_verb,
            local:cat:val:comps:[ (opt:minus ), (opt:minus ) ] ) ).

v_sorb_le := (@main_verb, 
  synsem: (@sorb_verb,
	   local:cat:val:comps:[ (opt:minus ), (opt:minus ) ] ) ).

v_ditrans_le :=  (@main_verb,
   synsem:  (@ditrans_verb, 
	     local:cat:val:comps:[(opt:minus),(opt:minus)] ) ).

v_ditrans_only_le := (@main_verb, 
  synsem: (@ditrans_only_verb, 
	   local:cat:val:comps:[ (opt:minus ), (opt:minus ) ] ) ).

v_double_pp_le := (@main_verb, 
  synsem: (@double_pp_verb, 
	   local:cat:val:comps:[ (opt:minus ), (opt:minus ) ] ) ).

v_empty_prep_intrans_le := (@main_verb, 
    synsem: (@empty_prep_intrans_verb, 
	     local:cat:val:comps:[(opt:minus)])).

v_empty_prep_trans_le := (@main_verb,
   synsem:(@empty_prep_trans_verb,
	   local:cat:val:comps:[(opt:minus),(opt:minus)])).

%%%added for wsj
%%% This is just like @v_empty_prep_trans_le, but the key value of the
%%%second complement does not have to unify with selected_rel, which
%%%rules out PP[of].  I don't know if ERG has another verbal class for
%%%something like "make something of something", but I can't find it.  I
%%%am also making the second complement optional.
%v_empty_prep_trans_of_le := (@main_verb,
%   synsem:(@empty_prep_trans_of_verb,
%	   local:cat:val:comps:[(opt:minus),(opt:plus)])).

v_empty_prep_non_trans_le := (@main_verb,
   synsem:(@empty_prep_non_trans_verb,
	   local:cat:val:comps:[(opt:minus),(opt:minus)])).

v_np_trans_le := (@main_verb, 
    synsem: (@np_trans_verb,
	    local:cat:val:comps:[(opt:minus)])).

v_npstar_trans_le := (@main_verb, 
    synsem: (@np_trans_verb,
	     local:cat:val:comps:[(opt:plus)])).


v_np_prep_trans_dors_le := (@main_verb_mliszt, 
  synsem: (@prep_trans_verb, 
	   local:cat:val:comps:[ (opt:minus ), 
                                   (opt:minus,
                                     local:keys:key:(dir_or_state_rel,
                                                    arg3:sort:entity))] ) ).

v_np_comp_le := (@main_verb, 
  synsem: (@np_comp_verb,
	   local:cat:val:comps:[ (opt:minus ), (opt:minus ) ] ) ).

v_np_non_trans_le := (@main_verb, 
    synsem: (@np_non_trans_verb, 
	     local:cat:val:comps:[(opt:minus)])).

v_particle_le := (@main_verb,
   synsem:(@particle_verb,
	   local:cat:val:comps:[opt:minus])).

v_particle_np_le := (@main_verb, 
   synsem: (@particle_np_verb,
	   local:cat:val:comps:[ (opt:minus ), (opt:minus ) ] ) ).

v_particle_pp_le := (@main_verb,
   synsem:(@particle_pp_verb,
	   local:cat:val:comps:[ (opt:minus), (opt:minus) ])).

%%%Added for wsj
%v_particle_opt_pp_le := (@main_verb,
%   synsem:(@particle_pp_verb,
%	   local:cat:val:comps:[ (opt:minus), (opt:plus) ])).

v_prep_intrans_le := (@main_verb_std, 
  synsem: (@prep_intrans_verb, 
	   local:cat:val:comps:[ (opt:minus ) ] ) ).

v_prepstar_intrans_le := (@main_verb_std, 
  synsem: (@prep_intrans_verb, 
	   local:cat:val:comps:[ (opt:plus ) ] ) ).

v_ssr_le := (@main_verb, 
  synsem: (@ssr_verb,
	   local:cat:val:comps:[ (opt:minus ) ] ) ).

v_prd_ssr_le := (@main_verb_mliszt,
     synsem: (@subj_prd_verb,
	      local:cat:val:comps:[(opt:minus)] )).
v_pp_inf_ssr_le := (@main_verb, 
  synsem: (@ssr_pp_inf_verb,
	   local:cat:val:comps:[ (opt:plus ), (opt:minus ) ] ) ).
v_prdp_pp_ssr_le := (@main_verb_std, 
  synsem: (@ssr_prdp_pp_verb,
	   local:cat:val:comps:[ (opt:minus ), (opt:plus ) ] ) ).

v_unacc_le := (@main_verb, 
  synsem: @unacc_verb ).

v_unerg_le := (@main_verb, 
                   synsem: @unerg_verb).

v_poss_le := (@main_verb, 
  synsem: (@poss_verb, 
	   local:cat:val:comps:[ (opt:minus ) ] ) ).

v_sorb_pass_le := (@main_verb_sans_key, 
    inflected:minus,
    synsem:(@sorbpass_verb,
            local: (@verb_participle_affix,
                    cat: (head:vform:psp_irreg,
			    val: (subj:[ (opt:minus ) ],
				  comps:hd:(opt:minus ) ) ),
		      cont: (psoa, liszt:[ Key ] ),
		      keys:key:Key ) ) ).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% AUXILIARY VERBS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

aux_verb := (@verb_synsem,
    local: (cat:head:tam:Tam,
            cont:index:e:Tam)).
                
aux_verb_ssr := (@aux_verb,@ssr_subst,%@two_arg, %basic_two_arg
    local:cat:val: (keycomp:Comp,
                    comps:hd:Comp)).

aux_verb_word_super := (@mcna,@nonconj,@nonmsg,@hc_to_phr,
    inflected:plus,
    synsem: @aux_verb_ssr). 

aux_verb_word := (@aux_verb_word_super,
    synsem:local:cat: (head:aux:plus_star,
                       posthead:plus)).

bse_aux_verb_word := (@aux_verb_word,
   synsem:local: ( cat: ( val: (subj:[ opt:minus],
			       comps:[ ( local: (cat: @vp_bse_unspec_cat,
						 conj: cnil),
					 opt:minus)])))).

inf_aux_verb_word := (@aux_verb_word_super,
    synsem: (@aux_verb_ssr,
	    local: (local_min,
		   cat:( head:aux:minus,
                         posthead:plus,
			 val:comps:[(synsem,
				      local:(  cat: @vp_inf_cat,
					       conj:cnil),
				       opt:minus)])))).

%% Only for auxiliary "have"
psp_aux_verb_word := (@aux_verb_word,
   synsem: (@aux_verb_ssr,
	    local: ( cat:val:comps: [ (synsem,
				       local: ( cat: (@vp_cat,
						     head: (verb,
							    vform:psp )),
					       cont:top:Hand,
					       conj:cnil ),
				       opt:minus)],
		     keys:key: ( handel:Hand )))).

prd_aux_verb_word := (@aux_verb_word,
    synsem: (@aux_verb_ssr,
             local: (cat:val:comps: [( local: (local_min,
                                             cat: (head:prd:plus,
                                                   val: (subj:[synsem],
                                                         comps:o_list,
                                                         spr:o_list),
                                                   mc:na),
                                             cont:e_index:Event,
                                             keys:key:independent_rel),
                                       opt:minus)],
                     cont:index:Event))).

raise_cont := (word,		%word_or_lexrule &
    synsem:local: ( cat:val:comps:hd: ( local:(local,
					       cont: (top:Hand,
						      index:Index ))),
		   cont: (top:Hand,
			  index:Index,
			  liszt:[]))).


add_cont := (word,	%word_or_lexrule
  synsem:local: (keys:key:Key,
		 cont:liszt:hd:(relation, Key)) ).

%real modal verbs are auxiliary verbs which select a base form complement.
%they only exist in finite forms.
%dpf 2-oct-01 - removed [--keycomp..index.e.tense no_tense) since this
%prevented low attachment of "when" in "when can kim arrive"

generic_modal_verb_word := (@aux_verb_word_super,
  synsem: (@aux_verb_ssr,
	   local: (cat:val:keycomp:local:cont:top:Chand,
                     cont: (index:Event,
			    h_cons:hd:( qeq,
					    sc_arg:Arghand,
					    outscpd:Chand ) ),
		     keys:key: (event:Event,
				arg4:Arghand ) ) ) ).

fin_modal_verb_word := (@generic_modal_verb_word,
  synsem:local: (cat: (head: (prd:minus,
				vform:fin_star,
				 tam:ind_or_mod_subj_tam ),
			 posthead:plus,
			 val:subj:[(synsem, local: (cat: @nomp_cat_nom, %nomp_cat_nom_min
						    keys:message:[],	 
						    conj:cnil ),
					    opt:minus) ] ),
		   cont:psoa ) ).

pres_modal_verb_word := (@fin_modal_verb_word, 
  synsem:local:cat: (head:tam: (tense:present_star,
                               aspect:no_aspect_star ),
                       val:comps:hd:local:cat:head:tam:tense:no_tense ) ).

%assume for now that all modals have simple present tense semantics,
%ignoring the habitual past readings possible for "would" and "could" -
%these will have to be separate lexical entries:

modal_verb_word := (@pres_modal_verb_word, @bse_aux_verb_word,
  synsem:local:cat: (head: (vform:fin_star,
                              prd:minus,
                              mod:[ (local: (intersective_mod,
                                            cat: @nbar_cat ) ) ] ),
                       val:comps:hd:local:cat: @vp_bse_cat ) ).

pos_modal_verb_word := (@modal_verb_word, @topkey,
  synsem:local: (cat:head:aux:plus_star,
		   cont: (liszt:[Key],
			  h_cons:[qeq] ),
		   keys:key:Key ) ).


ought_verb_word := (@pres_modal_verb_word,@inf_aux_verb_word,
    synsem:local:cat:head:mod:[( local:(intersective_mod,
                                         cat: @nbar_cat))]).

pos_ought_verb_word := (@ought_verb_word,@topkey,
    synsem:local:( keys:key:Key,
		   cont:( liszt:[Key],
			  h_cons:[qeq]))).

past_ought_verb_word := (@fin_modal_verb_word,@inf_aux_verb_word,@topkey,
    synsem:local:( cat:head:( tam:( tense:past_star,
                                    aspect:no_aspect_star),
                              mod:[( local:(intersective_mod,
                                             cat: @nbar_cat))]),
                   cont:( liszt:[Key],
			  h_cons:[qeq]),
		   keys:key:Key)).

basic_quasimodal_verb_word := (@aux_verb_word_super,
   synsem: ( local: ( cat:val: ( subj:[ ( opt:minus ) ],
                               comps:hd:local:cont: ( top:Hand,
                                                        index:Event ) ),
                     cont: ( top:Hand,
			    index:Event,
			    liszt:[],
			    h_cons:[] ),
		     keys:key:event:Event ) ) ). 

quasimodal_word := (@basic_quasimodal_verb_word, @inf_aux_verb_word,
   synsem:local:cat:head:mod:[ ] ).

contracted_aux_word := word.

there_verb_synsem := (@unsat_three_arg_subst,@basic_three_arg,@verb_synsem,
    local: (cat:val: (subj: [(local: (cont:index: (there_ind,
                                             png: (pn:Pn,
                                                   gen:no_gend_there))))],
                      comps: [(local: (agr: (non_expl_ind,
                                            png: (pn:Pn,
                                                  gen:neut)),
                                      cat: @np_cat_acc, %@np_cat_acc_min
                                      cont:index:Cind,
                                      conj:cnil,
                                      keys:key: (nonpro_rel,handel:Chand)),
                              opt:minus),
                            ( local: (cat: (head: (prd:plus,
                                                   tam:tense:no_tense),
                                            val: (subj: [( local:cont:index:Cind,
                                                           nonlocal:slash:e_list)],
                                                  spr:o_list,
                                                  comps:o_list),
                                            mc:na),
                                      cont:top:Chand,
                                      keys:key:no_rel),
                              opt:plus)]),
            keys:key: (v_event_arg3_rel,
                      arg3:Cind))).



will_aux_word := (@bse_aux_verb_word,
  synsem:local: (cat: (head: (vform:fin_star,
                                prd:minus,
                                mod: [ (local: (intersective_mod,
                                                cat: @nbar_cat ) ) ],
                                tam: ind_or_mod_subj_tam ),
                         val: (subj: [ (synsem, 
				        local: (cat: @nomp_cat_nom,	%nomp_cat_nom_min
						keys:message:[],  
						conj: cnil ) ) ],
			       comps:hd:local:cont:index:Event ) ),
                   cont: (psoa, index:Event ) ) ).

will_aux_pos_lex_e := (@will_aux_word,
  synsem:local: (cat:val:comps: [ (local:cont:top:Hand ) ],
                   cont: (top:Hand,
			  liszt:[],
			  h_cons:[] ) ) ).

va_will_pos_le := (@will_aux_pos_lex_e,
 synsem:local:cat: (head:tam: (tense:future_star,
                                 mood:indicative_star ),
                      val:comps: [ (local:cat: @vp_bse_cat ) ] ) ).

va_will_pos_cx_le := (@will_aux_pos_lex_e, @contracted_aux_word,
 synsem:local:cat: (head:tam: (tense:future_star,
                                 mood:indicative_star ),
                      val:comps: [ (local:cat: @vp_bse_cat ) ] ) ).

va_will_neg_le := (@will_aux_word, 
  synsem: (@aux_verb,
	   local: (cat: (head:tam: (tense:future_star,
                                      mood:indicative_star ),
                           val:comps:hd:local: (cat: @vp_bse_cat,
                                                   cont:top:Chand ) ),
                     cont: (topkey:Altkey,
			    liszt:[( neg_rel, Altkey,
				   arg:Arghand )],
                            h_cons: [( qeq, sc_arg:Arghand,
                                              outscpd:Chand ) ] ) ) ) ).

va_would_pos_le := (@will_aux_pos_lex_e, 
  synsem:local:cat:head:tam: (tense:future_star,
                                mood:modal_subj_star ) ).
va_would_pos_cx_le := (@will_aux_pos_lex_e, @contracted_aux_word, 
  synsem:local:cat:head:tam: (tense:future_star,
                                mood:modal_subj_star ) ).

va_would_neg_le := (@will_aux_word, 
  synsem: (@aux_verb,
	   local: (cat: (head:tam: (tense:future_star,
                                      mood:modal_subj_star ),
			   val:comps:hd:local:cont:top:Chand ),
                     cont: (topkey:Altkey,
			    liszt: [( neg_rel, Altkey,
				     arg:Arghand )],
                            h_cons: [( qeq, sc_arg:Arghand,
                                              outscpd:Chand) ] ) ) ) ).

%% modal verbs

modal_pos_lex_ent := (@pos_modal_verb_word, @add_cont).

va_modal_pos_le := (@modal_pos_lex_ent,
  synsem:local:cat:head:tam:mood:indicative_star ).

va_modal_pos_cx_le := (@modal_pos_lex_ent, @contracted_aux_word).

modal_subj_pos_lex_ent := (@modal_pos_lex_ent,
  synsem:local:cat:head:tam:mood:modal_subj_star ).

va_modal_subj_pos_le := @modal_subj_pos_lex_ent.

va_ought_pos_le := (@pos_ought_verb_word, @add_cont).
va_past_ought_pos_le := (@past_ought_verb_word, @add_cont).

va_quasimodal_le := (@quasimodal_word).

generic_modal_neg_super := (@aux_verb_word_super,
  synsem: (@aux_verb_ssr,
	   local: (cat:val:keycomp:local:cont:top:Chand,
		     cont: (topkey:Altkey,
			    liszt: [( neg_rel, Altkey,
				 arg:Narghand ), 
				 Key],
			    h_cons: [( qeq,
				  sc_arg:Arghand,
				    outscpd:Chand ),
				    (qeq,
				  sc_arg:Narghand,
				    outscpd:Khand) ] ),
		     keys:key:(Key,handel:Khand,
				       arg4:Arghand ) ) ) ).

generic_modal_neg := (@generic_modal_neg_super, @aux_verb_word). 

va_modal_neg_le := (@modal_verb_word, @generic_modal_neg).
va_modal_subj_neg_le := (@modal_verb_word, @generic_modal_neg, 
  synsem:local:cat:head:tam:mood:modal_subj_star ).

% *** auxiliary do ***
do_aux_word := (@bse_aux_verb_word,
  synsem:local: (cat: (head: (tam:Tam,
				voice:active,
                                mod: [ (local: (intersective_mod,
                                                cat: @nbar_cat ) ) ] ),
                         val: (subj: [ (synsem, 
				        local: (cat: @nomp_cat_nom,	%nomp_cat_nom_min
						keys:message:[],  
						conj:cnil ) ) ],
			       comps:hd:local: (cat:head:aux:minus,
						   cont: (top:Ctop,
							  index:Index ) ) ) ),
		   cont: (psoa, index:(Index, e:Tam ) ) ,
		   keys:key: (mod_role_rel, handel:Ctop ) ) ).

%removed raise-cont from parents, to allow event to not be identified with the
%comp-dtr's event   - is in conflict with collapsing of base and fin-non3rdsg 
%forms, given that we encode vit attributes in the event feature structure.
%sample problem: "kim does sleep"

do_fin := (@do_aux_word, @raise_cont, 
  synsem:local: (local,
		 cat: (head: (vform:fin_star,
				mod: [ (local: (intersective_mod,
					        cat: @nbar_cat ) ) ],
				prd:minus ),
			 posthead:plus,
			 val: (subj: [ (opt:minus) ],
			       comps:hd:local:cont:top:Hand ) ),
		   cont: (top:Hand,
			  liszt:[],
			  h_cons:[] ) ) ).

do_aux_neg_word := (@do_aux_word,
  synsem:local: (cat:val:comps:hd:local:cont: (top:Chand,
                                               index:Index ),
		   cont: (topkey:Altkey,
                          index:Index,
			  liszt:[ (neg_rel, Altkey,
				   arg:Arghand ) ],
			  h_cons: [ (qeq,
				    sc_arg:Arghand,
				    outscpd:Chand ) ] ) ) ).

do_pres := (@do_fin,
  synsem:local: (cat: (head:tam: (ind_or_mod_subj_tam,
                                  tense:present_star,
                                  aspect:no_aspect_star,
                                  mood:indicative_star ),
                         val:subj: [ (local:cont:index:png:Png ) ] ),
                   agr:png:Png ) ).

va_does_le := (@do_pres, 
  synsem:local:cat:val:subj: [ (local:cont:index:png: (png, pn:thirdsg ) ) ] ).

va_do_fin_le := (@do_pres,
  synsem:local:cat:val:subj: 
			     [ (local:cont:index:png: (png, 
						       pn:(nonthirdsg 
							   ) ) ) ] ). %strict_sort

va_did_le := (@do_fin,
  synsem:local:cat:head:tam:past_or_subj_tam ).

do_aux_neg_pres := (@do_aux_neg_word,
  synsem:local:cat:head:tam:( ind_or_mod_subj_tam,
                              tense:present_star,
				aspect:no_aspect_star,
				mood:indicative_star ) ).

va_do_neg_past_le := (@do_aux_neg_word, 
  synsem:local:cat:head:tam:past_or_subj_tam ).

va_doesnt_neg_pres_le := (@do_aux_neg_pres, 
  synsem:local:agr:png:( png,pn:thirdsg ) ).

va_dont_neg_pres_le := (@do_aux_neg_pres,
  synsem:local:agr:png:(png,pn:strict_nonthirdsg ) ). %, non3sg & strict_sort


% *** perfect have ***

have_aux_word := (@psp_aux_verb_word, 
  synsem:local: (cat:head:tam:aspect:perf_star,
                   keys:key:have_aux_rel ) ).

have_aux_pos_lex_entry := (@have_aux_word, @topkey,
  synsem:local: (cat:val:comps: [ (local:cont: (top:Hand,
						index:Index ) ) ],
		   cont: (top:Hand,
			  index:Index,
			  liszt:[],
			  h_cons:[] ) ) ).

have_aux_neg_lex_entry := (@have_aux_word,
  synsem: (@lex_synsem,
	   local: (cat: (head: (vform:fin_star,
				  prd:minus,
				  mod: [ (local: (intersective_mod,
					          cat: @nbar_cat ) ) ] ),
			   posthead:plus,
			   val: (subj: [ (opt:minus) ],
				 comps:hd:
				      (local:cont: (top:Chand,
						    index:Vind ) ) ) ),
		     cont: (topkey:Altkey,
			    index:Vind,
			    liszt: [ (neg_rel, Altkey,
				      arg:Arghand ) ],
			    h_cons: [ (qeq,
				       sc_arg:Arghand,
				       outscpd:Chand ) ] ) ) ) ).

have_fin := (@have_aux_word,
  synsem:local: (local,
		 cat: (head: (vform:fin_star,
				mod: [ (local: (intersective_mod,
					        cat: @nbar_cat ) ) ],
				prd:minus),
			 posthead:plus,
			 val:subj: [ (synsem, 
				      local: (cat: @nomp_cat_nom, %nomp_cat_nom_min
					      keys:message:[],  
					      conj:cnil ),
				      opt:minus) ] ),
		   cont:psoa ) ).

have_pres := (@have_fin,
  synsem:local:cat:head:tam: ( ind_or_mod_subj_tam,
                               tense:present_star,
				aspect:perf_star,
				mood:indicative_star ) ).

have_past := (@have_fin,
  synsem:local:cat:head:tam: (tense:past_star,
				aspect:perf_star,
				mood:indicative_star ) ).

have_subj := (@have_fin,
  synsem:local:cat:head:tam: (aspect:perf_star,
				mood:subjunctive ) ).

%we make "having" be [prd -) to block "kim is having fallen" and (the
%restrictive reading of) "the book having fallen is red":  we will also 
%exclude possibly grammatical examples like "anyone having seen that movie ..."
%but there are no attested instances of these in the full bnc.

va_have_prespart_le := (@have_aux_pos_lex_entry,
  synsem:local: (cat: (head: (vform:prp,
				prd:minus,
				mod: [ (local: (intersective_mod,
					        cat: @nbar_cat,
						cont: (top:Hand,
						       index:Nind ) ) ) ] ),
			 val:subj: [ (local:cont:index:Nind ) ] ),
		   cont:top:Hand ) ).

va_have_bse_le := (@have_aux_pos_lex_entry,
  synsem:local: (nomod_local,
		 cat: (head: (prd:minus,
                                vform:bse_only,
                                tam:aspect:perf_star ),
                         val:subj: [ unexpressed ] ),
		   cont:psoa ) ).

has_aux_lex_ent := (@have_aux_pos_lex_entry, @have_pres,
  synsem:local:cat:val:subj: [ (synsem, 
				local:cont:index:png: (png, 
						       pn:thirdsg ) ) ] ).

va_has_le := @has_aux_lex_ent.

va_has_cx_le := (@has_aux_lex_ent, @contracted_aux_word).

%wsj
%have_fin_aux_lex_ent := (@have_aux_pos_lex_entry,
%			    @have_pres,
%   synsem:local:agr:png:(png,
%			 pn:strict_nonthirdsg)).
			
%%wsj
%va_have_fin_le := @have_fin_aux_lex_ent.

had_aux_lex_ent := (@have_aux_pos_lex_entry, @have_past).

va_had_subj_le := (@have_aux_pos_lex_entry, @have_subj).

va_had_le := @had_aux_lex_ent.
va_had_cx_le := (@had_aux_lex_ent, @contracted_aux_word).

va_has_neg_le := (@have_aux_neg_lex_entry, @have_pres, 
  synsem:local:agr:png:( png, pn:thirdsg ) ).

va_have_fin_neg_le := (@have_aux_neg_lex_entry, @have_pres, 
  synsem:local:agr:png:( png, pn:strict_nonthirdsg ) ). % non3sg, strict_sort

va_had_neg_le := (@have_aux_neg_lex_entry, @have_past).

%% be %%

be_verb := (@mcna,@nonconj,@nonmsg,@hc_to_phr,
    inflected:plus,
    synsem:local:cat: (head:aux:plus_star,
		       val: (subj: [( local: (cat: @nomp_cat_min,
					      conj:cnil))],
			     comps:hd:opt:minus))).

be_fin := (@be_verb,
    synsem:local: (@non_perf,
		   cat: (head: (vform:fin_star,
				prd:minus,
				tam:aspect:nonprf,
				mod: [( local: (intersective_mod,
					        cat: @nbar_cat))]),
			 posthead:plus,
			 val:subj: [( local: (cat: @nomp_cat_nom, %@nomp_cat_nom_min
					      keys:message:e_list,  
					      conj:cnil),
				      opt:minus)]),
		   cont:psoa)).

be_pres := (@be_fin,
    synsem:local:cat:head:tam: (ind_or_mod_subj_tam,
                                tense:present_star,
				mood:indicative_star)).

be_past := (@be_fin,
  synsem:local:cat:head:tam: (ind_or_mod_subj_tam,
                              tense:past_star,
				mood:indicative_star ) ).

be_prespart := (@be_verb,
  synsem:local: (cat: (head: (vform:prp,
                                tam:aspect:progr_star,
				mod:[(local: (intersective_mod, 
					      cat: @nbar_cat,
						cont:index:Nind) ) ] ),
			 posthead:plus,
			 val:subj:[(local:cont:index:Nind) ]) ) ).

be_pastpart := (@be_verb,
  synsem:local: (nomod_local,
		 cat: (head: (vform:psp,
                                tam:aspect:perf_star,
                                prd:minus),
			 posthead:plus),
		   cont:psoa) ). 

be_neg := (sign,
  inflected:plus,
    synsem:( @lex_synsem,
	   local: (keys: (key:handel:Khand,
			    altkey:( neg_rel, Altkey,
				       arg:Arghand ) ),
		     cont: (topkey:Altkey,
			    h_cons:[( qeq,
				    sc_arg:Arghand,
				      outscpd:Khand ) ] ) ) ) ).

be_be_lex_entry := (@be_verb, 
    synsem:local: (nomod_local,
	  cat: (head: (prd:minus,
			vform:bse,
			tam:aspect:nonprf),
		 val:subj:[(unexpressed,opt:minus)] ) ) ).

be_being_lex_entry := (@be_prespart).

be_been_lex_entry := (@be_pastpart).

be_pres_lex_entry := @be_pres.

be_past_lex_entry := @be_past.

be_pres_neg_lex_entry := (@be_pres, @be_neg).
be_past_neg_lex_entry := (@be_past, @be_neg).
%be_subj_neg_lex_entry := (@be_subj, be_neg.

be_am_lex_entry := (@be_pres_lex_entry,
   synsem:local:agr:png:(png,
			 pn:firstsg)).

be_is_lex_entry := (@be_pres_lex_entry,
    synsem:local:agr:png: (png,pn:thirdsg)).

be_are_lex_entry := (@be_pres_lex_entry,
    synsem:local:agr:png: (png,pn:strict_nonfirstsg)). % non1sg,strict_sort

be_was_lex_entry := (@be_past_lex_entry,
  synsem:local:agr:png:(png,pn:strict_firstorthirdsg) ). %, strict_sort 

be_were_lex_entry := (@be_past_lex_entry,
  synsem:local:agr:png:(png,pn:strict_nonfirstsg) ).	%non1sg, strict_sort

be_am_neg_contr_lex_entry := (@be_pres_neg_lex_entry,
  synsem:local: (cat:head:inv:plus,
                   agr:png:( png,pn:firstsg ) ) ).

be_is_neg_contr_lex_entry := (@be_pres_neg_lex_entry,
  synsem:local:agr:png:(png,pn:thirdsg ) ).

be_are_neg_contr_lex_entry := (@be_pres_neg_lex_entry,
  synsem:local:agr:png:(png,pn:strict_nonfirstsg ) ). %non1sg, strict_sort

be_was_neg_contr_lex_entry := (@be_past_neg_lex_entry,
  synsem:local:agr:png:( png,pn:strict_firstorthirdsg ) ). %1or3sg, strict_sort

%be_was_subjnct_neg_contr_lex_entry := (@be_subj_neg_lex_entry,
%  synsem:local:agr:png:( png,pn:strict_firstorthirdsg ) ). %1or3sg, strict_sort

be_were_neg_contr_lex_entry := (@be_past_neg_lex_entry,
  synsem:local:agr:png:( png,pn:strict_nonfirstsg ) ).	%non1sg, strict_sort

%be_were_subjnct_neg_contr_lex_entry := (@be_subj_neg_lex_entry,
%  synsem:local:cat:head:tam: subjnct_tam ).

%be_aint_neg_contr_lex_entry := be_pres_neg_lex_entry.

%% be copula
be_copula := (@prd_aux_verb_word,
    synsem:local: (cat: (head:tam:Tam,
			 val:comps:hd:local: (cat:head:tam:Tam,
                                                 cont:top:Hand)),
                   keys:key: (x_be_prd_rel,handel:Hand))).

be_cop_pos_generic := (@be_copula,
    synsem:local: (cat:val:comps:hd:local:cont:top:Top,
		   cont: (top:Top,
			  liszt:[],
			  h_cons:[]))).

be_cop_pos := (@be_cop_pos_generic,
   synsem:local: @non_perf).

be_cop_neg := (@be_copula,
  synsem:local: (@non_perf,
		 keys:altkey:Altkey,
		   cont: (topkey:Altkey,
			  liszt:[Altkey] ) ) ).

vc_prd_be_le := (@be_be_lex_entry, @be_cop_pos_generic,
  synsem:local:cat:val:comps:[(local:cat:head:mod:[synsem]) ] ).

vc_prd_being_le := (@be_being_lex_entry, @be_cop_pos,
  synsem:local:cat: (head:prd:plus,
		       val:comps:hd:local:cat:head:vform:non_prp ) ).

vc_prd_been_le := (@be_been_lex_entry, @be_cop_pos_generic,
  synsem:local:cat:val:comps:[(local:cat:head:mod:[synsem])]).

vc_prd_am_le := (@be_am_lex_entry, @be_cop_pos).
vc_prd_is_le := (@be_is_lex_entry,@be_cop_pos).
vc_prd_is_cx_le := (@be_is_lex_entry, @be_cop_pos, @contracted_aux_word).

vc_prd_are_le := (@be_are_lex_entry,@be_cop_pos).
vc_prd_are_cx_le := (@be_are_lex_entry, @be_cop_pos, @contracted_aux_word).

vc_prd_was_le := (@be_was_lex_entry, @be_cop_pos).

vc_prd_were_le := (@be_were_lex_entry, @be_cop_pos).

%vc_prd_aint_neg_le := (@be_aint_neg_contr_lex_entry, be_cop_neg:
vc_prd_am_neg_le := (@be_am_neg_contr_lex_entry, @be_cop_neg).
vc_prd_is_neg_le := (@be_is_neg_contr_lex_entry, @be_cop_neg).
vc_prd_are_neg_le := (@be_are_neg_contr_lex_entry, @be_cop_neg).
vc_prd_was_neg_le := (@be_was_neg_contr_lex_entry, @be_cop_neg).
%vc_prd_was_neg_subj_le := (@be_was_subjnct_neg_contr_lex_entry, be_cop_neg.
vc_prd_were_neg_le := (@be_were_neg_contr_lex_entry, @be_cop_neg).
%vc_prd_were_neg_subj_le := (@be_were_subjnct_neg_contr_lex_entry, be_cop_neg,
%  synsem:local:agr:png png, (pn 1sg, strict_sort ) ).

% *** Identity BE ***

id_cop_verb := (@aux_verb,@two_arg_subst,@basic_two_arg, 
    local: (cat: (head:tam:aspect:nonprg,
                  val: (subj: [( local: (keys: 
                                         ( key:nom_rel,
                                           altkey:non_freerel_rel),
                                         cont: (top:Top, 
                                                index:(Id1ind,ref_ind ))))],
                        comps: [( local:( cat:(@nomp_cat, %nomp_cat_min
                                                head: (prd:minus,
                                                       mod:[])),
                                          cont: 
                                              ( top:Top,
                                                index:(Id2ind,ref_ind)),
					  keys:key:nom_rel,
                                          conj:cnil))])),
	    cont:top:Top,
	    keys:key:(x_cop_id_rel,
			     arg:Id1ind,
			     arg3:Id2ind))).

be_id := (@be_verb,
    synsem:(@id_cop_verb,
	     local:cont: (index:Event,
			  liszt:hd:event:Event))).

be_id_pos := (@be_id,@topkey,
    synsem:local:( keys:key:Key,
		   cont: (liszt:[Key],
			  h_cons:[]))).

be_id_neg_synsem := @id_cop_verb.

be_id_neg := (@be_id,
  synsem: (@be_id_neg_synsem, 
	   local: (keys: (key:Key,
			    altkey:Altkey ),
		     cont:liszt:[Key, Altkey] ) ) ).

vc_id_be_le := (@be_be_lex_entry, @be_id, @topkey,
  synsem:local: (keys:key:Key,
		   cont: (liszt: [Key],
			  h_cons:[] ) ) ).

vc_id_being_le := (@be_being_lex_entry, @be_id_pos).
vc_id_been_le := (@be_been_lex_entry, @be_id_pos).
vc_id_am_le := (@be_am_lex_entry, @be_id_pos).
vc_id_is_le := (@be_is_lex_entry,@be_id_pos).
vc_id_is_cx_le := (@be_is_lex_entry, @be_id_pos, @contracted_aux_word).

vc_id_are_le := (@be_are_lex_entry, @be_id_pos).
vc_id_are_cx_le := (@be_are_lex_entry, @be_id_pos, @contracted_aux_word).

vc_id_was_le := (@be_was_lex_entry, @be_id_pos).

vc_id_were_le := (@be_were_lex_entry, @be_id_pos).

%vc_id_aint_neg_le := (@be_aint_neg_contr_lex_entry, be_id_neg.
vc_id_am_neg_le := (@be_am_neg_contr_lex_entry, @be_id_neg).
vc_id_is_neg_le := (@be_is_neg_contr_lex_entry, @be_id_neg).
vc_id_are_neg_le := (@be_are_neg_contr_lex_entry, @be_id_neg).

vc_id_was_neg_le := (@be_was_neg_contr_lex_entry, @be_id_neg).
%vc_id_was_neg_subj_le := (@be_was_subjnct_neg_contr_lex_entry, @be_id_neg).
vc_id_were_neg_le := (@be_were_neg_contr_lex_entry, @be_id_neg).
%vc_id_were_neg_subj_le := (@be_were_subjnct_neg_contr_lex_entry, @be_id_neg,
%  synsem:local:agr:png png, (pn 1sg, strict_sort ) ).

% *** There Copula BE ***

there_cop_verb := (@aux_verb,@there_verb_synsem,
    local:keys:key:x_there_cop_rel).

be_th_cop := (@be_verb, 
    synsem: @there_cop_verb).

be_th_cop_pos := (@be_th_cop,@topkey, 
   synsem:local: (keys:key: (Key,event:Event),
		   cont: (index:Event,
			  liszt:[Key],
			  h_cons:[]))).

th_cop_neg_aux_verb := @there_cop_verb.

be_th_cop_neg := (@be_th_cop,
  synsem: (@th_cop_neg_aux_verb,
	   local: (keys: (key:Key,
			    altkey:Altkey ),
		     cont: (liszt:[Key, Altkey],
			    topkey:Altkey ) ) ) ).

vc_there_be_le := (@be_be_lex_entry, @be_th_cop_pos,
  synsem:local:cat:head:vform:bse_only ).

vc_there_being_le := (@be_being_lex_entry, @be_th_cop_pos,
  synsem:local:cat:head:prd:minus).

vc_there_been_le := (@be_been_lex_entry, @be_th_cop_pos).

vc_there_is_le := (@be_is_lex_entry,@be_th_cop_pos).
vc_there_are_le := (@be_are_lex_entry,@be_th_cop_pos).
vc_there_are_cx_le := (@be_are_lex_entry, @be_th_cop_pos, @contracted_aux_word).

vc_there_was_le := (@be_was_lex_entry,@be_th_cop_pos).
%vc_there_was_subj_le := (@be_was_subjnct_lex_entry, be_th_cop_pos.
vc_there_were_le := (@be_were_lex_entry, @be_th_cop_pos).

vc_there_s_cx_le := (@be_pres_lex_entry, @be_th_cop_pos, @contracted_aux_word).
%vc_there_aint_neg_le := (@be_aint_neg_contr_lex_entry, be_th_cop_neg.
vc_there_is_neg_le := (@be_is_neg_contr_lex_entry, @be_th_cop_neg).
vc_there_are_neg_le := (@be_are_neg_contr_lex_entry, @be_th_cop_neg).
vc_there_was_neg_le := (@be_was_neg_contr_lex_entry, @be_th_cop_neg).
%vc_there_was_neg_subj_le := (@be_was_subjnct_neg_contr_lex_entry, @be_th_cop_neg).
vc_there_were_neg_le := (@be_were_neg_contr_lex_entry, @be_th_cop_neg).
%vc_there_were_neg_subj_le := (@be_were_subjnct_neg_contr_lex_entry, 
%                             be_th_cop_neg,
%  synsem:local:agr:png png, (pn 3sg, strict_sort ) ).



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% NOUNS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

basic_nom_synsem := (@lex_synsem, 
                        local:(stemhead:nstem,
                               cat:head:nominal,
                               cont:nom_obj)).

nominal_synsem := (@basic_nom_synsem,
                     local:cat:head:poss:minus).

xpro_synsem := @nominal_synsem.
xref_synsem := @nominal_synsem.

pronominal_synsem := (@xpro_synsem,
    local: (cat:(head:(noun_star,
		       %comps spec of tags
		       mod:e_list),
               val:subj:e_list))).

nonpronominal_synsem := @xpro_synsem.


nonpro_nomod_synsem := (@nomod_synsem, @nonpronominal_synsem).
nonpro_onearg_synsem := (@nonpronominal_synsem, @basic_one_arg).
nomod_onearg_synsem := (@nomod_synsem, @one_arg).
nonpro_nomod_onearg_synsem := (@nonpro_nomod_synsem,@basic_one_arg). %, @basic_one_arg).

ref_synsem := (@xref_synsem,
    local:(keys:key:Key,
           cont:(index:(Inst,
                        ref_ind),
                 liszt:(hd:(Key,
                            basic_nom_rel,
                            inst:Inst),
                        tl:list)))). % ellipses in lkb, was e_list,
                                     %but this conflicts with
                                     %@personal_pro

non_ref_synsem := (@xref_synsem,@nomod_synsem,@zero_arg,
    local:cat:val: (spr:[],
                    comps:[])).

ref_pro_synsem := (@pronominal_synsem, @ref_synsem, @nomod_synsem).

non_ref_pro_synsem := (@pronominal_synsem,@non_ref_synsem,
    local: (agr:Agr,
            cont:index:Agr)).

basic_noun_synsem := (@nonpronominal_synsem, @ref_synsem, %ref_synsem only for MRS
                         local:cat:head:noun).

noun_synsem := (@basic_noun_synsem,
                   local:(agr:Agr,
                          cont:index:Agr)).

%% Common nouns
basic_common_noun_synsem := (@noun_synsem,
   local:(cat:val:(spr:[(synsem,
			 (local:(local, 
				 cat:(head:det,
				      val:(subj:[],
					   spr:o_list,%%olist
					   comps:o_list))),%%olist
			     opt:minus))]))).

common_noun_synsem := (@basic_common_noun_synsem,
                         local:stemhead:countnstem ). 
                                               

common_noun_nocomp_synsem := (@common_noun_synsem,@one_arg, %@basic_one_arg,
                                 local:cat:val:comps:[]).

basic_mass_or_count_synsem := (@basic_common_noun_synsem,
				  @nonpro_nomod_synsem,
   local:(stemhead:masscountnstem,
	  cont:liszt:[relation])).

mass_or_count_nocomp_synsem := (@basic_mass_or_count_synsem,
				   @one_arg,
   local:cat:val:comps:[]).  %Added VGM

noun_nocomp_synsem := (@common_noun_nocomp_synsem, @nonpro_nomod_onearg_synsem).
noun_nonpro_nomod_synsem := (@basic_common_noun_synsem,
			     @nonpro_nomod_synsem).
noun_two_arg_nomod_synsem := (@noun_nonpro_nomod_synsem,
				 @basic_two_arg). %can't be @two_arg
%because h_cons is not empty.

%One subtype.  Not used in descs.
basic_noun_ppcomp_synsem := (@basic_common_noun_synsem, @two_arg,
				%added for residues
    local:(cat:val:comps:(hd:(expressed_synsem,
                             local:(local,
                                    cat:(head:(prep,
                                               prd:minus,
                                               tam:tense:no_tense),
                                         val:comps:o_list),
                                    cont:(top:Hand,
                                          index:Nind),
                                    keys:key:Ckey)),
                                    /*CONT [ TOP #hand,
                                             INDEX #nind ],
                                      KEYS.KEY #ckey */
                          tl:e_list),
           cont:index:Nind,
           keys:(key:handel:Hand,
                 compkey:Ckey))).
/* In the lkb grammar, e_list is given as elipses, which I think would be most
properly translated as tl:list, but this leads to an infinite loop. */
          /*CONT.INDEX #nind,
            KEYS [ KEY.HANDEL #hand,
                   --COMPKEY #ckey ] */

basic_noun_2ppcomp_agent_synsem := (@basic_common_noun_synsem, @three_arg,
				%added for residues
    local:(cat:val:comps:[(expressed_synsem,
			   local:(local,
				  cat:(head:(prep,
					     prd:minus,
					     tam:tense:no_tense),
				       val:comps:o_list),
				  cont:(top:Hand,
					index:Nind),
				  keys:key:Ckey)),
			  (expressed_synsem,
			      local:(local,
				     cat:(head:(prep,
						prd:minus,
						tam:tense:no_tense),
					  val:comps:o_list),
				     cont:(top:Hand,
					   index:Nind),
				     keys:key:Okey))],
                                  
           cont:index:Nind,
           keys:(key:handel:Hand,
                 compkey:Ckey,
		 ocompkey:Okey))).

noun_nondeverb_ppcomp_synsem := (@basic_noun_ppcomp_synsem,
   local:(cat:val:comps:(hd:local:keys:key:arg3:Index,
                         tl:e_list),
          keys:key:(diadic_nom_rel,
                    arg3:Index))).

%%%added for wsj
%%%For nouns that select PP and agentive PP[by] complements.
%noun_nondeverb_2ppcomp_agent_synsem :=
%   (@basic_noun_2ppcomp_agent_synsem,
%   local:(cat:val:comps:[(local:keys:key:arg3:Index),
%			 (local:keys:key:arg3:AgentIndex)|_],
%	  cont:liszt:[Key,Altkey],
%	  keys:(key:(Key,
%		     specific_nom_rel),
%		altkey:(Altkey,
%			arg13_rel,
%			arg:AgentIndex,
%			arg3:Index)))).

noun_ppcomp_synsem := (@noun_nondeverb_ppcomp_synsem, 
                          @nonpro_nomod_synsem,
                          @common_noun_synsem).

%%%added for wsj
%%%moved @common_noun_synsem down so it doesn't conflict with
%%%mass-noun variety.
%noun_2ppcomp_agent_synsem := (@noun_nondeverb_2ppcomp_agent_synsem,
%				@nonpro_nomod_synsem).

noun_ppcomp_two_arg_synsem := (@noun_ppcomp_synsem, @two_arg).

%%%added for wsj
%noun_2ppcomp_agent_three_arg_synsem := (@noun_2ppcomp_agent_synsem,
%					  @three_arg).


%%%Key value used to specify that the (optional) complement
%%%must be an "of" PP.  Specifier is not optional.  Also, the
%%%value must be of type temp_abstr_rel.  For nouns like "time".  
temp_noun_ppcomp_synsem := (@noun_ppcomp_synsem,
    local:(cat:val:(comps:(hd:(local:keys:key:x_of_rel,
			       opt:plus),
			   tl:e_list), %ellipses
		    subj:e_list,
		    spr:(hd:opt:minus,
			 tl:e_list)),
	   cont:liszt:(hd:relation,
		       tl:e_list), 
	   keys:key:temp_abstr_rel)).

temp_noun_ppcomp_two_arg_synsem := (@temp_noun_ppcomp_synsem,
					  @two_arg).
					  
basic_noun_npcomp_synsem := (@noun_two_arg_nomod_synsem,
   local:(cat:val:comps:[(expressed_synsem,
			  local:(cat: @nomp_cat_acc, %@nomp_cat_acc_min,
				 conj:cnil,
				 keys:(key:abstr_named_rel,
				       message:[]),
				 cont:(top:Top,
				       index:Cindex)))],
	  cont:(top:Top,
		index:Index,
		liszt:[relation,
		       (unspec_rel,
			   handel:Hand,
			   hinst:Index,
			   nhinst:Cindex)],
		h_cons:[]),
	  keys:key:handel:Hand)).

%%%Specifies the person-number value as third-singular, and
%%%the divisible value as plus.  The DIVISIBLE feature is key
%%%in eligibility for the bare_np construction.
%One subtype.  Not used in descs.
basic_mass_noun_synsem := (@basic_common_noun_synsem,
				 @nonpro_nomod_synsem,
    local:(stemhead:massnstem,
	   cont:(index:(png:(png,
			     pn:thirdsg_star),
			divisible:plus_star)))).

scoping_noun_synsem := (@noun_two_arg_nomod_synsem,
   local:(cat:val:keycomp:local:(cont:top:Hand,
				 keys:message:one_list),
	  keys:key:(basic_hcomp_nom_rel,
		    arg4:Hand))).

%%%optionality info moved lower down.  VGM
common_noun_vpcomp_synsem := (@scoping_noun_synsem,
				 @common_noun_synsem,
   local:(cat:val:(keycomp:Comp,
		   comps:[(Comp,
			   @phr_synsem,
			   local:(cat:(@vp_inf_cat,
				       val:subj:[(pro_ss,
						  local:cont:index:Inst,
						  nonlocal:slash:[])]),
				  keys:message:[hypo_rel],
				  conj:cnil))]),
	  cont:(liszt:[relation,
		       (def_rel,
			   restr:Rhand,
			   bv:Inst),
		       (pron_rel,
			   handel:Prohand,
			   inst:(Inst,
				 prontype:zero_pron))],
		h_cons:[(qeq,
			 sc_arg:Rhand,
			 outscpd:Prohand)]))).
	  
		   
				       
%for "fact that..."			  
basic_common_noun_cpcomp_synsem := (@scoping_noun_synsem,
   local:(cat:val:(keycomp:Comp,
		   comps:[(Comp,
			   synsem,
			   local:(cat:head:strict_head:plus,
				  conj:cnil), % and cat:head:strict_type
			   opt:minus)]),
	  cont:(liszt:[relation],
		h_cons:[]))).
	  
common_noun_cpcomp_synsem := (@basic_common_noun_cpcomp_synsem,
   local:(stemhead:countnstem,
	  cat:val:comps:[local:cat:head:comp])).

common_noun_cpcomp_fin_synsem := (@common_noun_cpcomp_synsem,
   local:cat:val:comps:[local:cat: @s_cat_fin_v_c]).

common_noun_cpcomp_inf_synsem := (@common_noun_cpcomp_synsem,
   local:cat:val:comps:[local:cat: @s_cat_inf_v_c]).				     
mass_count_noun_cpcomp_fin_synsem :=
   (@basic_common_noun_cpcomp_synsem,
    local:(stemhead:masscountnstem,
	   cat:val:comps:[local:cat:(@s_cat_fin_v_c,
				     head:comp)])).

%%%Needed for lexical entries like "time".  Empty comps list,
%%%one item of
%%%type relation in liszt.
mass_noun_synsem := (@basic_mass_noun_synsem, @one_arg,
     local:(cat:val:comps:e_list,
	    cont:liszt:[relation])).

mass_noun_ppcomp_synsem := (@basic_mass_noun_synsem, @two_arg,
			       @noun_nondeverb_ppcomp_synsem,
   local:cont:liszt:[relation]).

mass_or_count_ppcomp_synsem := (@basic_mass_or_count_synsem, @two_arg,
			       @noun_nondeverb_ppcomp_synsem).

%%%Used for expressions like "most of the programmers", "half
%%%the programmers" and "half bark" (no complement).
%%%Mod and Subj e_list.
basic_partitive_noun_synsem := (@basic_noun_synsem,
   local:(cat:(head:(partn,
		     mod:e_list),
	       val:(subj:e_list,
		    keycomp:(local:(local_min, %local_min
				    cat:(head:(prep,
					       prd:minus,
					       tam:tense:no_tense),
					 val:comps:o_list), 
				    cont:(top:Nhand,
					  index:Index),
				    keys:key:(Ckey,
					      x_of_rel)), %_of_rel
			     nonlocal:slash:e_list))),  
	  cont:(index:Index,
		h_cons:(hd:(qeq,
			    sc_arg:Phand,
			    outscpd:Nhand),
			tl:e_list)), %ellipses
	  keys:(key:handel:Nhand,
		altkey:(quant_or_wh_rel,
			bv:Index,
			restr:Phand),
		compkey:Ckey))).
		
				   
%Used for expressions like "most of the programmers", "all the dogs"
%%%and "half bark" (no complement).  The specifier is meant for things
%%%like "almost" but also allows "very". 
partitive_noun_synsem := (@basic_partitive_noun_synsem,
   local:(cat:val:(spr:[(local:(local_min, %local_min
				cat:val:(spr:o_list,
					 comps:o_list),
				cont:top:Hand,
				keys:key:(degree_rel,
					  darg:Darg)),
			 nonlocal:(que:e_list,  
				   rel:e_list),
			 opt:plus)],
		   keycomp:opt:minus),
	  cont:top:Khand,
	  keys:(key:handel:Khand,
		altkey:(handel:Hand,
			dim:Darg)))).
		   
				
%Used for expressions like "most of the programmers".  For this
%%%variety of partitive noun, the PPof complement is equated with
%%%the keycomp specifications in @basic_partitive_noun_synsem
%%%(= head:prep, key:x_of_rel).  
partitive_noun_ppof_synsem := (@partitive_noun_synsem,
   local:(cat:val:(keycomp:(Comp,
			    local:keys:key:arg3:Arg3),
		   comps:(hd:Comp,
			  tl:e_list)),
	  keys:key:(part_of_rel,
		    arg3:(Arg3,
			  non_expl_ind)))).

%%%For words like "half". Gets some agreement features (person-number,
%%%divisible) from its complement, via keycomp (since the keycomp
%%%value was linked to the comps list element in @partitive_noun_
%%%ppof_synsem).

partitive_noun_ppof_agr_synsem := (@partitive_noun_ppof_synsem,
   local:(cat:val:keycomp:local:agr:(png:pn:Pn,
				     divisible:Div),
	  agr:(png:pn:Pn, divisible:Div))).

%for words like "none".  Without the agreement specifications above.
partitive_noun_ppof_noagr_synsem := @partitive_noun_ppof_synsem.

%%%For words like "half" and "all" in "all the dogs".  Liszt has _three_
%%%elements, so tl must be left unspecified in @n_part_lexent.
%%%Third element on liszt is similar to keycomp semantics specifications
%%%for PPof variety of partitive noun.  Complement is specified as
%%%@nomp_cat_acc instead of @nomp_cat_acc_min because otherwise we
%%%allow N' rather than NP (like "all dog").  Kordula discusses this
%%%in a comment above.

partitive_noun_np_synsem := (@partitive_noun_synsem,
    local:(cat:val:comps:(hd:(synsem,
			      local:(cat: @nomp_cat_acc, %@nomp_cat_acc_min,
				     keys:(message:e_list,  
					   altkey:explicit_quant_rel),
				     conj:cnil,
				     cont:index:Arg3)),
			  tl:e_list),
	   keys:key:(part_of_rel,
		     handel:Hand,
		     inst:Index,
		     arg3:(Arg3,
			   non_expl_ind)),  %non_expl-ind
	   cont:liszt:(hd:relation,   
		       tl:(hd:relation,
			   tl:(hd:(x_of_rel,
				   handel:Hand,
				   event:e:tense:no_tense,
				   arg:Index,
				   arg3:Arg3),
			       tl:e_list))))).


%For words like "half".  Gets agreement features directly from
%%%complement (not via keycomp like PPof complement partitive
%%%nouns).
partitive_noun_np_agr_synsem := (@partitive_noun_np_synsem,
    local:(cat:val:comps:(hd:local:agr:(png:pn:Pn,
					divisible:Div),
			  tl:e_list),
	   agr:(png:pn:Pn,
		divisible:Div))).

%For words like "none" and "half".  Has no complement, no
%%%agreement specifications.
partitive_noun_nocomp_synsem := (@partitive_noun_synsem,
    local:(cat:val:comps:e_list,
	   keys:key:part_of_rel)).

basic_intr_noun_word := (@hcons_amalg_basic_affixed_word,
   synsem:(@common_noun_nocomp_synsem,
           local:cont:(liszt:[relation],
                      h_cons:e_list))).


n_intr_lex_entry := (@basic_intr_noun_word,
    synsem:(@noun_nocomp_synsem,
            local:(cat:val:spr:(hd:local:keys:key:quant_or_wh_rel,
                                tl:e_list),
                   keys:key:basic_nom_rel),
            modified:notmod)).
        
n_intr_le := @n_intr_lex_entry.

basic_noun_ppcomp_word := (@hcons_amalg_affixed_word,
     synsem:(@noun_ppcomp_two_arg_synsem,
             local:cont:liszt:[relation])).

noun_ppcomp_word := (@basic_noun_ppcomp_word,
    synsem:modified:notmod).

n_ppcomp_le := @noun_ppcomp_word.

n_ppof_le := (@noun_ppcomp_word,
    synsem:local:keys:compkey:x_of_rel).                   

%%%added for wsj
%%% There are no nominal relation types that have more than one
%%% argument defined.  So I have to incorporate another rel on liszt.
%basic_noun_2ppcomp_agent_word := (@hcons_amalg_affixed_word,
%   synsem:(@noun_2ppcomp_agent_three_arg_synsem,
%	   local:cont:liszt:[relation,relation])).

%%%added for wsj
%noun_2ppcomp_agent_word := (@basic_noun_2ppcomp_agent_word,
%   synsem:modified:notmod).

%%%added for wsj
%%%for nouns that select a PP complement and a PP[by] complement.
%%%modelled after @n_ppcomp_le.
%%% compkey/key:arg3 = PP complement
%%% ocompkey/key:arg = agentive PP[by] complement
%%%@common_noun_synsem specifies countnstem
%n_2ppcomp_agent_le := (@noun_2ppcomp_agent_word,
%   synsem:(@common_noun_synsem,
%	   local:keys:ocompkey:x_by_rel)).			  

%%% Difference between count nouns and mass nouns is that the base
%%%lexical entries of mass nouns have extra information, so it is
%%%possible to have a mass-noun variant of a lexical entry by specifying
%%%this macro for the synsem value.
n_mass_2ppcomp_agent_le := (@noun_2ppcomp_agent_word,
   synsem:(@basic_mass_noun_synsem,
	   local:keys:ocompkey:x_by_rel)).			  

% For nouns like "time" (not the mass noun).
basic_n_temp_ppcomp_lexent := (@hcons_amalg_affixed_word,
    synsem: @temp_noun_ppcomp_two_arg_synsem).

% For nouns like "time" (not the mass noun). 
n_temp_ppcomp_le := (@basic_n_temp_ppcomp_lexent,
    synsem:modified:notmod).

n_day_of_week_le := (@basic_n_temp_ppcomp_lexent,
   synsem:local:(cat:val:comps:[local:keys:compkey:non_day_diadic_modable_rel],
		 keys:(key:dofw_rel,
		       altkey:basic_nom_rel))).
% For words like January.
n_month_le := (@basic_n_temp_ppcomp_lexent,
   synsem:(local:(cat:val:comps:[local:keys:compkey:yofc_rel],
		  keys:(key:mofy_rel,
			altkey:basic_nom_rel)),
	   modified:notmod)).

%%%added from ERG for wsj
%%%for nouns that select VP[inf] complements
%n_vpcomp_lexent := (@hcons_amalg_affixed_word,
%   synsem:(@common_noun_vpcomp_synsem,
%	   modified:notmod)).

%Added these macros to allow optional/nonoptional complement.  VGM
%n_vpcomp_le := (@n_vpcomp_lexent,
%   synsem:local:cat:val:comps:[opt:minus]).

%n_vpcompstar_le := (@n_vpcomp_lexent,
%   synsem:local:cat:val:comps:[opt:plus]).

%for "fact/wbelief that..."
n_cpcomp_fin_le := (@hcons_amalg_affixed_word,
   synsem:(@common_noun_cpcomp_fin_synsem,
	   modified:notmod)).

%procedure, way
n_cpcomp_inf_le := (@hcons_amalg_affixed_word,
   synsem:(@common_noun_cpcomp_inf_synsem,
	   modified:notmod)).

n_mass_count_cpcomp_fin_le := (@hcons_amalg_basic_affixed_word,
   synsem:(@mass_count_noun_cpcomp_fin_synsem,
	   modified:notmod)).

%For nouns like "time".  
n_mass_le := (@hcons_amalg_basic_affixed_word,
    synsem:(@mass_noun_synsem,
	    modified:notmod)).

n_mass_count_le := (@hcons_amalg_basic_affixed_word,
   synsem:(@mass_or_count_nocomp_synsem,
	   modified:notmod)).

n_mass_ppcomp_le := (@hcons_amalg_basic_affixed_word,
   synsem:(@mass_noun_ppcomp_synsem,
	   modified:notmod)).

n_mass_count_ppcomp_le := (@hcons_amalg_basic_affixed_word,
   synsem:(@mass_or_count_ppcomp_synsem,
	   modified:notmod)).



%wsj
%%%for intransitive nouns whose base lexical entries are plural
%n_plur_lexent := (@amalg_word,
%   synsem:(@noun_nocomp_synsem,
%	   local:cont:(index:png:(png,
%				  pn:thirdpl_star),
%		       liszt:[relation],
%		       h_cons:[]))).

n_plur_le := (@n_plur_lexent,
   synsem:modified:notmod).		 
				  

%%%For words like "staff".  Person-number feature for index value is
%%%thirdplural.
n_plur_ppcomp_le := (@amalg_word,
    synsem:(@noun_ppcomp_two_arg_synsem,
	    local:cont:(index:png:(png,
				   pn:thirdpl_star),
			liszt:(hd:relation,
			       tl:e_list),  
			h_cons:e_list))).   

%%%For words like "none", "half" and "all".  Subvarieties may have no
%%%complement, an optional PPof complement (with or without agreement) or
%%%an NP complement (with agreement).  Immediate dtr macros basically
%%%invoke the appropriate synsem := and specify that there are two
%%%elements on liszt, except for the npcomp variety, which has no such
%%%specification.  Two elements on liszt are its key and altkey.  One
%%%item on h_cons.  Que list is empty.

n_part_lexent := (@que_word,
    synsem:(@partitive_noun_synsem,
	    local:(cont:(liszt:(hd:Key,
				tl:hd:Altkey), %ellipses
			 h_cons:(hd:qeq,
				 tl:e_list)),  
		   keys:(key:Key,
			 altkey:Altkey)),
	    nonlocal:que:e_list,  
	    modified:notmod)).

%%%For words like "half" in "half of the dogs".
%%%Two relation members of liszt.
n_part_ppof_agr_le := (@n_part_lexent,
    synsem:( @partitive_noun_ppof_agr_synsem,
	     local:cont:liszt:(hd:relation,   
			       tl:(hd:relation,
				   tl:e_list)))).

%%%For words like "none" in "none of the dogs".
%%%Two relation members of liszt.
n_part_ppof_noagr_le := (@n_part_lexent,
    synsem:( @partitive_noun_ppof_noagr_synsem,
	     local:cont:liszt:(hd:relation,   
			       tl:(hd:relation,
				   tl:e_list)))).

%%%For words like "half" and "all", as in "all/half the dogs".
%%%liszt specified more fully in synsem macros.
n_part_npcomp_agr_le := (@n_part_lexent,
    synsem: @partitive_noun_np_agr_synsem).			       
			   
%%%for words like "none" and "half", as in "none/half sleep(s)".
%%%Two relation members of liszt.
n_part_nocomp_le := (@n_part_lexent,
    synsem:(@partitive_noun_nocomp_synsem,
	    local:cont:liszt:(hd:relation,
			      tl:(hd:relation,
				  tl:e_list)))).
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Lexical NPs (proper names, pronouns, names of weekdays, ...)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

basic_np_synsem := (@ref_synsem,
    local:cat:(head:noun_star, %noun*
               val:subj:e_list)).

basic_np_word := (@basic_nontopkey, @hc_to_phr, 
    synsem: @basic_np_synsem).

non_affixed_np := (@basic_nontopkey, @hc_to_phr, @nonque, @nonmsg,
    synsem:(modified:notmod,
            local:cat:val:comps:e_list)).
                     
np_word := (@basic_np_word, @non_affixed_np,
    synsem:local:cat:val:spr:e_list).

np_synsem := (@noun_synsem, @nomod_synsem).

basic_np_sing_synsem := (@basic_np_synsem,
   local:(keys:key:handel:Keyhand,
	  cont:(liszt:(hd:(basic_nom_rel,
			   inst:Ind),
		       tl:hd:(quant_rel,
			      bv:Ind,
			      restr:Rhand)),
		h_cons:[(qeq,
			 sc_arg:Rhand,
			 outscpd:Keyhand)]))).

basic_np_sing_word := (@basic_np_word,
   synsem: @basic_np_sing_synsem).

n_proper_lexent := (@non_affixed_np,
                       synsem: (@noun_nocomp_synsem ,
                                local:(cat:val:spr:[(local:(agr:(png:pn:thirdsg,
                                                                 divisible:minus),
                                                           keys:key:quant_or_wh_rel))],
                                       cont:( top:Top,
                                              index:(Index, png:(png, pn:thirdsg_star)),
                                              liszt:[relation],
                                              h_cons:e_list),
                                       keys:( key:(named_rel,handel:Top),%named_rel, 
                                              altkey:basic_nom_rel),
                                       agr:(Index,divisible:minus_star)) )).




n_proper_le := (@n_proper_lexent, synsem:modified:periph:plus).

np_adv_synsem := (@basic_np_sing_synsem, @pronominal_synsem,
   local:(cat:val:spr:[anti_synsem],
	  keys:altkey:relation)).

basic_np_adv_word := (@basic_np_sing_word,@nonmsg,
   synsem:(@np_adv_synsem,
	   local:(cont:(index:(Ind,
			       png:(png,
				    pn:thirdsg_star)),
			liszt:(hd:relation,
			       tl:hd:Altkey)),
		  keys:altkey:Altkey,
		  agr:Ind))).

np_adv_word := (@basic_np_adv_word, @nonque,
   synsem:local: ( cat:val:comps:[ ],
                   keys:altkey:def_explicit_rel ) ).

n_adv_le := @np_adv_word.

n_wh_adv_le := (@basic_np_adv_word,
   synsem:(local:(cat:(head:case:acc,
		       val:comps:[(opt:plus,
				   local:(cat:head:wh_adv,
					  conj:cnil,
					  keys:key:wh_the_hell_rel))]),
		  cont:liszt:[relation,which_rel]), 
	   nonlocal:que:[handle])).
		  
%% Pronouns
%No subtypes.  Used in one desc.
pers_pro_synsem := (@basic_np_synsem, @ref_pro_synsem,
    local:cat:val:(spr:e_list,
                   comps:e_list)).

personal_pro := (@np_word,
    synsem:( @pers_pro_synsem,
             local:cont:(liszt:(hd:(pron_rel,
                                    handel:Prohand,
                                    inst:Inst),
                                tl:(hd:(def_rel,
                                        restr:Rhand,
                                        bv:Inst),
                                    tl:e_list)),
                         h_cons:(hd:(qeq,
                                     sc_arg:Rhand,
                                     outscpd:Prohand),
                                 tl:e_list)))).

n_pers_pro_noagr_le := @personal_pro.

n_pers_pro_le := (@personal_pro,
    synsem:local:(agr:Agr,
                  cont:(index:(Agr,
                               prontype:std_pron)))).

n_refl_pro_le := (@personal_pro,
   synsem:local:(cat:head:case:acc,
		 agr:Agr,
		 cont:index:Agr,
		 keys:key:(pron_rel,
			   inst:prontype:refl))).

n_recip_pro_le := (@np_word,
   synsem:(@ref_pro_synsem,
	    local: ( cat:head:case:acc,
		     agr:Agr,
		     cont: ( index:Agr,
			    liszt: [( recip_pro_rel,
                                      inst:prontype:recip )],
                            h_cons:[] ) ) ) ).

n_poss_pro_le := (@basic_nontopkey, @nonmsg, @hc_to_phr,
   synsem:(@nomod_synsem,
	   local:(cat:(head:noun_star,
		       val:(spr:[],
			    comps:[],
			    spec:[anti_synsem])),
		  agr:Index,
		  cont:(index:Index,
			liszt:[(pron_rel,Key,
				handel:Prohand,
				inst:(Eind,
				      prontype:std_pron)),
			       (def_rel,
				   bv:Eind,
				   restr:Rhand),
			       (def_np_rel,
				   bv:Index,
				   restr:Phand),
			       (basic_poss_rel,Altkey,
				   handel:Phand,
				   arg3:Eind,
				   arg:Index)],
			h_cons:[(qeq,
				 sc_arg:Rhand,
				 outscpd:Prohand)]),
		  keys:(key:Key,
			altkey:Altkey)),
	   nonlocal:que:[],
	   modified:notmod)).

n_expl_it_le := (@nontopkey,
    synsem: (@non_ref_pro_synsem,
             local: (keys:key:no_rel,
                     cont: (index:it_ind,
                            liszt:[])),
             modified:notmod)).

n_expl_there_le := (@nontopkey,
    synsem: (@non_ref_pro_synsem,
             local: (keys:key:no_rel,
                     cont: (index:there_ind,
                            liszt:[])),
             modified:notmod)).

n_wh_pro_le := (@que_word,
   synsem:(@ref_pro_synsem,
	   local:(cat:val:(spr:[],
			   comps:[]),
		  %we don't have "hell", and this is problematic
		  %for nonlocal feature amalgamation
			   %%%comps:[(opt:plus, 
%%%				   local:(cat:head:wh_adv,
%%%					  conj:cnil,
%%%					  keys:key:wh_the_hell_rel))]
		  agr:Index,
		  cont:(index:(Index,
			       png:(png,
				    pn:thirdsg_star)),
			liszt:[handel:Nhand,(which_rel,
					     bv:Index,
					     restr:Rhand)],  
			h_cons:[(qeq,
				 sc_arg:Rhand,
				 outscpd:Nhand)])),
	   nonlocal:que:[handle],
	   modified:notmod)).
		  
						
n_rel_pro_lexent := (@rel_word,
   synsem:(@pronominal_synsem,
	   local:(cat:(head:mod:e_list,
		       val:(subj:e_list,
			    spr:e_list,
			    comps:e_list)),
		  agr:Index,
		  cont:(top:Hand,
			index:Index,
			liszt:e_list,  
			h_cons:e_list),  
		  keys:(key:non_temp_nom_rel,
			altkey:relation)),
	   nonlocal:rel:(hd:(top:Hand,
			     index:Index),
			 tl:e_list))).

n_rel_pro_le := (@n_rel_pro_lexent,
   synsem:(modified:notmod,
	   local:keys:key:reg_nom_rel)).

n_rel_pro_nonwh_le := (@n_rel_pro_lexent,
   synsem:local:(cat:head:prd:minus,
		 keys:key:modable_nom_rel)).

generic_pro_adv_word := (@que_word,
   synsem:(@np_synsem,
	   local:(cat:val:(spr:[(local:(local_min,
					cont:top:Khand,
					keys:key:(degree_rel,
						  darg:Darg)),
				 nonlocal:(slash:[], %added for residues
					   que:[],
					   rel:[]),
				 opt:plus)],
			   comps:[(opt:plus,
				    local:(cat:(@prd_cat,
						head:adj_star),
					   conj:cnil,
					   cont:(top:Nhand,
						 index:Inst)),
				    nonlocal:(slash:[],
					      rel:[],
					      que:[]))]),
		  cont:(liszt:[basic_nom_rel,
			       (Altkey,
				   quant_rel)],
			h_cons:[(qeq,
				 sc_arg:Rhand,
				 outscpd:Nhand)]),
		  keys:(key:(handel:Nhand,
			     inst:(Inst,
				   png:(png,
					pn:thirdsg_star))),
			altkey:(Altkey,
				handel:Khand,
				bv:Inst,
				restr:Rhand,
				dim:Darg))),
	   nonlocal:que:[])).

n_generic_pro_le := (@generic_pro_adv_word,
   synsem:modified:notmod).

n_deictic_pro_le := (@nontopkey,
   synsem:(@ref_pro_synsem,
	   local:(cat:val:(spr:[],
			   comps:[]),
		  cont:(index:Index,
			liszt:[generic_nom_rel,
			       (demonstrative_rel,
				   Altkey,
				   bv:Ind,
				   restr:Rhand)],
			h_cons:[(qeq,
				 sc_arg:Rhand,
				 outscpd:Hand)]),
		  agr:Index,
		  keys:(key:(handel:Hand,
			     inst:Ind),
			altkey:Altkey)),
	   modified:notmod)).

%%%%%%%%%%%%%%%%%%%%%%%%
%% synsems for auxiliary verb lexical rules
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

sai_synsem := (@lex_synsem,
   local: ( cat: ( head:(verb_star,inv:plus_star,
				 aux:plus_star,
                                 prd:minus,
                                 mod:[ ( local:( intersective_mod,
                                                cat:val:spr:list, %*cons*
						 keys:key:no_rel ) ) ],
                                tam:ind_or_mod_subj_tam ),
                  val:comps:hd:nonlocal:slash:[],  
                  posthead:plus,
		  mc:na ),
	    keys:message:[])).	 

%%%Tags share the Key value of their Mod; relational types are configured
%%%in the type hierarchy so that the Key value of 'do' is a supertype of
%%%main-verb Key values, and other auxiliaries have the same Key value
%%%regardless of negation.
tag_synsem := (@lex_synsem,
   local:(cat:(head:(verb,
		     aux:minus,
		     inv:minus,
		     tam:(ind_or_mod_subj_tam,
			  tense:Tense),
		     mod:[(local:(scopal_mod,
				  cat:(@s_cat_fin,
				       head:tam:tense:(Tense,
						       strict_tense),
				%strict_sort,
				       mc:plus),
				  agr:png:(Png,
					   png,
					   gen:strict_gender), %this
				  %rules out unification of andro with
				  %other gender values.
				        %%%  [ GEN strict_sort,
%%%                                            PN strict_sort ],
				  cont:(top:Modhand,
					index:(Ind,
					       e:tense:real_tense)),
				  keys:(key:Key, %see below
					message:[(Presup,
						  prpstn_rel)])),
			   nonlocal:(slash:[],
				     rel:[],
				     que:[]))]),
	       posthead:plus,
	       val:(subj:[],
		    spr:[],
		    comps:[(@pronominal_synsem,
			    lex:plus, %added to filter NPs
			    opt:minus,
			    local:(cat:val:(spec:[],
					    spr:[]), %added to filter NPs
				   agr:Tagagr,
				   cont:index:png:Png,
				   keys:altkey:no_rel))]),
	       mc:plus),
	  agr:Tagagr,
	  cont:(top:Nehand,
		index:Ind,
		h_cons:[(qeq,
			 sc_arg:Soahand,
			 outscpd:Modhand)]),
	  keys:(key:Key, %this causes a problem with key:id
		% so we leave id unspecified for these lexical entries
		message:[(ne_rel,
			  handel:Nehand,
			  soa:Soahand,
			  params:[])]),
	  ctxt:presup:[Presup])).
	  						      
			  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ADJECTIVES
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

basic_adj_synsem_lex_or_phrase := (canonical_synsem,
    local:( stemhead:astem,
            agr:Agr,
            cat:( head:(adj_star,tam:Tam),
                 val:( subj:[( local:( cat: @nomp_cat, %@nomp_cat_min
                                         cont:index:Agr,
                                        conj:cnil,
                                         agr:Agr ) ) ],
                       spr:[( synsem_min,
                              local:(local,
                                      cat: ( val:spr:o_list, %% *olist*,
                                             mc:na),
                                      keys:key:(degree_rel,
                                                darg:Darg)),
                               nonlocal:slash:e_list,% 
                               opt:plus) ])),
            keys:key:(basic_adj_rel,
                      event:e:Tam,
                      dim:Darg)),
    modified:periph:na).

basic_adj_synsem := (@basic_adj_synsem_lex_or_phrase, 
    @lex_synsem,
     local: (cat:val:( subj:[_],
                       spr:[_] ),
             cont:liszt:hd:Key, %ellipses
             keys:key:Key)).

adj_synsem_lex_or_phrase := (@basic_adj_synsem_lex_or_phrase,@isect_synsem,
    local:( cat:( head:mod:[( local:(  cat: @nbar_cat,
                                       cont:index:(Ind,
                                                   ref_ind),%%ref-ind,
                                       conj:cnil))],
                  val:subj:[( local:cont:index:individual)]),
            cont: (index:Ind,
                   e_index:Event),
            keys:key:event:Event)).

adj_synsem := (@basic_adj_synsem,
                  @adj_synsem_lex_or_phrase).

nomod_adj_synsem := (@basic_adj_synsem,
    local: (cat:head:mod:[(local:cat:head:no_head)],
            cont:e_index:Event,
            keys:key:event:Event)).

nonprd_synsem := (@lex_synsem,
    local:cat:head:prd:minus).

prd_synsem := (@lex_synsem,
   local:cat:head:prd:plus).

intrans_adj_synsem := (@adj_synsem,@two_arg,
    local:cat: (val:comps:e_list,
                posthead:minus)).

adj_three_arg_synsem := (@adj_synsem, @three_arg).

scoping_adj_synsem := (@basic_adj_synsem,@prd_synsem,
    local: (cat:val:keycomp:local: ( keys:message:one_list,  
                                      cont:top:Hand),
            keys:key:(basic_adj_arg4_rel,arg4:Hand))).

reg_adj_cp_synsem := (@scoping_adj_synsem,@nomod_adj_synsem, 
                     @basic_cp_intrans_subst,@three_arg,
    local: (cat:val:keycomp:local:
                               ( cat: (@s_cat_fin_or_inf_v_c,
                                       head:tam:ind_or_mod_subj_tam),
				   % basic_ind_or_mod_subj_tam
				   keys:message:[prop_ques_rel]),
            cont:liszt:[relation],
            keys:key:adj_arg4_rel)).

reg_adj_atrans_cp_synsem := (@reg_adj_cp_synsem,
    local:cat:val:subj:[(local:cont:index:it_ind)]).

reg_adj_atrans_that_cp_synsem := (@reg_adj_atrans_cp_synsem,
    local:cat:val:keycomp:local: (cat:head:tam:tense:real_tense,
                                  keys:message:[prpstn_rel])).

adj_word := (@hcons_amalg_word,
    synsem: (@adj_synsem,
             local:( cat: (head:mod:[( local:cont:index:Ind)],
                           val:subj:[( local:cont:index:Ind)]),
                     cont:liszt:[abstr_adj_rel],
                     keys:key:arg:Ind))).

reg_adj_word := (@adj_word,
   inflected:minus).

reg_intrans_adj := (@reg_adj_word,
   synsem: @intrans_adj_synsem).

adj_intrans_le := @reg_intrans_adj.

reg_adj_atrans_cp_word := (@hcons_amalg_affixed_word,
    synsem: @reg_adj_atrans_cp_synsem).

adj_reg_atrans_that_cp_le := (@reg_adj_atrans_cp_word,
    synsem: (@reg_adj_atrans_that_cp_synsem,
             local:cat:val:comps:[(opt:minus)])).

%%%added for wsj
%%%Will take a VP[inf] complement whose slash value is coindexed with its
%%%subject.
%adj_tough_synsem := (@three_arg,
%   local:(cat:val:(spr:[nonlocal:(rel:Rel,
%				  que:Que)],
%		   subj:[local:cont:index:Index],
%		   comps:[(@phr_synsem,
%			   local:(cat:(@vp_inf_cat,
%				       val:subj:[(pro_ss,
%						  nonlocal:slash:[])]),
%				  keys:message:[hypo_rel],
%				  cont:top:Hand,
%				  conj:cnil),
%			   nonlocal:slash:[cont:index:Index],
%			   opt:minus)]),
%	  keys:key:(adj_arg4_rel,
%		    arg4:Hand)),
%   nonlocal:(rel:Rel,
%	     que:Que,
%	     slash:[])).

%adj_tough_le := (@reg_adj_word,
%   synsem: @adj_tough_synsem).

adj_more_less_le := (@basic_compar_adj_word,
   synsem:(@adj_three_arg_synsem,
	   local:(cat:val:(subj:(Subj,
				  o_list),
			   spr:o_list,
			   comps:[(@lex_synsem,
				  local:(cat:(head:(adj,
						    tam:tense:no_tense),
					      val:(subj:Subj,
						   spr:o_list,
						   comps:[])),
					 cont:(top:Top,
					       index:Ind)),
				  lex:plus,
				  opt:minus)]),
		  keys:key:more_less_adj_rel,
		  cont:(top:Top,
			index:Ind)))).
						    
adj_wh_le := (@nonconj, @non_affix_bearing, @mcna, @nonslash, 
                        @nonrel, @nonmsg,
   synsem:( @lex_synsem,
       local: ( stemhead:astem,
		cat: ( posthead:plus,
		      head:(adj_star,  mod:[ ] ),
		      val: ( subj: [ (synsem,
				    local: ( cat: @nomp_cat_min,
					     conj:cnil,
					     cont:index:Ind ) ) ],
			    spr:[],
			    comps:[] ) ),
		cont: ( top:Top,
		       index:Ind,
		       liszt:[( unspec_adj_rel,
			         handel:Ahand,
				  arg:Ind ),
			        (which_rel, bv:Pind,
					      restr:Hand ),
			        (property_rel,  handel:Hand,
						 inst:Pind ),
			        (prpstn_to_prop_rel, Key,
			         handel:Top,
				  prpstn:Ahand,
				  prop:Pind )],
		       h_cons:[] ),
		keys:key:Key ),
	nonlocal:que:[ handle ] ) ).

compar_superl_adj_word := (@hcons_amalg_non_affixed_word,
   synsem: (@adj_synsem,
            local:( cat:( head:mod:[( local:cont:index:Ind)],
                           val:subj:[(local:cont:index:Ind)]),
                     cont:liszt:[( handel:Hand,
                                     arg:Ind),
                                 (Altkey,
                                  handel:Hand,
                                   arg:Ind)],
                     keys:altkey:Altkey))).

basic_compar_adj_word := (@compar_superl_adj_word,
   synsem:local:( cat:val:spr:[( local:keys:key:much_deg_rel)],
                   keys:altkey:comp_rel)).

adj_comp_le := (@basic_compar_adj_word,
   synsem: @intrans_adj_synsem).

basic_superl_adj_word := (@compar_superl_adj_word,
   synsem:local:(cat:val:spr:[local:keys:key:very_deg_rel],
		 keys:altkey:superl_rel)).

adj_superl_le := (@basic_superl_adj_word,
   synsem:(@intrans_adj_synsem,
	   local:cat:head:prd:minus)).

adj_most_least_le := (@basic_superl_adj_word,
   synsem:(@adj_three_arg_synsem,
	   local:(cat:val:(subj:(Subj,
				 o_list),
			   spr:o_list,
			   comps:[(@lex_synsem,
				   local:(cat:(head:(adj,
						     tam:tense:no_tense),
					       val:(subj:Subj,
						    spr:o_list,
						    comps:[])),
					  cont:(top:Top,
						index:Ind)),
				   lex:plus,
				   opt:minus)]),
		  keys:key:most_least_adj_rel,
		  cont:(top:Top,
			index:Ind)))).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% PREPOSITIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

basic_prep_synsem := (canonical_synsem, 
    local:(cat:head:(n_or_p, 
                     tam:Tam),
           cont:liszt:hd:(norm_relation,
			  event:e:Tam))). %ellipses

%% added the lex_synsem specification for basic_prep_synsem. Without
%% this, prepositions aren't lex:plus and cannot undergo slash
%%amalgamation
prep_synsem := (@basic_prep_synsem, @unsat_two_arg_subst,
		      @lex_synsem, 
    local:(cat:(head:prep_star, %prep*
               val:comps:(hd:(synsem,
                              local:(local_min,
                                     keys:key:Ckey,
                                     cont:index:Objind)), %local_min
                                    /*[ KEYS.KEY #ckey,
                                        CONT.INDEX #objind ]*/
                          tl:list), %ellipses
               posthead:plus),
           cont:liszt:hd:Key,
		      %tl:e_list conficts with a_per_p,
		      % ellipses in the ergo grammar
	   keys:(key:(Key,
		      arg3:Objind),
		 compkey:Ckey))).
         

prep_p_synsem := (@basic_prep_synsem,
    local:(cat:val:(subj:(hd:(synsem_min,  
                             local:(cat: @nomp_cat_min,
                                    cont:index:(Subjind,
                                                event_or_index),
                                    conj:cnil),
                              nonlocal:(slash:e_list,
                                        rel:e_list,
                                        que:e_list)),
                         tl:e_list)),
           keys:key:arg:Subjind)).

prep_with_spr_synsem := (@basic_prep_synsem,
    local:(cat:val:spr:(hd:(synsem_min, 
                           local:(local_min,  %%local_min
                                  cat:(head:adv,
                                       val:(spr:o_list,
                                            comps:o_list)),
                                  keys:key:(very_deg_rel,
                                            darg:Darg)),
                            nonlocal:que:e_list),
                        tl:e_list),
           keys:key:dim:Darg)).
                           
basic_mod_n_or_vp_synsem := (@isect_synsem,
     local:(cat:(head:mod:(hd:local:(cat:( @n_or_v_cat,
                                          head:n_or_v,
                                          mc:Mc),
                                     cont:index:(Ind,
                                                 non_expl),
                                     conj:cnil,
                                     keys:message:Msg),
                           tl:e_list),
                 mc:Mc,
                 posthead:plus),
            cont:(index:Ind,
                  e_index:Event),
            keys:(key:(arg:Ind,
                       event:Event),
                  message:Msg))).

mod_n_or_vp_synsem := (@basic_mod_n_or_vp_synsem, @prep_with_spr_synsem).

prep_p_mod_synsem := (@prep_p_synsem, @mod_n_or_vp_synsem,
    local:cat:val:spr:(hd:opt:plus,
                       tl:e_list)).

prep_prd_or_nonprd_synsem := (@prep_synsem, @prep_p_mod_synsem).

basic_trans_prep_synsem := (@prep_prd_or_nonprd_synsem, %@two_arg,
				  %%conflicts with a_per_p
				  %%basic_two_arg See comment for @two_arg
    local:(cat:val:subj:(hd:nonlocal:(slash:e_list,
                                    rel:e_list,
                                    que:e_list),
                        tl:e_list),
           cont:liszt:hd:prep_rel)). % ellipses in lkb; e_list
				%conflicts with @p_nbar_comp_lexent

trans_prep_synsem := (@basic_trans_prep_synsem,
    local:(cat:val:comps:(hd:(local:cont:index:non_expl_ind,
                                %LOCAL.CONT.INDEX non_expl-ind,
                             nonlocal:que:list), %*handlelist*
                         tl:e_list),
           cont:(liszt:(hd:prep_rel,
			tl:e_list), 		% ellipses in lkb
		 h_cons:[]))). %added for residues


basic_lex_pp_synsem := (@prep_p_synsem, @phr_synsem,
   lex:minus, %added for residue		   
   local:(arg_s:valence_append(Subj,Spr,Comps), %added
	  cat:val:(subj:Subj,
		   spr:Spr,
		   comps:(Comps,[])))).

lex_pp_synsem := (@basic_lex_pp_synsem,@mod_n_or_vp_synsem,@one_arg,
   local:cat:head:(prep_star,
                    mod:[( modified:notmod_or_rmod)])).

compar_adj_prep_synsem := (@prep_synsem,@isect_synsem,@lex_synsem,
    local:( cat:( head: ( prd:minus,
			    mod:[( local: ( cat:( head:adj,
						  val:spr:[( local:keys:key:much_deg_rel)],
						  mc:na),
					      cont:( top:Top,
						     index:Ind),
					      keys:( altkey:(comp_rel,
							     arg3:Arg))))]),
                  val:( spr:[],
                        comps:[( local:( cat:( head:noun,
						val:( spr:o_list,
						      subj:o_list,
						      comps:[])),
					  cont:( top:Top,
						 index:Arg)),
				  nonlocal:( slash:[],  
					      rel:[],  
					      que:[]),	 
				  opt:minus)])),
            cont:( top:Top,
                   index:Ind,
                   liszt:[x_compar_than_rel],
                   h_cons:[]),
	    keys:message:[],
            conj:cnil)).

basic_prep_word := (@msg_amalg_word,
    synsem:( @trans_prep_synsem,
            local:cat:val:comps:(hd:(synsem,
				     local:(cat: @nomp_cat_acc,
                                %nomp_cat_acc_min
					    keys:message:e_list,
					    conj:cnil)),
				 tl:e_list))).

prep_word := (@basic_prep_word,
     synsem:local:cat:val:comps:[(local:cont:index:non_expl_ind)]). 

p_le := (@prep_word,
    synsem:local:cat:val:comps:[(opt:minus)]).

p_reg_lexent := (@prep_word, 
    synsem:local:(cat:val:comps:(hd:(local:(local_min, %local_min,
					    keys:key:non_temp_nom_rel),
				     opt:minus),
				 tl:e_list))).

p_reg_le := @p_reg_lexent.

p_nospec_le := (@prep_word, 
    synsem:local: (cat: (head: (mod:[(local:keys:key:never_unify_rel)],
                                tam: (tense:no_tense,
                                      aspect:noasp_and_progr)),
                         val: (spr:[unexpressed],
                               comps:[  (opt:minus,
                                         local:agr: (png:pn:Pn,
                                                     divisible:Div))])),
                   agr: (png:pn:Pn,
                         divisible:Div))).

p_temp_le := (@msg_amalg_word,
   synsem:(@trans_prep_synsem,
	   local:cat:val:comps:[(synsem,
				 local:(cat:(head:(nominal,
						   strict_head:plus, %strict_type
						   case:acc,
						   poss:minus),
					     val:(subj:o_list,
						  spr:o_list,
						  comps:o_list),
					     mc:na),
					conj:cnil),
				 opt:minus)])).

p_cp_lexent := (@msg_amalg_word,
   synsem:( @basic_trans_prep_synsem,
       local: ( cat:val:comps:[ (synsem,
				 local: 
				  ( cat: (@s_cat_fin_v_c,  head:verb ),
				    conj:cnil,
				    cont: ( top:Mhand,
					   index:( event,Event )),
				    keys:message:[ message] ),
                                  nonlocal:que:list,% *handlelist*,
				  opt:minus) ],
		cont: ( top:Mhand,
		       liszt:[ prep_rel],
		       h_cons:[] ),
		keys:key:arg3:Event ) ) ).

p_cp_le := (@p_cp_lexent,
   synsem:local:cat:val:comps:[ ( local:keys:message: [ prpstn_rel] ) ] ).

p_prdp_le := (@msg_amalg_word,
   synsem: (@basic_trans_prep_synsem,
       local: ( cat:val:comps:[ (synsem,
				 local: ( cat: (@prd_cat,
                                               val:subj:
                                                [ ( local:cont:index:Arg ) ]),
                                          conj:cnil,
					  cont:top:Top ),
                                  nonlocal: ( slash:[],	 
                                              que:[],  
                                              rel:[] ),	 
                                  opt:minus ) ],
		cont: ( top:Top,
		       liszt: [prep_rel],
		       h_cons: [] ),
                keys:key: ( arg:Arg ) ) ) ).

p_no_n_mod_le := (@prep_word,
   synsem:local:cat: ( head:mod:[ ( local:cat:val:subj:[ synsem ] ) ],
		       val:comps:[ ( opt:minus ) ] ) ).

basic_prep_nomod_synsem := (@lex_synsem,@prep_with_spr_synsem,
    local: (cat: (head:(prep_star, prd:minus,
				 mod:[]),
		  val:( spr:[opt:plus],
                        comps:[(synsem,
				 local:(local_min,
					keys:key:Ckey,
					cont:index:Ind),
				  nonlocal:que:list, % *handlelist*
				  opt:minus)])),
	    cont:liszt:[Key],
	    keys:( key:(prep_rel,Key,
		        arg3:Ind),
		   compkey:Ckey))).

prep_nosubj_synsem := (@basic_prep_nomod_synsem,@one_arg, 
                       local:cat:val:subj:[]).

pp_word := (@basic_norm_no_affix_word,
   %non_amalgamating_word, % added to prevent nonlocal feature amalgamation			 	       
   synsem: (@lex_pp_synsem,
	    local:( cat:val:spr:[opt:plus],
                     keys:key:Key,
		     cont:liszt:[Key]))).

pp_le := @pp_word.

p_idiom_nomod_le := (@amalg_word,
   synsem: (@prep_nosubj_synsem,
	    local:cat:val:comps:[(synsem,local:( cat: @nomp_cat_acc, %nomp_cat_acc_min
						 keys:message:[],  
						 conj:cnil))])).

p_nospec_nogap_le := (@prep_word,
    synsem:local:cat:val:(spr:(hd:unexpressed,
			       tl:e_list),
			  comps:(hd:(opt:minus,
				     nonlocal:slash:e_list),  
				 tl:e_list))).

p_nbar_comp_lexent := (@msg_amalg_word,
   synsem:(@basic_trans_prep_synsem,
	   local:(cat:val:(spr:[nonlocal:slash:[]],
			   comps:[(@lex_synsem,
				   opt:minus,
				   local:(cat:(head:noun,
					       val:(spr:[unexpressed],
						    comps:o_list)),
					  cont:top:Nhand,
					  keys:altkey:no_rel),
				   nonlocal:slash:[],
				   modified:periph:na_or_minus)]),
		  cont:(liszt:[(prep_rel,
				arg3:Arg3),
			       (udef_rel,
				   bv:Arg3,
				   restr:Rhand)],
			h_cons:[(qeq,
				 sc_arg:Rhand,
				 outscpd:Nhand)])))).

p_nbar_comp_nmod_lexent := (@p_nbar_comp_lexent,
   synsem:local:(cat:val:(subj:[anti_synsem],
			  comps:[modified:notmod]),
		 keys:key:event:e:(tense:no_tense,
				   aspect:no_aspect))).

%for "a" in "three times a day"
p_nbar_comp_nmod_le := (@p_nbar_comp_nmod_lexent,
   synsem:local:cat:(head:mod:[local:(cat:head:noun,
				      keys:altkey:no_rel)],
		     val:comps:[local:agr:png:pn:thirdsg])).

pp_rel_le := (@rel_word,
   %non_amalgamating_word, % added to prevent nonlocal feature amalgamation			 		 
   synsem:(@basic_lex_pp_synsem,
	   local:(cat:(head:(prep_star,
			     prd:plus,
			     mod:(hd:local:(cat:(@vp_cat,
						 head:verb),
					    cont:index:(Event,
							event),
					    conj:cnil,
					    keys:message:Msg),
				  tl:e_list)),
		       val:spr:[(synsem,
				 local:(local, %local_min
					cat:(head:adv,
					     val:(spr:o_list,
						  comps:o_list)),
					cont:top:Khand,
					keys:key:(degree_rel,
						  darg:Darg)),
				 nonlocal:que:e_list,
				 opt:plus)],
		       posthead:plus),
		  cont:(index:Event,
			liszt:(hd:(Key,
				   arg:Event,
				   arg3:Objind),  
			       tl:e_list),
			h_cons:e_list),  
		  keys:(key:(Key,
			     handel:Khand,
			     dim:Darg),
			message:Msg)),
	   nonlocal:rel:(hd:index:Objind,
			 tl:e_list))).


p_compar_than_le := (@norm_mod_nonque_no_affix_word,
   synsem: @compar_adj_prep_synsem ).
	  				      
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% ADVERBS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


basic_adverb_synsem := (@basic_one_arg, @nonprd_synsem,
   local: ( cat: ( head:( basic_adv,
		        mod:[ ( local:( local_basic,
				        cat:mc:Mc,
                                         cont:index:(Vevent, individual),
					 keys:message:Msg,
					 conj:cnil ) ) ] ),
		  val: ( subj:[],
			comps:[] ),
                  mc:Mc ),
	    cont: ( index:Vevent,
		   liszt:hd:Key),
	    keys: ( key:(Key, arg_rel),
		   message:Msg ) )).

basic_scopal_adverb_synsem := (@basic_adverb_synsem,
   local: ( cat:head:mod:[ ( local:( scopal_mod,
				    cat:head:( adverbee,
					       strict_head:plus), %, strict_type
				     cont:top:Mhand ) ) ],
	    cont:h_cons:hd:( qeq,
				  sc_arg:Hand,
				   outscpd:Mhand ),
	    keys:key:arg:(Hand, handle) ) ).

basic_int_adverb_synsem := (@basic_adverb_synsem, @isect_synsem,
   local: ( cat:head:mod:[ ( local: ( cat:mc:na,
                                     cont:index:Vevent ) ) ],	
            cont:index:Vevent,
	    keys:key:arg:Vevent ) ).


spec_adverb_synsem := (@basic_adverb_synsem,
   local: ( cat:val:spr:[ (synsem, 
			   local:( local_min,
				   cat: ( head:adv,
					  val: ( subj:[ ],
						spr:o_list ),
					  mc:na ),
                                    cont:top:Hand,
				    keys:key:( degree_rel,
					 darg:Darg ) ) ) ],
            keys:key: ( handel:Hand,
		       dim:Darg ) ) ).

scopal_spec_adverb_synsem := (@basic_scopal_adverb_synsem, @spec_adverb_synsem,
   local:cat:head:adv ).

intersect_spec_adverb_synsem := (@basic_int_adverb_synsem, @spec_adverb_synsem).

%% vp, pp, ap
scopal_adverb_synsem := (@scopal_spec_adverb_synsem,
   local: ( cat:head:mod:[ ( local:cat: ( val: ( subj:[ synsem_min ],
					       comps:o_list ),
                                         mc:na_or_minus ) ) ],
	    cont: ( liszt: [ relation],
		   h_cons: [ qeq ] ) ) ).

basic_intersect_adverb_synsem := (@intersect_spec_adverb_synsem,
   local:cat:head:mod:[ ( local:cat: ( val: ( subj:[ synsem ],
					     comps:o_list ),
				       mc:na_or_minus ) ) ] ).

intersect_adverb_synsem := (@basic_intersect_adverb_synsem,
   local: ( cat:head:( reg_adv, mod:[ ( local:cat: @adverbee_cat ) ] ),
	    cont: ( liszt:[relation],
                   h_cons:[] ) ) ).

intersect_adverb_auxv_synsem := (@basic_intersect_adverb_synsem,
   local: ( cat: ( head:( lexadv,  mod:[ ( local: ( cat:( @adverbee_cat,
                                                  head:(v_or_g,
							  strict_head:plus)), %, strict_type
                                                  cont:top:Top ) ) ] ),
                  posthead:minus ),
            cont:top:Top ) ).

scopal_vp_adverb_synsem := (@scopal_adverb_synsem,
   local:cat:head:mod:[ ( local:cat:head:(adverbee,
					  strict_head:plus)) ] ). %v_or_g_or_a, strict_type

scopal_vp_aux_adverb_synsem := (@basic_scopal_adverb_synsem, @spec_adverb_synsem,
   local: ( cat: ( head:(lexadv,
		        mod:[ ( local:cat: ( head: (v_or_g,
						       strict_head:plus),% strict_type,
					     val: ( subj:[ synsem ],
						   comps:o_list ),
					     mc:na ) ) ] ),
		  posthead:minus ),
	    cont: ( liszt: [ relation],
		   h_cons: [ qeq] ) ) ).

comp_vp_adverb_synsem := (@basic_intersect_adverb_synsem,
   local: ( cat: ( head:( adv,  mod:[ ( local:cat: @adverbee_cat ) ] ),
		  posthead:plus ),
	    cont: ( liszt: [(Key,
			   handel:Hand,
			    arg:Ind ),
			  (comp_rel,
			   handel:Hand,
			    arg:Ind ) ],
                   h_cons:[] ),
	    keys:key:Key ) ).

intersect_vp_adverb_synsem := (@intersect_adverb_synsem,
   local:cat:head:mod:[ ( local:cat:head:(v_or_g,
					  strict_head:plus)) ] ). %, strict_type

scopal_s_adverb_synsem := (@spec_adverb_synsem,
   local: ( cat:head:( adv,
                      mod:[ ( local:( scopal_mod,
                                      cat: ( head:verb,% strict_type,
                                             val: ( subj:o_list,
                                                   comps:o_list ),
                                             mc:bool ),
                                       cont:top:Mhand,
                                       keys:message:one_list ) ) ] ),  
	    cont: ( top:Top,
		   liszt: [ relation, (prpstn_rel,
			               handel:Top,
					soa:Soahand ) ],
		   h_cons: [( qeq,
			    sc_arg:Soahand,
			     outscpd:Khand ) ] ),
	    keys:key: ( handel:Khand,
                       arg:Mhand ) ) ).

scopal_s_adverb_nospec_synsem := (@basic_scopal_adverb_synsem,
   local: ( cat: ( val:spr:[ anti_synsem ],
		  head:(adv,
                           mod:[ ( local:cat: ( head:verb, %, strict_type,
						val: (subj:o_list,
						      comps:o_list ),
						mc:bool ) ) ] ) ),
	    cont: ( top:Top,
		   liszt: [ relation, (prpstn_rel,
			               handel:Top,
					soa:Soahand ) ],
		   h_cons: [ qeq,
			    ( qeq,
			    sc_arg:Soahand,
			     outscpd:Khand ) ] ),
	    keys:key:handel:Khand ) ).

adverb_word := (@norm_mod_no_affix_word,
   synsem: (@scopal_adverb_synsem, 
	    local:cat:head:mod:[ ( local:cat:head:(adverbee,
						   strict_head:plus) )
			       ] ) ).
				%v_or_g_or_a  %strict_type

adv_le := @adverb_word.

adv_s_pre_le := (@norm_mod_no_affix_notopkey_word,
   synsem: (@scopal_s_adverb_synsem,
	    local:cat: ( posthead:minus,
			 head:mod:[ ( local:cat:mc:plus ) ] ) ) ).

adv_s_prop_pre_le := (@norm_mod_no_affix_notopkey_word,
   synsem:( @scopal_s_adverb_synsem,
	    local:cat: ( posthead:minus,
			 head:mod:
                              [ ( local: ( cat:mc:plus,
                                          keys:message: [ prpstn_rel]))]))).

adv_s_pre_word_nospec_le := (@norm_mod_no_affix_notopkey_word,
   synsem: (@scopal_s_adverb_nospec_synsem,
	    local:cat:posthead:minus ) ).


adv_post_le := (@adverb_word, 
   synsem:local:cat:posthead:plus ).

vp_adverb_word := (@norm_mod_no_affix_word,
   synsem: @scopal_vp_adverb_synsem ).

adv_vp_le := (@vp_adverb_word,
   synsem:local:cat:head:mod:[ ( local:cat:head:verb ) ] ).

% 'please'
adv_vp_bse_le := (@vp_adverb_word,
   synsem:local:cat:head:mod:[ ( local:cat:head:( verb, 
                                                  vform:imp_vform ) ) ] ).

adv_comp_vp_le := (@norm_mod_no_affix_word,
   synsem: @comp_vp_adverb_synsem ).

adv_vp_aux_le := (@norm_mod_no_affix_word,
   synsem: @scopal_vp_aux_adverb_synsem ).

adv_vp_post_le := (@vp_adverb_word, 
   synsem:local:cat: ( head:mod:[ ( local:cat:head:(v_or_g, vform:fin ) ) ],
                       posthead:plus ) ).

adv_vp_pre_le := (@vp_adverb_word, 
   synsem:local:cat:posthead:minus).

int_vp_adverb_word := (@norm_mod_no_affix_word,
   synsem: @intersect_vp_adverb_synsem ).
    
int_vp_aux_adverb_word := (@norm_mod_no_affix_word,
   synsem: @intersect_adverb_auxv_synsem ).
    
adv_int_vp_le := (@int_vp_adverb_word,
   synsem:local:cat:head:adv ).

basic_adv_int_vp_aux_le := (@que_nolabel_word,
   synsem:(@intersect_adverb_auxv_synsem,
	   local:(cat:head:tam:Tam,
		  cont:liszt:[(relation,
			       label:Label),
			      (label:Label,
				  cons)|_],
		  keys:key:event:e:Tam))).

adv_int_vp_aux_le := (@int_vp_aux_adverb_word,
   synsem:local: ( cat:head:mod:[ ( local:cont:top:Top ) ],
                   cont: ( top:Top,
                          liszt:[Key ],
                          h_cons:[] ),
                   keys:key:Key ) ).

adv_int_vp_post_le := (@int_vp_adverb_word, 
   synsem:local:cat: ( head:adv,
                       posthead:plus ) ).

pp_wh_le := (@nonconj, @non_affix_bearing, @mcna, @nonslash, @nonrel, 
		  @topkey, 
   synsem: (@prep_p_mod_synsem,@lex_synsem, %% added lex_synsem
       local: ( cat: ( head:(prep_star,
			    prd:bool,

			     mod:[ ( local:cat:head:(adverbee,
						     strict_head:plus)) ] ),
				%v_or_g_or_a,strict_type
		      val:comps:[],
		      posthead:plus ),
		cont: ( liszt:[(Key,  arg3:Objind),
			        (which_rel,  bv:Objind,
					      restr:Rhand ),
			        (nom_rel, Altkey,
			                   handel:Nhand,
					    inst:Objind)],
		       h_cons: [( qeq,
			        sc_arg:Rhand,
				 outscpd:Nhand )] ),
		keys: ( key:Key,
		       altkey:Altkey ) ),
	nonlocal:que:[ handle ] ) ).

adv_comparison_spec_le := (@norm_no_affix_word,
   synsem:(@nomod_synsem,
	   local:(cat:(head:adv,
		       val:(comps:[],
			    spr:[])),
		  cont:(top:Hand,
			index:Inst,
			liszt:[(Key,
				handel:Hand,
				c_inst:Inst)],
			h_cons:[]),
		  keys:key:Key))).
		       
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DETERMINERS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

basic_det_synsem := (@nomod_synsem,
   local:(cat:(head:det,
               val:(spr:[(local:(local_min,  %local_min
                                 cont:top:Khand,
                                 keys:key:(degree_rel,
                                           darg:Darg)),
                          nonlocal:(que:e_list,
                                    rel:e_list),
                          opt:plus)],     
                    spec:[(local:cont:(top:Nhand,
                                          index:Index))],
                    comps:e_list)),
          cont:(nom_obj, 
                 index:Index,
                 liszt:hd:(quant_or_wh_rel,
                            Key), %ellipses; e_list conflicts elsewhere
                 h_cons:hd:(qeq,
                             sc_arg:Rhand,
                             outscpd:Nhand)),
                         %tl:e_list % ellipses -- e_list conflicts 
          keys:key:(Key,
                    handel:Khand,
                    bv:Index, 
                    restr:Rhand,
                    dim:Darg))).

%I have added the head specification; see comment below.
nonpart_det_synsem := (@basic_det_synsem,
   local:cat:head:nonpart_det).

det_synsem := (@nonpart_det_synsem,
   local:cont:(liszt:[(quant_or_wh_rel)],
               h_cons:[(qeq)])).

%For quantifiers like "many", "few" "most" and "all".
part_det_synsem := (@basic_det_synsem,
   local:cat:head:part_det).  %my addition to signature, to
%deal with a type to := translation problem.  The partitive
%determiner to partitive noun lexical rules only stipulate that
%the daughter's synsem must be of "type" part_det_synsem.  But
%since, as a description, @part_det_synsem denotes everything
%fitting the description @basic_det_synsem, every determiner is
%licensed as a partitive noun (with a few accidental exceptions)
%and we license things like "the sleeps" and "the of the dogs".
%I don't want to add this as a subtype somewhere under synsem,
%however, and then have to stipulate that every other synsem is
%nonpart_det.  So I have added two types under det, the subtype of
%head.  @basic_det_synsem has only two submacros -- @part_det_synsem
%and @nonpart_det_synsem, so I added head value specifications to
%both.

		     
%For quantifiers like "many", "few", "most"  and "all".
%H_cons has a single constraint,
% and the Que list is empty (not an interrogative pronoun).
part_det_synsem_nonwh := (@part_det_synsem,
    local:cont:h_cons:(hd:qeq,  
		       tl:e_list),
    nonlocal:que:e_list).   

%wsj
next_last_det_synsem := (@part_det_synsem,
   local:cont:h_cons:[qeq],
   nonlocal:que:[]).

det_word := (@que_word,
                synsem:(@det_synsem,
                        local:cat:head:poss:minus)).

det_word_sing := (@det_word,
    synsem:local:(keys:(key:bv:(png:(png,
                                     pn:thirdsg_star), %3sg*
                                divisible:minus_star), %-*
                        altkey:no_rel),
                  agr:(png:pn:thirdsg,
                       divisible:minus))).
                                
                                    
det_word_nonque := (@det_word,@nonque).

%For plural demonstratives "these" and "those".  Requires
%that the bound variable have a third-plural value; its
%own agreement feature value the same.
det_pl_le := (@det_word_nonque,
    synsem:(local:(keys:(key:bv:png:(png,
				     pn:thirdpl_star),
			 altkey:no_rel),
		   agr:png:pn:thirdpl),
	    modified:hasmod)).

%For singular demonstratives like "this" and "that".
%Requires that the
% bound variable have a third-singular value.  Its own
%agreement feature value is also third singular.  
det_sm_le := (@det_word_nonque,
    synsem:(local:(keys:key:bv:png:(png,
				    pn:thirdsg_star),
		   agr:png:pn:thirdsg),
	    modified:hasmod)).


%wsj
%det_next_last_le := (@que_word, @nonque,
%   synsem:(@next_last_det_synsem,
%	   local:cat:head:poss:minus,
%	   modified:hasmod)).

%For quantifiers like "many", "few" "most" and "all".

% General constraint on relational type of single liszt element.  
% And again, the modified:hasmod specification.
pdet_word := (@que_word,
    synsem:(@part_det_synsem_nonwh,
	    local:(cat:val:spec:(hd:local:keys:altkey:basic_nom_rel,
				 tl:e_list),
		   cont:liszt:(hd:quant_or_wh_rel,
			       tl:e_list)),  
	    modified:hasmod)).
		   
				 
				  
%For quantifiers like "many", "few", "most" and "all".
pdet_word_nonque := (@pdet_word, @nonque).

%For quantifiers like "some", "any".
det_part_le := (@pdet_word_nonque).

det_part_sg_le := (@pdet_word_nonque,
   synsem:local: ( keys:key:bv:( png:( png, pn:thirdsg_star ),
                                 divisible:minus_star ),
                   agr: ( png:pn:thirdsg,
                         divisible:minus ) ) ).

%For quantifiers like "many" and "few".
%Agreement and bound variable features
%have third-plural value.
det_part_pl_le := (@pdet_word_nonque,
    synsem:local:(keys:key:bv:png:(png,
				   pn:thirdpl_star),
		  agr:png:pn:thirdpl)).

% For quantifiers like "all" and "most".
% Bound variable and own agreement
% feature have the divisible:plus value associated with mass and
% plural nouns.
det_part_pl_mass_le := (@pdet_word_nonque,
    synsem:(local:(keys:key:bv:divisible:plus_star,
		   agr:divisible:plus),
	    modified:hasmod)).

det_part_unsp_le := (@que_word,
   synsem:( @part_det_synsem, 
	    local: ( cat:head:poss:minus,
		     cont: ( liszt: [quant_or_wh_rel],
			    h_cons:[qeq] ) ),
	     nonlocal:que:[ handle ]  ) ).

pdet_word_pl_mass_wh := (@que_word,
   synsem:( @part_det_synsem, 
	    local: ( cat:head:poss:minus,
		     cont: (index:Mainind,
                            liszt:[ udef_rel,
				 (which_rel,  bv:Index,
					       restr:Rhand ),
				 (diadic_nom_rel,Altkey,
				    handel:Nhand,
				     inst:Index ),
                                 (unspec_rel,
                                    handel:Nhand, 
                                     hinst:Mainind,
                                     nhinst:Index)],
			    h_cons: [ qeq,
				     ( qeq,
				       sc_arg:Rhand,
					outscpd:Nhand)] ),
		     keys:altkey:Altkey ),
             nonlocal:que:[ handle ]) ).

det_part_pl_wh_le := (@pdet_word_pl_mass_wh,
   synsem:local: ( keys: ( key:bv:png:(png, pn:thirdpl_star),
                          altkey:number_rel ),
                   agr:png:pn:thirdpl ) ).

det_part_one_le := (@que_nolabel_word,
   synsem:(@part_det_synsem_nonwh,
	   local:(cont:liszt:[(udef_rel,
			       bv:(Ind,
				   png:(png,
					pn:thirdsg_star),
				   divisible:minus_star)),
			      (card_rel,
				  arg:Ind,
				  const_value:(a_ one))],
		  agr:(png:pn:thirdsg,
		       divisible:minus)))).

% For quantifiers like "some" in addition to determiners like "the".
det_le := (@det_word_nonque,
              synsem:(local:(cat:val:spec:[(modified:Modif)],
                             keys:altkey:no_rel),
                             modified:Modif)).

det_word_modable := (@det_word,
   synsem: ( local:keys:altkey:no_rel,
             modified:hasmod) ).

det_wh_le := @det_word_modable.

det_sing_nonque := (@det_word_sing, @nonque).

det_sg_nomod_le := (@det_sing_nonque,
    synsem:(modified:notmod,
            local:cat:val:spr:[anti_synsem])).

%For quantifiers like "every".  Has the modified:hasmod specification
% associated with quantifiers.
det_sg_le := (@det_sing_nonque,
    synsem:modified:hasmod).

poss_word := (@nonconj, @non_affix_bearing, @nonslash, @nonmsg,
                    @mcna,
    synsem:local:(cat:head:poss:plus,
                  cont:(nom_obj,
                        index:Index,
                        liszt:(hd:relation,
                               tl:hd:(pro_poss_rel,
                                      arg:Index))))). % ellipses

%For "whose".  Altkey value of N' is its own altkey value.
%Its own key value is of type abstr_def_rel.                
nonwh_poss_word := (@poss_word, @nonque,
    synsem:( @nonpart_det_synsem,
             local:(cont:(liszt:(hd:relation,
				 tl:hd:Altkey), %ellipses
			  h_cons:hd:qeq), % ellipses
                    keys:(key:abstr_def_rel,
                          altkey:Altkey)))).
    
det_poss_le := (@nonwh_poss_word, @nonrel,
    synsem:local:(cat:val:spec:(hd:local:cont:top:Hand,
                                tl:e_list),
                  cont:(liszt:[relation,
                               (handel:Hand,
                                   arg3:Ind),
                               (def_rel,
                                   restr:Rhand,
                                   bv:Ind),
                               (pron_rel,
                                   handel:Prohand,
                                   inst:(Ind,
                                         prontype:std_pron))],
                        h_cons:[qeq,
                                (qeq,
                                    sc_arg:Rhand,
                                    outscpd:Prohand)]))).

%For "whose".  Gives it it's nonempty rel value, from second element
%on liszt (corresponds to the N').
det_rel_poss_le := (@nonwh_poss_word,
   synsem:(local:cont:(liszt:(hd:relation,
			      tl:(hd:(handel:Hand,
				      arg3:Ind),
				  tl:e_list)),  
		       h_cons:(hd:qeq,
			       tl:e_list)),  
	   nonlocal:rel:(hd:(top:Hand,
			     index:Ind),
			 tl:e_list))).
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Free relatives
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

free_rel_pro_word := (@nonconj,@non_affix_bearing,@mcna,@nonrel,
			    @nonmsg,@hc_to_phr,
   %non_amalgamating_word,  % added to prevent nonlocal feature amalgamation			 
   synsem:(synsem,
	   lex:minus,  %added for residues			    
	   local:(cat:val:(spr:[],
			   subj:[],
			   comps:[]),
		  agr:Ind,
		  cont:(index:(ref_ind,
			       Ind,
			       png:pn:thirdsg),
			liszt:(hd:(free_relative_ever_rel,
				   bv:Ind,
				   restr:Rhand),
			       tl:hd:(handel:Nhand,
				      inst:Ind)),
			h_cons:[(qeq,
				 sc_arg:Rhand,
				 outscpd:Nhand)]),
		  arg_s:[]),
	   nonlocal:(rel:[],
		     que:[Ind], 
		     slash:[(cat:val:(subj:[], %added for residues
				      comps:[]),
			     conj:cnil)]))).


%%% For whatever, whoever.
n_freerel_pro_le := (@free_rel_pro_word,
   synsem:(local:(cat:head:(noun_star,
			    mod:[],
			    prd:minus),
		  cont:(index:Ind,
			e_index:Ind,
			liszt:[(relation,Altkey),Key]),
		  keys:(key:Key,
			altkey:Altkey)),
	   nonlocal:slash:[(cat:head:(noun,
				      mod:[],
				      prd:minus),
			    cont:index:Ind,
			    agr:(ref_ind,
				 png:pn:thirdsg))])).   

%%%For when, where.
n_freerel_pro_adv_le := (@free_rel_pro_word,
   synsem:(local:(cat:head:(noun_star,
			    mod:[],
			    prd:minus),
		  cont:(e_index:Arg,
			liszt:[relation,
			       (Key,
				inst:Ind),
			       (prep_mod_rel,
				   handel:Lochand,
				   event:e:(tense:no_tense,
					    aspect:no_aspect),
				   arg:Arg,
				   arg3:Ind)]),
		  keys:(key:Key,
			altkey:Key)),
	   nonlocal:slash:[(cat:head:(prep,
				      mod:[(synsem,
					    local:cont:index:Arg)]),
			    cont:(top:Lochand,
				  e_index:Arg))])).

free_rel_det_word_gen := (@nonconj,@non_affix_bearing,@mcna,
			    @nonrel,@nonmsg,@hc_to_phr,
   synsem:(@basic_det_synsem,
	   local:(cat:(head:poss:minus,
		       val:spec:[local:cont:top:Althand]),
		  cont:(liszt:[free_relative_ever_rel],  
			h_cons:[qeq]),  
		  keys:altkey:handel:Althand),
	   nonlocal:(que:[index],
		     slash:[cat:head:n_or_p]))).

%%% For what
det_freerel_le := (@free_rel_det_word_gen,
   synsem:(@det_synsem,
	   local:(cat:head:poss:minus,
		  keys:altkey:no_rel),
	   nonlocal:slash:[cat:head:case:acc])).   

%%% For whichever.
n_freerel_part_le := (@free_rel_det_word_gen,
   synsem: @part_det_synsem).			    
			   
% Possessives
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
n_poss_clitic_lexent := (@mcna, @nonconj, @nonmsg,
        @non_affix_bearing,
     synsem:(@nomod_synsem,
             local:(cat:(head:(possable:plus,
                               poss:plus),  
                         val:(spr:[(synsem,
				    local:(cat: @nomp_cat, %nomp_cat_min
					   keys:key:nonpro_rel,
					   cont:index:(Pindex,
						       individual),
					   conj:cnil),
				    nonlocal:(slash:Slash,
					      rel:Rel,
					      que:Que),
				    opt:minus)],
                              comps:[],
                              spec:[(local:cont:(top:Phand,
                                                index:Index))])),
                     cont:(index:Index,
                           liszt:[(Key, def_rel,
                                        bv:Index,
                                        restr:Rhand),
                                  (Altkey, poss_rel,
                                           handel:Phand,
                                           arg3:Pindex,
                                           arg:Index)],
                           h_cons:[(qeq,
                                   sc_arg:Rhand,
                                   outscpd:Phand)]),
                     keys:(key:Key,
                           altkey:Altkey)),
             nonlocal:(slash:Slash,
                       rel:Rel,
                       que:Que))).

n_poss_clitic_lex_le := (@n_poss_clitic_lexent,
    synsem:local:cat:val:spr:(hd:lex:plus,
                              tl:e_list)).

n_poss_clitic_phr_le := (@n_poss_clitic_lexent,
    synsem:local:cat:val:spr:(hd:lex:minus,
                              tl:e_list)).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SUBORDINATING CONJUNCTIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

basic_subconj_synsem := (@nonprd_synsem,
    local: ( cat: ( head:(prep,
		         mod:[( local: (scopal_mod,
				         cat: (@s_cat,
                                               mc:Mc ),
					 cont:(top:Modtop,
					       index:Ind ),
                                         keys:message:one_list,	 
					 conj:cnil),
				 nonlocal:slash:[])] ),   
		   val:(subj:[],
			spr:[]),
                   mc:Mc),
            cont:( top:Top,
		   index:Ind,
		   liszt:(hd: (subord_rel, Key,
                                 handel:Stop,
                                  main:Main,
                                  subord:Subord),
                          tl:hd:(prpstn_rel, Msg,
                                 handel:Top,
                                  soa:Soa )), % ....
		   h_cons:(hd:(qeq, sc_arg:Main,
                                  outscpd:Modtop),
                           tl:(hd:(qeq,sc_arg:Subord),
                               tl:hd:(qeq,sc_arg:Soa,
                                  outscpd:Stop)))), %....
            keys:( key:Key,
		   message:[Msg] ) ) ).

basic_onearg_subconj_synsem := (@basic_subconj_synsem, %@one_arg, %basic_one_arg,
    local:( cat:val:comps:[(synsem,
                                       local:keys:key:Ckey,
                                       nonlocal: ( slash:[],
                                                   rel:[],
                                                   que:[] ),
                                       opt:minus)],
            keys:compkey:Ckey) ).

subconj_cp_synsem := (@basic_onearg_subconj_synsem,
   local: ( cat:val:comps:[ ( local: ( cont: ( top:Ctop,
                                             index:event ),
                                      keys:message:[ prpstn_rel] ),
                              nonlocal: ( slash:[ ],
                                          que:[],
                                          rel:[] ) ) ],
            cont: ( liszt: [ relation, relation ],
                   h_cons: [ qeq,
                            ( qeq,  outscpd:Ctop ), 
                             qeq ] ) ) ).

subconj_synsem := (@subconj_cp_synsem,
   local:cat:val:comps:[ ( local: ( cat: @s_cat_fin,
                                    cont:index:e:tense:real_tense ) ) ] ).

subconj_inf_synsem := (@basic_onearg_subconj_synsem,
    local: ( cat:(head:mod:[(local:cat: @s_cat_fin_or_imp)],
                  val:comps:[ ( local: 
                                ( cat: (@vp_bse_cat,
                                  val: ( subj: 
                                              [(unexpressed,
                                                 local:cont:index:Sind)],
                                          spr:o_list) ),
                                cont: (top:Vptop,
                                       index:(event,
                                             e: (tense:no_tense,
                                                 mood:ind_or_mod_subj))),
                                keys:message:[]))] ),	  
            cont: (liszt: [ subord_rel,
                             message,
                            (hypo_rel,handel:Ctop,
                                         soa:Hsoa),
                            (def_rel,restr:Rhand,
                                        bv:Sind),
                            (pron_rel,handel:Prohand,
					inst:(Sind,
					      prontype:zero_pron))],
                   h_cons: [  qeq,
                             (qeq,outscpd:Ctop ), 
                             qeq,
                             (qeq,sc_arg:Hsoa,
                                  outscpd:Vptop),
                             (qeq,sc_arg:Rhand,
                                  outscpd:Prohand )] ) ) ).

subconj_prd_synsem := (@basic_onearg_subconj_synsem,
   local:(cat:(head:mod:[local:(cat: @s_cat_fin_or_imp,
				agr:Sind)],
	       val:comps:[local:(cat:(@prd_cat,
				      val:subj:[(unexpressed,
						 local:cont:index:Sind)]),
				 cont:top:Prdtop)]),
	  cont:(liszt:[subord_rel,
		       message,
		       (hypo_rel,
			   handel:Ctop,
			   soa:Hsoa)],
		h_cons:[qeq,
			(qeq,
			    outscpd:Ctop),
			qeq,
			(qeq,
			    sc_arg:Hsoa,
			    outscpd:Prdtop)]))).
		
				      
		     
subconj_if_synsem := (@basic_subconj_synsem, @basic_two_arg,
   local: ( cat: ( head:(tam:mood:Mood,
                         mod:[ ( local:cat: @s_cat_fin_or_imp ) ] ),
                  val:comps:[ (synsem,
                             local: ( cat: ( head:( prep_or_modnp,
						    strict_head:plus,
				                    % strict_type,
						    tam:tense:no_tense,
						    mod:[ ( local:intersective_mod)]),
					       val:comps:[ ] ),
					cont: ( top:Chand,
						  index:Event ) ),
				  nonlocal: ( slash:[],
						rel:[],
						que:[] ),
				  opt: plus )| [ (synsem,
						     local: ( cat: @np_cat_nom, %@np_cat_nom_min
								cont:index:Ind,
								agr:Agr,
								conj:cnil ),
						     nonlocal:slash:[],
						     opt:minus),
						 (synsem,
						     local:( local_min,
							     cat: (
							     head:(
								   verbal,
								   strict_head:plus, % strict_type,
									   vform:fin,
									   tam:mood:Mood ),
                                              val: ( subj:
                                                    [ (synsem,
                                                       local: 
                                                        ( agr:Agr,
                                                          cont:index:Ind )) ],
                                                    comps:o_list ) ),
                                        cont:( top:Chand,
                                               index:Event ),
                                        keys:message:[] ),
                                opt:minus ) ] ] ),
            cont: ( liszt: [ subord_rel,
                            message,
                            (prpstn_rel,
                             handel:Cmsg,
                              soa:Soa ) ],
                   h_cons: [qeq, 
                           (qeq,  outscpd:Cmsg ),
                           qeq,
                           (qeq,  sc_arg:Soa,
                                   outscpd:Chand ) ] ) ) ).

subconj_word := (@basic_mod_no_affix_notopkey_word, @nonque,
   synsem: (@basic_subconj_synsem,
            local:cat:val:comps:[ ( opt:minus,
                                     nonlocal:slash:[] ) ] ) ).
    
p_subconj_le := (@subconj_word,
   synsem: @subconj_synsem ).

p_subconj_if_indic_le := (@basic_mod_no_affix_notopkey_word, @nonque,
   synsem: (@subconj_if_synsem,
            local:cat:val:comps:[ synsem, 
                                   synsem, 
                                   ( local:cat:head:tam: 
                                                 ind_or_mod_subj_tam) ] ) ).

p_subconj_if_subjnct_le := (@basic_mod_no_affix_notopkey_word, @nonque,
   synsem: (@subconj_if_synsem,
            local:cat:val:comps:[ synsem, 
                                   synsem, 
                                   ( local:cat:head:tam:subjnct_tam ) ] ) ).

p_subconj_inf_le := (@basic_mod_no_affix_notopkey_word, @nonque,
    synsem: @subconj_inf_synsem ).

p_subconj_prd_le := (@basic_mod_no_affix_notopkey_word, @nonque,
   synsem: @subconj_prd_synsem).			

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Coordination
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

conj_word := (word,
   inflected:plus,
   synsem:(synsem,
	   local:(arg_s:[Comp], %added for nonloc feat amalgamation
		  cat:(head:Head,
		       mc:Mc,
		       val:(subj:Subj,
			    spr:Spr,
			    comps:[(Comp,
				    synsem,
				    local:(local_min,
					   cat:(head:Head,
						mc:Mc,
						val:(subj:Subj,
						     spr:Spr,
						     comps:Comps),
						hc_lex:Hclex),
					   agr:divisible:Div,
					   keys:(key:Key,
						 message:Msg)),
				    lex:Lex,
				    opt:minus)|Comps]),
		       hc_lex:Hclex),
		  agr:divisible:Div,
		  keys:(key:Key,
			message:Msg)),
	   lex:Lex)).

conj_complex_le := (@conj_word,
   synsem:local:(cat:val:comps:hd:local:cont:e_index:Ind,
		 conj:lex_conj,
		 cont:(top:Chand,
		       index:Cind,
		       liszt:[(Altkey,
			       relation,
			       handel:Chand,
			       c_arg:Cind,
			       r_index:Ind)],
		       h_cons:[]),
		 keys:altkey:Altkey)).

conj_atomic_le := (@conj_word,
   synsem:local:(cat:val:comps:hd:local:(cont:top:Hand,
					 conj:cnil),
		 conj:atomic_conj,
		 cont:(top:Hand,
		       liszt:[],
		       h_cons:[]))).

%%% Negation %%

adv_not_le := (@norm_mod_nonque_no_affix_word,
   synsem:( @lex_synsem, 
	  local: ( cat: ( head:( negadv,
			       mod:[ ( local:( scopal_mod,
					       cat: ( head:( v_or_g,
							     strict_head:plus,
							     %% strict_type,
							    vform:non_fin ),
						      val: ( subj:[ synsem_min ],
							    comps:o_list ),
                                                      mc:na ),
						cont: ( top:Mhand,
						       index:Vevent ),
						conj:cnil,
						keys:message:Msg ) ) ] ),
			 val: ( subj:[ ],
			       comps:[ ],
			       spr:[ ] ),
                         mc:na,
			 posthead:minus),
		   cont: (index:Vevent,
			  liszt:[( neg_rel,Key,
				  arg:Hand )],
			  h_cons:[( qeq,
				   sc_arg:Hand,
				    outscpd:Mhand )] ),
		   keys: ( key:Key,
			  message:Msg ) ) ) ).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Complementizer
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%valence_append won't work for all complementizers, because "to", for
%%%example, has spr:o_list.  In infinitive relatives it is no further
%%%specified, but when selected as a VP complement, it unifies with a
%%%verbal spr specification.  Another possible solution is to specify in
%%%constructions spr:[].

complementizer_word := (@msg_word,
    synsem:local: (local_min,
		      cat: (head:(comp,
				  poss:minus,
				  inv:minus),
			       val:spr:o_list),
		      agr:png:pn:thirdsg_star,
		      cont:index:non_expl)).

plain_compl_word := (@complementizer_word,
    synsem:local:( cat:val: (subj:[Subj],
			     comps:(Comps, 
				   [( local:(local_min,
					     keys:key:Ckey,
					     cont:index:Ind),
				      opt:minus)|_])),
		   cont:index:Ind,
		   arg_s:[Subj|Comps],
		   keys:compkey:Ckey)).

%% added lex_synsem specification, so that slash amalgamation
%% also applies to complementizer
two_place_compl_word := (@complementizer_word,
    synsem: (@lex_synsem, @basic_two_arg, 
           local: (nomod_local,
             cat: (head: (vform:Vform,
                          tam: (Tam,   tense:Tense,
                                       aspect:Aspect,
                                       mood:Mood)),
                   val: (subj:[],
			 spr:[],%added for residues VGM 8/22   
                         comps:
                              [( local:  (cat: (head:(prep_or_modnp, 
						      strict_head:plus,
				                      %strict_type &
						      tam:tense:no_tense,
						      mod:[ local:intersective_mod ]),
                                                val:comps:[]),
                                          cont: (top:Chand,
                                                 index:Event)),
                                  nonlocal:  (slash:e_list,
                                              rel:e_list,
                                              que:e_list ),
                                  opt:plus)|[(synsem,  nonlocal:(Nloc,
                                                      slash:e_list)),
                                  (local: (local_min,
                                          cat: (head: (verbal,
							  strict_head:plus,
				                       % & strict_type &
                                                       vform:Vform,
                                                       tam:Tam),
                                                val: (subj:[nonlocal:Nloc],
                                                      comps:o_list)),
                                          cont: (top:Chand,
                                                 index:Event),
                                          keys: (key:Ckey,
                                                 message:e_list)),
                                    opt:minus)]])),
             cont: (top:Mhand,
                    index: (Event, e:  (tense:Tense,
                                        aspect:Aspect,
                                        mood:Mood)),
                    liszt:(hd:Msg), %% added e_list
                    h_cons:(hd: ( qeq,
                                    sc_arg:Soahand,
                                    outscpd:Chand))), %,tl:e_list
                      %%added []
             keys: (compkey:Ckey,
                    message:[ (Msg, handel:Mhand,
                                    soa:Soahand)])))).

%% Agreement between the VP and the subject (which are both
%% complements of that) of the that-clause
sor_compl_word := (@two_place_compl_word,
    synsem:local:cat:val:comps:[ synsem,
                                 ( local: (cat: @nomp_cat, %@nomp_cat_min
                                           cont:index:Ind,
                                           agr:Agr,
                                           conj:cnil),
                                   opt:minus),
                                 ( local:cat:val:subj: 
                                      [(local: (agr:Agr, 
                                                cont:index:Ind))])]).

comp_that_le := (@sor_compl_word,
    synsem:local:  (cat: (head:(vform:fin,
                                tam:mood: (Mood,ind_or_mod_subj),
                                aux:minus),
                          val:comps:[ synsem, 
                                      (local:cat: @np_cat_nom), %@np_cat_nom_min
                                      (local:cat:head:tam: (tense:real_tense,
                                                            mood:Mood))],
                          mc:minus),
                   cont: (liszt:[relation],
                          h_cons:[qeq]),
                   keys: (key:verb_aspect_rel,
                          message:[prpstn_rel]))).


comp_for_le := (@sor_compl_word,
   synsem:local:(cat:(head:(vform:inf,
			    aux:minus),
		      val:comps:[local:keys:key:no_rel,
				 local:cat: @np_cat_acc,
				%np_cat_acc_min
				 nonlocal:slash:[]],
		      mc:minus),
		 cont:(liszt:[relation],
		       h_cons:[qeq]),
		 keys:(key:verb_aspect_rel,
		       message:[hypo_rel]))).
		 
to_compl_word := (@plain_compl_word,
    synsem:(canonical_synsem,
	    lex:plus_star,
	    %@lex_synsem, can't call valence_append/4
				%@two_arg, %basic_two_arg @two_arg is not
				%appropriate here, because h_cons is _not_ empty.
       local: ( cat: (head: (aux:plus,
                             prd:minus),
                     val: (subj:[(local:( cont:Cont,
                                            agr:Agr))],
                           comps: 
                              [ (synsem, 
				 local: 
                                  (cat: (@vp_bse_cat,
                                          val:subj: 
                                           [( local:( cont:Cont,
                                                       agr:Agr),
                                               nonlocal:
                                                     ( slash:[],
                                                       rel:[],
                                                       que:[]))])))])),
               keys:key:verb_aspect_rel))).

comp_to_nonprop_le := (@to_compl_word,
    synsem:local: (nomod_local,
		   cat: (head:vform:inf,
                         val:( subj:[canonical_synsem],
			       comps:[( local:( local_min,
					         cont:top:Hand))]),
			 mc:na),
		   cont:( top:Hand,
			  liszt:[],
			  h_cons:[]),
		   keys:message:[])).	 

basic_comp_to_prop_lexent := (@to_compl_word,
   synsem:local:(cat:(head:mod:[local:(intersective_mod,
				       cat: @nbar_cat)],
		      val:(subj:[pro_ss],
			   comps:[local:(cont:top:Chand,
					 agr:Agr)]),
		      mc:na_or_minus,
		      posthead:plus),
		 cont:(topkey:Topkey,
		       liszt:[Topkey],  
		       h_cons:[(qeq,
				sc_arg:Soahand,
				outscpd:Chand)]),
		 agr:Agr,
		 keys:message:[(hypo_rel,
				Topkey,
				soa:Soahand)])).

comp_to_prop_le := (@basic_comp_to_prop_lexent,
   synsem:local:cat:head:vform:inf).


whether_compl_word := (@complementizer_word,
   synsem: ( local:( nomod_local,
		    cont:liszt:hd:Msg,
		     keys:message:[( int_rel, Msg,
				      params:[] )] ),
	     nonlocal:slash:[] ) ).

comp_whether_if_fin_lexent := (@whether_compl_word, @sor_compl_word,
   synsem:local: ( cat: ( head: (vform:fin,
                                tam:mood:(Mood,strict_sort)), 
			 val:comps:[ synsem, 
                                     ( local:cat: @np_cat_nom ), %@np_cat_nom_min
                                     ( local:cat:head:tam:mood:Mood ) ],
                         mc:minus ),
                   cont: ( liszt:[relation],
                          h_cons:[qeq] ),
                   keys:key:verb_aspect_rel ) ).

comp_whether_fin_le := (@comp_whether_if_fin_lexent,
   synsem:local:cat:(head:tam:mood:ind_or_mod_subj,
		     val:comps:[synsem,
				synsem,
				(local:cat:head:tam:ind_or_mod_subj_tam)])).

comp_if_indic_le := (@comp_whether_if_fin_lexent,
   synsem:local:cat: ( head:case:acc,
                       val:comps:[ synsem, 
                                   synsem, 
                                   ( local:cat:head:tam: 
                                                 ind_or_mod_subj_tam ) ] ) ).

comp_if_subjnct_le := (@comp_whether_if_fin_lexent,
   synsem:local:cat: ( head:case:acc,
                       val:comps:[ synsem, 
                                   synsem, 
                                   ( local:cat:head:tam:subjnct_tam ) ] ) ).

how_compl_lexent := (@sor_compl_word,
   synsem:local: ( cat: ( head: (vform:fin,
                                tam:mood:ind_or_mod_subj),
                         val:comps:[ synsem, 
                                     ( local:cat: @np_cat_nom ), %np_cat_nom_min
                                    ( local: ( cat:head:tam:mood:strict_ind_or_mod_subj,
                                                               % (ind_or_mod_subj,strict_sort),
                                              cont: (top:Ctop,
                                                     index:Cind ) ) ) ] ),
                   cont: (index:Cind,
                          liszt:[ message,
                                 (Key,  handel:Ctop,
                                          event:e:tense:no_tense,
                                          arg:Cind,
                                          arg3:Objind ),
                                 (which_rel,  bv:Objind,
                                               restr:Rhand ),
                                 (Altkey,
                                  handel:Nhand,
                                   inst:Objind ) ],
                          h_cons:[ qeq, 
                                  (qeq,
                                   sc_arg:Rhand,
                                    outscpd:Nhand) ] ),
                   keys:( key:Key,
                          altkey:Altkey ) ) ).



%how_compl_mc_le := (how_compl_lexent, whether_compl_word,
%   synsem:local:cat:mc plus ).

% 'the way how they did that'
how_compl_le := (@how_compl_lexent,
   synsem: ( local: ( cat:mc:minus,
                     cont:liszt:hd:Msg,
                     keys:message:[(Msg, prpstn_rel)] ),
             nonlocal:slash:[]) ).

comp_whether_inf_le := (@whether_compl_word, @plain_compl_word,
   synsem:(@ssr_two_arg_subst,
	   local:(cat:(head:vform:inf,
		       val:comps:[local:(cat:(head:(comp,
						    vform:inf),
					      val:(comps:o_list,
						   spr:o_list)),
					 cont:top:Chand)],
		       mc:minus),
		  cont:(top:Mhand,
			liszt:[Msg],
			h_cons:[(qeq,
				 sc_arg:Soahand,
				 outscpd:Chand)]),
		  keys:(key:verb_aspect_rel,
			message:[(Msg,
				  handel:Mhand,
				  soa:Soahand)])))).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% imperative words "don't" and "let's"
%%%%%%%%%%%%%%

root_marker_word := (@nonque, @non_affix_bearing, @nonrel, @nonconj, @hc_to_phr,
   synsem:( synsem,
	  local: ( arg_s:valence_append(Subj,Spr,Comps),
		     cat: ( head:( verb_star,  tam:mood:Mood,
				   aux:minus,
				   inv:minus ),
			      val:(subj:Subj,
				   spr:Spr,
				   comps:(Comps,
					  [ (synsem,
						local:( local_min,
							cat: ( head:tam:mood:Mood,
								 val:comps:o_list ),
							ctxt:Ctxt ),
						nonlocal: ( slash:[],  
							      que:[],  
							      rel:[] ) ) ]) )),
		     ctxt:Ctxt ),
	    nonlocal:slash:[] ) ).

lex_imperative := (@root_marker_word,
   synsem:local: 
	   ( cat: ( head:mod:[ anti_synsem ],
                   val: 
		    ( subj:[ anti_synsem ],
                      spr:[ anti_synsem ],
		      comps:[ ( local: ( cat: ( head:( verb,
						    vform:bse_only ),
					      val:subj:
						 [ (synsem,
						    local:( local_min,
							    cont:index:Inst ),
						     nonlocal: ( slash:[], 
								 que:[],  
								 rel:[])) ],
					      mc:na ),
					cont: ( top:Khand,
                                               index:Ind ) ),
                                opt:plus ) ] ),
		   mc:plus ),
	     agr:Inst,
	     cont: ( top:Hand,
		    index:(Ind, e:tense:present ),
		    liszt: [ Msg, 
                                 (def_rel,  restr:Rhand,
                                             bv:Inst ),
				 (pron_rel, 
				  handel:Prohand,
				   inst:(Inst,
					  prontype:std_pron ) )|_],
		    h_cons: [ (qeq,
				   sc_arg:Soa ), 
                                  (qeq,
                                   sc_arg:Rhand,
                                    outscpd:Prohand )|_ ] ),
	     keys: ( key:( no_rel, handel:Khand ),
		    message:[( imp_rel, Msg,
			      handel:Hand,
			       soa:Soa ) ] ) ) ).

va_lets_imp_le := (@lex_imperative,
   synsem:local: ( cat:val:comps:[ ( local:cont:top:Chand ) ],
		   agr: ( png:( png, pn:firstpl_star ),
			 prontype:std_1pl ),
		   cont:( h_cons:[ ( outscpd:Chand ), qeq ],
			  liszt: [ relation, relation, relation ] ) ) ).

va_dont_imp_le := (@lex_imperative,
   synsem:local: ( cat:val:comps:[ ( local:cont:top:Chand ) ],
		   agr: ( png:( png, pn:secondper ),
			 prontype:std_2 ),
		   cont: ( liszt:[ relation,
				   relation,
                                   relation,
				   (neg_rel,
				  handel:Neghand,
				   arg:Arg )],
			  h_cons: [ ( outscpd:Neghand ),
                                    qeq,
				    (qeq,
				     sc_arg:Arg,
				      outscpd:Chand ) ] ) ) ).

basic_disc_adv_synsem := (@lex_synsem,
   local: ( cat: ( head:( root_marker,
		        prd:minus,
			 mod:[ ( local:( scopal_mod,
				        cat:val: ( subj:o_list,
                                                     spr:o_list,
                                                   comps:o_list ),
                                         cont:index:Ind,
					 keys:message:Msg ),
				 nonlocal:slash:[] ) ] ),
		  val: ( subj:[ ],
			spr:[ ],
			comps:[ ] ) ),
	    cont:index:( event_or_index, Ind),
	    keys:message:Msg,
	    conj:cnil ),
    nonlocal: ( slash:[],
		rel:[],
		que:[] ) ).

disc_adv_synsem := (@basic_disc_adv_synsem,
   local:cat: ( head:mod:[ ( local:cat:head:(disc_adverbee,
					     strict_head:plus)) ], %, strict_type
                mc:plus ) ).


disc_adv_word := (@msg_word,
   synsem:( @disc_adv_synsem,
	    local: ( cat:head:mod:[ ( local:cont: ( top:Mtop,
						   index:Mindex ) ) ],
		     cont: ( top:(Chand, handle),
			    index:Cind,
			    liszt: [(Key,  handel:Khand ),
				   (  discourse_rel,
				    handel:Chand,
				     c_arg:Cind,
				     l_handel:Khand,
				     r_handel:Mtop,
				     r_index:Mindex )],
                            h_cons:[] ),
                     keys:key:(Key, abstr_excl_rel )) ) ).

adv_disc_le := @disc_adv_word.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Temporal Nouns
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
abstr_hour_word := (@hc_word, @non_affix_bearing,
   synsem:(@phr_synsem,
	   lex:minus, %added for residue 
	   local:(nomod_local,
		  stemhead:nstem,
		  cat:(head:(noun_star,
			     poss:minus),
		       val:(subj:(Subj,[]),
			    spr:(Spr,
				 [(local:(local_min,
					  cat:(head:adv,
					       val:(spr:o_list,
						    comps:o_list,
						    spec:[local:cat:val:comps:[]])),
					  cont:top:Nhand,
					  keys:key:(degree_rel,
						    darg:Darg)),
				   opt:plus)]),
			   comps:(Comps,
				  [(expressed_synsem,
				   local:(cat:(head:intadj, %intadj2,
					       val:comps:[]),
					  conj:cnil,
					  cont:(top:Nhand,
						index:Minute),
					  keys:key:minute_rel),
				   nonlocal:slash:[],
				   opt:plus),
				  (expressed_synsem,
				      local:(cat:head:no_head,
					     conj:cnil,
					     cont:(top:Nhand,
						   index:AmPm),
					     keys:key:am_pm_rel),
				      nonlocal:slash:[],
				      opt:plus),
				  (expressed_synsem,
				      local:(cat:(@prd_cat,
						  head:(prep,
							mod:[local:(cont:(top:Nhand,
									 index:Index),
								    keys:key:Key)])),
					     keys:key:temp_loc_rel,
					     conj:cnil))])),
		       hc_lex:plus),
		  cont:(nom_obj,
			index:Index,
			liszt:(hd:(numbered_hour_rel,
				   Key,
				   handel:Nhand,
				   inst:Index,
				   min:Minute,
				   am_pm:AmPm,
				   dim:Darg),
			       tl:(hd:(def_rel,
				       bv:Index,
				       restr:Rhand))),
			h_cons:[(qeq,
				 sc_arg:Rhand,
				 outscpd:Nhand)]),
		  agr:Index,
		  arg_s:valence_append(Subj,Spr,Comps),
		  keys:key:Key),
	   modified:(notmod,
		     periph:plus))).
					       
n_hour_le := (@abstr_hour_word,
   %non_amalgamating_word, % added to prevent nonlocal feature amalgamation			 		 
   synsem:local:cont:liszt:[relation,relation]).

month_synsem := (@nonpro_nomod_onearg_synsem,
   local:(cat:(head:noun_star,
	       val:(spr:[(local:keys:key:quant_or_wh_rel,
			  opt:minus)],
		    comps:[(local:(local_min,
				    cat:(val:(subj:[],
					      comps:o_list,
					      spr:o_list),
					 mc:na),
				    conj:cnil,
				    cont:index:YearInd),
			     nonlocal:slash:[])])),
	  agr:Ind,
	  cont:(index:Ind,
		liszt:[Key,
			(x_of_rel,
			handel:Hand,
			event:e:tense:no_tense,
			arg:Ind,
			arg3:YearInd)],
		h_cons:[]),
	  keys:key:(Key,
		    handel:Hand,
		    inst:(Ind,
			  png:(png,
			       pn:thirdsg_star,
			       gen:neut)))),
   modified:notmod).		       
					 
month_no_of_year_synsem := (@month_synsem,
   local:(cat:val:comps:[(expressed_synsem,
			  local:(cat: @nomp_cat_acc_min,
				 keys:key:yofc_rel),
			  opt:minus)],
	  keys:key:mofy_rel)).

n_month_year_le := (@nontopkey,
   synsem: @month_no_of_year_synsem).

n_year_le := (@non_affixed_np,
   synsem:(@noun_nocomp_synsem,
	   local:(cat:(head:mod:[],
		       val:spr:[local:agr:(png:pn:thirdsg,
					   divisible:minus)]),
		  agr:divisible:minus,
		  conj:cnil,
		  keys:(key:yofc_rel,
			altkey:basic_nom_rel),
		  cont:(index:png:(png,
				   pn:thirdsg_star),
			liszt:[relation],
			h_cons:[])),
	   modified:notmod)).
		
basic_dom_synsem := (@common_noun_synsem,% @two_arg,
   local:(cat:val:spr:[(expressed_synsem,
			local:keys:key:quant_or_wh_rel)],
	  cont:(top:Hand,
		index:divisible:minus_star,
		liszt:hd:(dofm_rel,
			  handel:Hand,
			  inst:png:(png,
				    pn:thirdsg_star,
				    gen:neut_star))))).

basic_dom_ord_synsem := (@basic_dom_synsem,
   local:cat:(head:prd:plus,
	      val:(spr:[local:keys:key:abstr_def_rel],
		   comps:[nonlocal:slash:e_list]))).

dom_ord_synsem := (@basic_dom_ord_synsem, @temp_noun_ppcomp_synsem,
   local:cat:val:comps:[(local:keys:(key:x_of_rel,
				     compkey:mofy_rel),
			 opt:plus)]).

dom_ord_yofc_synsem := (@basic_dom_ord_synsem,
			      @basic_noun_npcomp_synsem,
   local:cat:val:(spr:[local:keys:altkey:mofy_rel],
		  comps:[(local:keys:key:yofc_rel,
			  opt:minus)])).

dom_card_synsem := (@basic_dom_synsem, @basic_noun_npcomp_synsem,
   local:(cat:(head:prd:minus,
	       val:(spr:[local:keys:(key:implicit_quant_rel,
				     altkey:mofy_rel)],
		    comps:[(local:keys:key:yofc_rel,
			    opt:plus)])),
	  keys:altkey:relation)).

abstr_n_day_of_month_le := (@hc_word, @non_affix_bearing,
   synsem: @basic_dom_synsem).

n_day_of_month_le := (@abstr_n_day_of_month_le,
			    synsem: @dom_ord_synsem).

n_day_of_month_card_le := (@abstr_n_day_of_month_le,
   synsem: @dom_card_synsem).

n_def_day_part_le := (@norm_no_affix_word,
   synsem:(@nomod_onearg_synsem,
	   local:(cat:(head:noun_star,
		       val:(spr:[(synsem,
				  local:(local_min,
					 cat:(head:det,
					      val:(subj:[],
						   comps:o_list)),
					 cont:(index:Inst,
					       liszt:[relation]),
					 keys:key:abstr_def_rel),
				  opt:minus)],
			    comps:[]),
		       posthead:plus),
		  agr:Inst,
		  cont:(index:Inst,
			liszt:[Key]),
		  keys:key:(def_day_part_rel,
			    Key,
			    inst:Inst)),
	   modified:notmod)).
						     
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%  Degree specifiers for adjectives
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
basic_degree_spec_synsem := (canonical_synsem,
    local:(nomod_local,
           cat:(head:adv_or_partn,
                val:(subj:e_list,
                     spr:(hd:(local:(local_min, %local_min
                                     cat:(head:adv,
                                          val:spr:o_list), %*olist*
                                     keys:key:(degree_rel,
                                               handel:Khand,
                                               darg:Darg)),
                              nonlocal:que:e_list,  
                              opt:plus),
                          tl:e_list),
                     spec:(hd:local:(keys:(key:handel:Khand,
                                           altkey:non_conj_rel),
                                     cont:(top:Hand,
                                           index:Specind)),
                           tl:e_list))),
           cont:(top:Hand,
                 index:Specind),
           keys:key:(degree_rel,
                     handel:Khand,
                     dim:Darg))).
 
degree_spec_synsem := (@basic_degree_spec_synsem,
    local:cat:val:comps:e_list).

lex_degree_spec_synsem := (@degree_spec_synsem, @lex_synsem,
    local:cat:head:adv,
    modified:periph:na).

phr_degree_spec_synsem := (@degree_spec_synsem, @phr_synsem).

eq_degree_spec_synsem := (@basic_degree_spec_synsem, @lex_synsem,
   local:(cat:(head:adv,
	       val:(spec:[local:cont:index:Adjind],
		    comps:[local:(cat:(head:prep,
				       val:comps:o_list),
				  keys:key:(x_as_comp_rel,
					    arg3:Cind))])),
	  keys:key:(eq_degree_rel,
		    arg:Adjind,
		    arg3:Cind))).
				 
basic_degree_spec_word := (@que_word,
    synsem:(@lex_degree_spec_synsem,
            local:(keys:key:Key,
                   cont:liszt:(hd:Key)))).  

degree_spec_word := (@basic_degree_spec_word, @nonque,
    synsem:local:cont:(liszt:(hd:(degree_rel,
                                  darg:deg_ind),
                              tl:e_list),
                       h_cons:e_list)).  

adv_degree_spec_le := @degree_spec_word.

adv_wh_degree_spec_le := (@basic_degree_spec_word,
   synsem: ( local:cont: ( liszt: [( abstr_deg_rel,
				  handel:Hand,
				   darg:Darg ),
			         (which_rel,
			          bv:Darg,
				   restr:Rhand ) ],
			  h_cons: [( qeq,  sc_arg:Rhand,
					    outscpd:Hand ) ] ),
	     nonlocal:que:[ handle ] ) ).

eq_degree_spec_le := (@que_word,
   synsem:(@eq_degree_spec_synsem,
	   local:(keys:key:Key,
		  cont:(liszt:[Key],
			h_cons:[])))).
				   

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Numbers
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%added lex_synsem so that slash amalgamation can apply
num_synsem := (@zero_arg, @lex_synsem, %basic_zero_arg,
    local:(cat:val:subj:e_list,
           cont:liszt:(hd:integer_rel,
                       tl:e_list))).  % ellipses

int_adj_synsem := (canonical_synsem,
                      local:(cat:(head:intadj,
                                  hc_lex:plus,
                                  val:subj:e_list,
                                  posthead:minus),
                             cont:index:non_expl_ind,
                             keys:key:integer_rel)).

anycard_norm_num_synsem := (@num_synsem, @int_adj_synsem).

basic_norm_num_synsem := (@num_synsem, @int_adj_synsem,
    local:(cat:(head:mod:[(local:(intersective_mod,
                                 cat: @nbar_cat,
                                 cont:(top:Mhand,
                                       index:Index),
                                 keys:key:nonpro_rel,
                                 conj:cnil,
                                 agr:Index),
                           modified:periph:na)],
                val:spec:[local:cont:top:Top]),
           cont:(top:Top,
                 index:Index),
           keys:(key:arg:Index,
                 altkey:handel:Mhand)),
    modified:periph:plus).

norm_num_synsem := (@basic_norm_num_synsem,@zero_arg,
    local:(cont:liszt:hd:Key,
           keys:key:Key)).

norm_num_word := (@nontopkey,
    synsem:(@norm_num_synsem,
            local:cat:head:(prd:minus,
                            mod:(hd:local:agr:divisible:plus_star, 
                                 tl:e_list)))).
        
norm_card_word := (@norm_num_word,
    synsem:local:keys:key:card_rel).

card_only_word := (@norm_card_word,
    synsem:local:(cat:head:ordinal:minus,
                  cont:index:png:(png,
                                  pn:thirdpl))).

ord_word := (@norm_num_word,
    synsem:local:(cat:(head:ordinal:plus,
		       val:comps:e_list),
		  keys:key:ord_rel)).

complement_free_number := (@norm_num_word,
    synsem:local:cat:val:comps:e_list).

unspecified_num := (@norm_num_word,
    synsem:local:(cat:val:spr:[(local:(local_min, %local_min
                                       cat:(head:adv,
                                            val:(spr:o_list,
                                                 comps:o_list)),
				       cont:top:Khand,
                                       keys:key:(degree_rel,
                                                 darg:Darg)),
                                opt:plus)],
                  keys:key:(handel:Khand,
                            dim:Darg))).

unspecified_num_without_complements := (@complement_free_number,
    @unspecified_num,
    synsem:local:(cont:liszt:(hd:const_rel,
                              tl:e_list),
                  keys:(key:Key,
                        altkey:Key))).

adj_bare_unspecified_card_le := (@card_only_word,
     @unspecified_num_without_complements).

adj_bare_unspecified_ord_le := (@ord_word,
				      @unspecified_num_without_complements).

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Titles
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

title_synsem := (%basic_zero_arg, and h_cons nonempty
   @lex_synsem, %added for residues		        
   local:(cat:(head:(adv,
		     mod:[(local:(intersective_mod,
				  cat: @nbar_cat,
				  conj:cnil,
				  cont:index:Nind,
				  keys:key:(abstr_named_rel,
					    handel:Nhand)),
			   modified:notmod_or_rmod)]),
	       val:(subj:[],
		    spr:[],
		    comps:[])),
	  cont:(index:Ind,
		liszt:[(Key,
			handel:Khand,
			inst:Ind),
		       (udef_rel,
			   bv:Ind,
			   restr:Rhand),
		       (title_id_rel,
			   handel:Nhand,
			   arg:Ind,
			   arg3:Nind)],
		h_cons:[(qeq,
			 sc_arg:Rhand,
			 outscpd:Khand)]),
	  keys:key:Key),
   modified:periph:na).

n_title_le := (@nontopkey,
   synsem:(@title_synsem,
	   local:cat:posthead:minus)).

n_post_title_le := (@norm_no_affix_word,
   synsem:(@title_synsem,
	   local:cat:posthead:plus)).
	  



